@@ -1,6 +1,6 @@
 /******************************************************************************
  *
- * Copyright (C) 1997-2014 by Dimitri van Heesch.
+ * Copyright (C) 1997-2015 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -116,7 +116,7 @@ static std::string uriDecode(const std::string & sSrc)
 }
 
 /** return list of strings that result when splitting \a s using 
- *  delimeter \a delim 
+ *  delimiter \a delim 
  */
 static std::vector<std::string> split(const std::string &s, char delim) 
 {
@@ -137,7 +137,7 @@ T fromString(const std::string& s)
   return t;
 }
 
-/** Class that holds the startin position of a word */
+/** Class that holds the starting position of a word */
 struct WordPosition
 {
   WordPosition(int s,int i) : start(s), index(i) {}
@@ -196,7 +196,7 @@ static bool insideRange(const std::vector<Range> &ranges,int start,int len)
 }
 
 /** Returns a list of text \a fragments from \a s containing one or
- *  more \a words. The list is sorted occording to the 
+ *  more \a words. The list is sorted according to the 
  *  number of occurrences of words within the fragment.
  */ 
 static void highlighter(const std::string &s,
@@ -367,12 +367,24 @@ int main(int argc,char **argv)
     // create query
     Xapian::Database db(indexDir);
     Xapian::Enquire enquire(db);
-    Xapian::Query query;
+
     std::vector<std::string> words = split(searchFor,' ');
-    for (std::vector<std::string>::const_iterator it=words.begin();it!=words.end();++it)
-    {
-      query = Xapian::Query(Xapian::Query::OP_OR,query,Xapian::Query(*it));
-    }
+    Xapian::QueryParser parser;
+    parser.set_database(db);
+    parser.set_default_op(Xapian::Query::OP_AND);
+    parser.set_stemming_strategy(Xapian::QueryParser::STEM_ALL);
+    Xapian::termcount max_expansion=100;
+#if (XAPIAN_MAJOR_VERSION==1) && (XAPIAN_MINOR_VERSION==2)
+    parser.set_max_wildcard_expansion(max_expansion);
+#else
+    parser.set_max_expansion(max_expansion,Xapian::Query::WILDCARD_LIMIT_MOST_FREQUENT);
+#endif
+    Xapian::Query query=parser.parse_query(searchFor,
+                                           Xapian::QueryParser::FLAG_DEFAULT  |
+                                           Xapian::QueryParser::FLAG_WILDCARD |
+                                           Xapian::QueryParser::FLAG_PHRASE   |
+                                           Xapian::QueryParser::FLAG_PARTIAL
+                                          );
     enquire.set_query(query);
 
     // get results
@@ -401,7 +413,7 @@ int main(int argc,char **argv)
       Xapian::Document doc = i.get_document();
       highlighter(doc.get_value(FIELD_DOC),words,hl);
       std::cout << "  {\"type\": \"" << doc.get_value(FIELD_TYPE) << "\"," << std::endl
-                << "   \"name\": \"" << doc.get_value(FIELD_NAME) << doc.get_value(FIELD_ARGS) << "\"," << std::endl
+                << "   \"name\": \"" << doc.get_value(FIELD_NAME) << escapeString(doc.get_value(FIELD_ARGS)) << "\"," << std::endl
                 << "   \"tag\": \""  << doc.get_value(FIELD_TAG) << "\"," << std::endl
                 << "   \"url\": \""  << doc.get_value(FIELD_URL) << "\"," << std::endl;
       std::cout << "   \"fragments\":[" << std::endl;
