@@ -1596,7 +1596,7 @@ QTextStream &QTextStream::output_int( int format, ulong n, bool neg )
     static char hexdigits_upper[] = "0123456789ABCDEF";
     CHECK_STREAM_PRECOND
     char buf[76];
-    register char *p;
+    char *p;
     int	  len;
     char *hexdigits;
 
@@ -1784,7 +1784,7 @@ QTextStream &QTextStream::operator<<( double f )
 	f_char = (flags() & uppercase) ? 'E' : 'e';
     else
 	f_char = (flags() & uppercase) ? 'G' : 'g';
-    register char *fs = format;			// generate format string
+    char *fs = format;			// generate format string
     *fs++ = '%';				//   "%.<prec>l<f_char>"
     *fs++ = '.';
     int prec = precision();
