@@ -22,11 +22,13 @@
 #include "language.h"
 #include "ftextstream.h"
 #include "resourcemgr.h"
+#include "doxygen.h"
 #include <qdir.h>
 
 //--------------------------------------------------------------------------
 
 const QCString CiteConsts::fileName("citelist");
+/* when changing this also take doxygen.bst into account */
 const QCString CiteConsts::anchorPrefix("CITEREF_");
 const QCString bibTmpFile("bibTmpFile_");
 const QCString bibTmpDir("bibTmpDir/");
@@ -77,7 +79,7 @@ void CiteDict::writeLatexBibliography(FTextStream &t)
       {
         if (i) t << ",";
         i++;
-        t << bibTmpFile << QString().setNum(i);
+        t << bibTmpFile << QCString().setNum(i);
       }
     }
     bibdata = citeDataList.next();
@@ -118,8 +120,58 @@ void CiteDict::generatePage() const
   // do not generate an empty citations page
   if (isEmpty()) return; // nothing to cite
 
-  // 1. generate file with markers and citations to OUTPUT_DIRECTORY
+  // 0. add cross references from the bib files to the cite dictionary
   QFile f;
+  QStrList &citeDataList = Config_getList(CITE_BIB_FILES);
+  const char *bibdata = citeDataList.first();
+  while (bibdata)
+  {
+    QCString bibFile = bibdata;
+    if (!bibFile.isEmpty() && bibFile.right(4)!=".bib") bibFile+=".bib";
+    QFileInfo fi(bibFile);
+    if (fi.exists())
+    {
+      if (!bibFile.isEmpty())
+      {
+        f.setName(bibFile);
+        if (!f.open(IO_ReadOnly)) 
+        {
+          err("could not open file %s for reading\n",bibFile.data());
+        }
+        QCString doc;
+        QFileInfo fi(bibFile);
+        QCString input(fi.size()+1);
+        f.readBlock(input.rawData(),fi.size());
+        f.close();
+        input.at(fi.size())='\0';
+        int p=0,s;
+        while ((s=input.find('\n',p))!=-1)
+        {
+          QCString line = input.mid(p,s-p);
+          p=s+1;
+
+	  int i;
+          if ((i = line.find("crossref")) != -1) /* assumption cross reference is on one line and the only item */
+          {
+            int j=line.find("{",i);
+            int k=line.find("}",i);
+            if (j!=-1 && k!=-1)
+            {
+              QCString label = line.mid(j+1,k-j-1);
+              if (!m_entries.find(label)) Doxygen::citeDict->insert(label.data());
+            }
+          }
+        }
+      }
+    }
+    else if (!fi.exists())
+    {
+      err("bib file %s not found!\n",bibFile.data());
+    }
+    bibdata = citeDataList.next();
+  }
+
+  // 1. generate file with markers and citations to OUTPUT_DIRECTORY
   QCString outputDir = Config_getString(OUTPUT_DIRECTORY);
   QCString citeListFile = outputDir+"/citelist.doc";
   f.setName(citeListFile);
@@ -154,12 +206,11 @@ void CiteDict::generatePage() const
   //    so bibtex can find them without path (bibtex doesn't support paths or
   //    filenames with spaces!)
   //    Strictly not required when only latex is generated
-  QStrList &citeDataList = Config_getList(CITE_BIB_FILES);
   QCString bibOutputDir = outputDir+"/"+bibTmpDir;
   QCString bibOutputFiles = "";
   QDir thisDir;
   thisDir.mkdir(bibOutputDir);
-  const char *bibdata = citeDataList.first();
+  bibdata = citeDataList.first();
   int i = 0;
   while (bibdata)
   {
@@ -175,10 +226,6 @@ void CiteDict::generatePage() const
         bibOutputFiles = bibOutputFiles + " " + bibTmpDir + bibTmpFile + QCString().setNum(i) + ".bib";
       }
     }
-    else if (!fi.exists())
-    {
-      err("bib file %s not found!\n",bibFile.data());
-    }
     bibdata = citeDataList.next();
   }
 
@@ -188,14 +235,14 @@ void CiteDict::generatePage() const
   // 5. run bib2xhtml perl script on the generated file which will insert the
   //    bibliography in citelist.doc
   int exitCode;
-  portable_sysTimerStop();
-  if ((exitCode=portable_system("perl","\""+bib2xhtmlFile+"\" "+bibOutputFiles+" \""+
+  Portable::sysTimerStop();
+  if ((exitCode=Portable::system("perl","\""+bib2xhtmlFile+"\" "+bibOutputFiles+" \""+
                          citeListFile+"\"")) != 0)
   {
     err("Problems running bibtex. Verify that the command 'perl --version' works from the command line. Exit code: %d\n",
         exitCode);
   }
-  portable_sysTimerStop();
+  Portable::sysTimerStop();
 
   QDir::setCurrent(oldDir);
 
@@ -223,7 +270,6 @@ void CiteDict::generatePage() const
 
     if      (line.find("<!-- BEGIN BIBLIOGRAPHY")!=-1) insideBib=TRUE;
     else if (line.find("<!-- END BIBLIOGRAPH")!=-1)    insideBib=FALSE;
-    else if (insideBib) doc+=line+"\n";
     int i;
     // determine text to use at the location of the @cite command
     if (insideBib && (i=line.find("name=\"CITEREF_"))!=-1)
@@ -234,20 +280,23 @@ void CiteDict::generatePage() const
       {
         QCString label = line.mid(i+14,j-i-14);
         QCString number = line.mid(j+2,k-j-1);
+        label = substitute(substitute(label,"&ndash;","--"),"&mdash;","---");
         CiteInfo *ci = m_entries.find(label);
         //printf("label='%s' number='%s' => %p\n",label.data(),number.data(),ci);
+        line = line.left(i+14) + label + line.right(line.length()-j);
         if (ci)
         {
           ci->text = number;
         }
       }
     }
+    if (insideBib) doc+=line+"\n";
   }
   //printf("doc=[%s]\n",doc.data());
 
   // 7. add it as a page
   addRelatedPage(CiteConsts::fileName,
-       theTranslator->trCiteReferences(),doc,0,CiteConsts::fileName,1,0,0,0);
+       theTranslator->trCiteReferences(),doc,CiteConsts::fileName,1);
 
   // 8. for latex we just copy the bib files to the output and let 
   //    latex do this work.
@@ -268,7 +317,7 @@ void CiteDict::generatePage() const
       {
         if (!bibFile.isEmpty())
         {
-          // bug_700510, multile times the same name were overwriting; creating new names
+          // bug_700510, multiple times the same name were overwriting; creating new names
           // also for names with spaces
           ++i;
           copyFile(bibFile,latexOutputDir + bibTmpFile + QCString().setNum(i) + ".bib");
@@ -286,7 +335,7 @@ void CiteDict::generatePage() const
   thisDir.remove(citeListFile);
   thisDir.remove(doxygenBstFile);
   thisDir.remove(bib2xhtmlFile);
-  // we might try to remove too many files as empty files didn't get a coresponding new file
+  // we might try to remove too many files as empty files didn't get a corresponding new file
   // but the remove function does not emit an error for it and we don't catch the error return
   // so no problem.
   for (unsigned int j = 1; j <= citeDataList.count(); j++)
