@@ -133,7 +133,12 @@ enum CommandType
   CMD_SETSCOPE     = 103,
   CMD_PUNT         = 104,
   CMD_PLUS         = 105,
-  CMD_MINUS        = 106
+  CMD_MINUS        = 106,
+  CMD_INCLUDEDOC   = 107,
+  CMD_SNIPPETDOC   = 108,
+  CMD_SNIPWITHLINES= 109,
+  CMD_EMOJI        = 110,
+  CMD_EQUAL        = 111
 };
 
 enum HtmlTagType
@@ -172,6 +177,11 @@ enum HtmlTagType
   HTML_SPAN      = 31,
   HTML_DIV       = 32,
   HTML_BLOCKQUOTE= 33,
+  HTML_STRIKE    = 34,
+  HTML_UNDERLINE = 35,
+  HTML_INS       = 36,
+  HTML_DEL       = 37,
+  HTML_S         = 38,
 
   XML_CmdMask    = 0x100,
 
@@ -205,7 +215,7 @@ class Mapper
 {
   public:
     int map(const char *n);
-    QString find(const int n);
+    QCString find(const int n);
     Mapper(const CommandMap *cm,bool caseSensitive);
   private:
     QDict<int> m_map;
