@@ -21,6 +21,7 @@ from xml.dom import minidom, Node
 def transformDocs(doc):
 	# join lines, unless it is an empty line
 	# remove doxygen layout constructs
+        # Note: also look at expert.cpp of doxywizard for doxywizard parts
 	doc = doc.strip()
 	doc = doc.replace("\n", " ")
 	doc = doc.replace("\r", " ")
@@ -57,13 +58,14 @@ def transformDocs(doc):
 				 doc)
 	doc = re.sub('\\\\ref +external', '"Linking to external documentation"',
 				 doc)
+	doc = re.sub('\\\\ref +formulas', '"Including formulas"', doc)
 	# fallback for not handled
 	doc = re.sub('\\\\ref', '', doc)
 	#<a href="address">description</a> -> description (see: address)
 	doc = re.sub('<a +href="([^"]*)" *>([^<]*)</a>', '\\2 (see: \\1)', doc)
 	# LaTeX name as formula -> LaTeX
 	doc = doc.replace("\\f$\\mbox{\\LaTeX}\\f$", "LaTeX")
-	# Other forula's (now just 2) so explicitely mentioned.
+	# Other formula's (now just 2) so explicitly mentioned.
 	doc = doc.replace("\\f$2^{(16+\\mbox{LOOKUP\\_CACHE\\_SIZE})}\\f$",
 					  "2^(16+LOOKUP_CACHE_SIZE)")
 	doc = doc.replace("\\f$2^{16} = 65536\\f$", "2^16=65536")
@@ -272,7 +274,7 @@ def parseOption(node):
 				print("              \"%s\"" % (line))
 		print("             );")
 		if defval != '':
-			print("  cs->setDefaultValue(\"%s\");" % (defval))
+			print("  cs->setDefaultValue(\"%s\");" % (defval.replace('\\','\\\\')))
 		if format == 'file':
 			print("  cs->setWidgetType(ConfigString::File);")
 		elif format == 'image':
@@ -529,7 +531,7 @@ def parseOptionDoc(node, first):
 				if defval != '':
 					print("")
 					print("The default value is: <code>%s</code>." % (
-						defval))
+						defval.replace('\\','\\\\')))
 			print("")
 		# depends handling
 		if (node.hasAttribute('depends')):
@@ -717,6 +719,10 @@ def main():
 		print("")
 		print("void ConfigValues::init()")
 		print("{")
+		print("  static bool first = TRUE;")
+		print("  if (!first) return;")
+		print("  first = FALSE;")
+		print("")
 		for n in elem.childNodes:
 			if n.nodeType == Node.ELEMENT_NODE:
 				if (n.nodeName == "group"):
