@@ -37,14 +37,14 @@ class ConfigOption
     /*! The type of option */
     enum OptionType 
     { 
-      O_Info,      //<! A section header
-      O_List,      //<! A list of items
-      O_Enum,      //<! A fixed set of items
-      O_String,    //<! A single item
-      O_Int,       //<! An integer value
-      O_Bool,      //<! A boolean value
-      O_Obsolete,  //<! An obsolete option
-      O_Disabled   //<! Disabled compile time option
+      O_Info,      //!< A section header
+      O_List,      //!< A list of items
+      O_Enum,      //!< A fixed set of items
+      O_String,    //!< A single item
+      O_Int,       //!< An integer value
+      O_Bool,      //!< A boolean value
+      O_Obsolete,  //!< An obsolete option
+      O_Disabled   //!< Disabled compile time option
     };
     enum 
     { 
@@ -73,7 +73,9 @@ class ConfigOption
 
   protected:
     virtual void writeTemplate(FTextStream &t,bool sl,bool upd) = 0;
+    virtual void compareDoxyfile(FTextStream &t) = 0;
     virtual void convertStrToVal() {}
+    virtual void emptyValueToDefault() {}
     virtual void substEnvVars() = 0;
     virtual void init() {}
 
@@ -103,6 +105,7 @@ class ConfigInfo : public ConfigOption
       m_doc = doc;
     }
     void writeTemplate(FTextStream &t, bool sl,bool);
+    void compareDoxyfile(FTextStream &){};
     void substEnvVars() {}
 };
 
@@ -123,7 +126,9 @@ class ConfigList : public ConfigOption
     void setWidgetType(WidgetType w) { m_widgetType = w; }
     WidgetType widgetType() const { return m_widgetType; }
     QStrList *valueRef() { return &m_value; }
+    QStrList getDefault() { return m_defaultValue; }
     void writeTemplate(FTextStream &t,bool sl,bool);
+    void compareDoxyfile(FTextStream &t);
     void substEnvVars();
     void init() { m_value = m_defaultValue; }
   private:
@@ -153,6 +158,7 @@ class ConfigEnum : public ConfigOption
     QCString *valueRef() { return &m_value; }
     void substEnvVars();
     void writeTemplate(FTextStream &t,bool sl,bool);
+    void compareDoxyfile(FTextStream &t);
     void init() { m_value = m_defValue.copy(); }
 
   private:
@@ -182,8 +188,10 @@ class ConfigString : public ConfigOption
     void setDefaultValue(const char *v) { m_defValue = v; }
     QCString *valueRef() { return &m_value; }
     void writeTemplate(FTextStream &t,bool sl,bool);
+    void compareDoxyfile(FTextStream &t);
     void substEnvVars();
     void init() { m_value = m_defValue.copy(); }
+    void emptyValueToDefault() { if(m_value.isEmpty()) m_value=m_defValue; };
   
   private:
     QCString m_value;
@@ -213,6 +221,7 @@ class ConfigInt : public ConfigOption
     void convertStrToVal();
     void substEnvVars();
     void writeTemplate(FTextStream &t,bool sl,bool upd);
+    void compareDoxyfile(FTextStream &t);
     void init() { m_value = m_defValue; }
   private:
     int m_value;
@@ -241,6 +250,7 @@ class ConfigBool : public ConfigOption
     void substEnvVars();
     void setValueString(const QCString &v) { m_valueString = v; }
     void writeTemplate(FTextStream &t,bool sl,bool upd);
+    void compareDoxyfile(FTextStream &t);
     void init() { m_value = m_defValue; }
   private:
     bool m_value;
@@ -256,6 +266,7 @@ class ConfigObsolete : public ConfigOption
     ConfigObsolete(const char *name) : ConfigOption(O_Obsolete)  
     { m_name = name; }
     void writeTemplate(FTextStream &,bool,bool);
+    void compareDoxyfile(FTextStream &) {}
     void substEnvVars() {}
 };
 
@@ -267,6 +278,7 @@ class ConfigDisabled : public ConfigOption
     ConfigDisabled(const char *name) : ConfigOption(O_Disabled)  
     { m_name = name; }
     void writeTemplate(FTextStream &,bool,bool);
+    void compareDoxyfile(FTextStream &) {}
     void substEnvVars() {}
 };
 
@@ -466,6 +478,11 @@ class ConfigImpl
      */
     void writeTemplate(FTextStream &t,bool shortIndex,bool updateOnly);
 
+    /*! Writes a the differences between the current configuration and the
+     *  template configuration to stream \a t.
+     */
+    void compareDoxyfile(FTextStream &t);
+
     void setHeader(const char *header) { m_header = header; }
 
     /////////////////////////////
@@ -477,6 +494,10 @@ class ConfigImpl
      */
     void convertStrToVal();
 
+    /*! Sets default value in case value is empty
+     */
+    void emptyValueToDefault();
+
     /*! Replaces references to environment variable by the actual value
      *  of the environment variable.
      */
