@@ -48,6 +48,8 @@ static LabelMap s_labels[] =
   { "markdown",     Debug::Markdown     },
   { "filteroutput", Debug::FilterOutput },
   { "lex",          Debug::Lex },
+  { "plantuml",     Debug::Plantuml },
+  { "fortranfixed2free", Debug::FortranFixed2Free },
   { 0,             (Debug::DebugMask)0  }
 };
 
