@@ -20,7 +20,9 @@
 
 #include "docvisitor.h"
 #include <qstack.h>
+#include <qlist.h>
 #include <qcstring.h>
+#include <docparser.h>
 
 class FTextStream;
 class CodeOutputInterface;
@@ -31,6 +33,7 @@ class DocbookDocVisitor : public DocVisitor
 {
     public:
     DocbookDocVisitor(FTextStream &t,CodeOutputInterface &ci);
+    ~DocbookDocVisitor();
     //--------------------------------------
     // visitor functions for leaf nodes
     //--------------------------------------
@@ -38,6 +41,7 @@ class DocbookDocVisitor : public DocVisitor
     void visit(DocLinkedWord *);
     void visit(DocWhiteSpace *);
     void visit(DocSymbol *);
+    void visit(DocEmoji *);
     void visit(DocURL *);
     void visit(DocLineBreak *);
     void visit(DocHorRuler *);
@@ -123,8 +127,6 @@ class DocbookDocVisitor : public DocVisitor
     void visitPost(DocXRefItem *);
     void visitPre(DocInternalRef *);
     void visitPost(DocInternalRef *);
-    void visitPre(DocCopy *);
-    void visitPost(DocCopy *);
     void visitPre(DocText *);
     void visitPost(DocText *);
     void visitPre(DocHtmlBlockQuote *);
@@ -145,18 +147,27 @@ class DocbookDocVisitor : public DocVisitor
     void pushEnabled();
     void popEnabled();
     void startMscFile(const QCString &fileName,const QCString &width,
-    const QCString &height, bool hasCaption);
+    const QCString &height, bool hasCaption,const QList<DocNode> &children);
     void endMscFile(bool hasCaption);
     void writeMscFile(const QCString &fileName, DocVerbatim *s);
     void startDiaFile(const QCString &fileName,const QCString &width,
-                      const QCString &height, bool hasCaption);
+                      const QCString &height, bool hasCaption,const QList<DocNode> &children);
     void endDiaFile(bool hasCaption);
     void writeDiaFile(const QCString &fileName, DocVerbatim *s);
     void startDotFile(const QCString &fileName,const QCString &width,
-    const QCString &height, bool hasCaption);
+    const QCString &height, bool hasCaption,const QList<DocNode> &children);
     void endDotFile(bool hasCaption);
     void writeDotFile(const QCString &fileName, DocVerbatim *s);
     void writePlantUMLFile(const QCString &fileName, DocVerbatim *s);
+    void visitPreStart(FTextStream &t,
+                   const QList<DocNode> &children,
+                   bool hasCaption,
+                   const QCString &name,
+                   const QCString &width,
+                   const QCString &height,
+                   bool inlineImage = FALSE);
+    void visitPostEnd(FTextStream &t, bool hasCaption, bool inlineImage = FALSE);
+    void visitCaption(const QList<DocNode> &children);
     //--------------------------------------
     // state variables
     //--------------------------------------
