@@ -62,8 +62,7 @@ void DocSets::initialize()
   QFile makefile(mfName);
   if (!makefile.open(IO_WriteOnly))
   {
-    err("Could not open file %s for writing\n",mfName.data());
-    exit(1);
+    term("Could not open file %s for writing\n",mfName.data());
   }
   FTextStream ts(&makefile);
 
@@ -113,8 +112,7 @@ void DocSets::initialize()
   QFile plist(plName);
   if (!plist.open(IO_WriteOnly))
   {
-    err("Could not open file %s for writing\n",plName.data());
-    exit(1);
+    term("Could not open file %s for writing\n",plName.data());
   }
   FTextStream ts(&plist);
 
@@ -149,8 +147,7 @@ void DocSets::initialize()
   m_nf = new QFile(notes);
   if (!m_nf->open(IO_WriteOnly))
   {
-    err("Could not open file %s for writing\n",notes.data());
-    exit(1);
+    term("Could not open file %s for writing\n",notes.data());
   }
   //QCString indexName=Config_getBool(GENERATE_TREEVIEW)?"main":"index";
   QCString indexName="index";
@@ -170,8 +167,7 @@ void DocSets::initialize()
   m_tf = new QFile(tokens);
   if (!m_tf->open(IO_WriteOnly))
   {
-    err("Could not open file %s for writing\n",tokens.data());
-    exit(1);
+    term("Could not open file %s for writing\n",tokens.data());
   }
   m_tts.setDevice(m_tf);
   m_tts << "<?xml version=\"1.0\" encoding=\"UTF-8\"?>" << endl;
@@ -236,7 +232,7 @@ void DocSets::addContentsItem(bool isDir,
                               const char *anchor,
                               bool /* separateIndex */,
                               bool /* addToNavIndex */,
-                              Definition * /*def*/)
+                              const Definition * /*def*/)
 {
   (void)isDir;
   //printf("DocSets::addContentsItem(%s) m_dc=%d\n",name,m_dc);
@@ -274,14 +270,14 @@ void DocSets::addContentsItem(bool isDir,
   }
 }
 
-void DocSets::addIndexItem(Definition *context,MemberDef *md,
+void DocSets::addIndexItem(const Definition *context,const MemberDef *md,
                            const char *,const char *)
 {
   if (md==0 && context==0) return;
 
-  FileDef *fd      = 0;
-  ClassDef *cd     = 0;
-  NamespaceDef *nd = 0;
+  const FileDef *fd      = 0;
+  const ClassDef *cd     = 0;
+  const NamespaceDef *nd = 0;
 
   if (md)
   {
@@ -326,7 +322,7 @@ void DocSets::addIndexItem(Definition *context,MemberDef *md,
     case SrcLangExt_PHP:     lang="php"; break;        // PHP4/5
     case SrcLangExt_D:       lang="d"; break;          // D
     case SrcLangExt_Java:    lang="java"; break;       // Java
-    case SrcLangExt_JS:      lang="javascript"; break; // Javascript
+    case SrcLangExt_JS:      lang="javascript"; break; // JavaScript
     case SrcLangExt_Python:  lang="python"; break;     // Python
     case SrcLangExt_Fortran: lang="fortran"; break;    // Fortran
     case SrcLangExt_VHDL:    lang="vhdl"; break;       // VHDL
@@ -334,6 +330,7 @@ void DocSets::addIndexItem(Definition *context,MemberDef *md,
     case SrcLangExt_SQL:     lang="sql"; break;        // Sql
     case SrcLangExt_Tcl:     lang="tcl"; break;        // Tcl
     case SrcLangExt_Markdown:lang="markdown"; break;   // Markdown
+    case SrcLangExt_Slice:   lang="slice"; break;      // Slice
     case SrcLangExt_Unknown: lang="unknown"; break;    // should not happen!
   }
 
@@ -401,6 +398,10 @@ void DocSets::addIndexItem(Definition *context,MemberDef *md,
         type="ifc"; break;
       case MemberType_Service:
         type="svc"; break;
+      case MemberType_Sequence:
+        type="sequence"; break;
+      case MemberType_Dictionary:
+        type="dictionary"; break;
     }
     cd = md->getClassDef();
     nd = md->getNamespaceDef();
@@ -412,7 +413,7 @@ void DocSets::addIndexItem(Definition *context,MemberDef *md,
     {
       scope = nd->name();
     }
-    MemberDef *declMd = md->memberDeclaration();
+    const MemberDef *declMd = md->memberDeclaration();
     if (declMd==0) declMd = md;
     {
       fd = md->getFileDef();
@@ -427,15 +428,15 @@ void DocSets::addIndexItem(Definition *context,MemberDef *md,
   {
     if (fd==0 && context->definitionType()==Definition::TypeFile)
     {
-      fd = (FileDef*)context;
+      fd = dynamic_cast<const FileDef*>(context);
     }
     if (cd==0 && context->definitionType()==Definition::TypeClass)
     {
-      cd = (ClassDef*)context;
+      cd = dynamic_cast<const ClassDef*>(context);
     }
     if (nd==0 && context->definitionType()==Definition::TypeNamespace)
     {
-      nd = (NamespaceDef*)context;
+      nd = dynamic_cast<const NamespaceDef*>(context);
     }
     if (fd)
     {
