@@ -50,8 +50,8 @@ class EclipseHelp : public IndexIntf
     virtual void decContentsDepth();
     virtual void addContentsItem(bool isDir, const char *name, const char *ref,
                                  const char *file, const char *anchor,bool separateIndex,bool addToNavIndex,
-                                 Definition *def);
-    virtual void addIndexItem(Definition *context,MemberDef *md,
+                                 const Definition *def);
+    virtual void addIndexItem(const Definition *context,const MemberDef *md,
                               const char *sectionAnchor,const char *title);
     virtual void addIndexFile(const char *name);
     virtual void addImageFile(const char *name);
