@@ -1,12 +1,12 @@
 /******************************************************************************
  *
- * 
+ *
  *
  * Copyright (C) 1997-2015 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
- * documentation under the terms of the GNU General Public License is hereby 
- * granted. No representations are made about the suitability of this software 
+ * documentation under the terms of the GNU General Public License is hereby
+ * granted. No representations are made about the suitability of this software
  * for any purpose. It is provided "as is" without express or implied warranty.
  * See the GNU General Public License for more details.
  *
@@ -18,36 +18,35 @@
 #ifndef ENTRY_H
 #define ENTRY_H
 
-#include "types.h"
-
-#include <qlist.h>
 #include <qgstring.h>
 
+#include <vector>
+#include <memory>
+
+#include "types.h"
+#include "arguments.h"
+
 struct SectionInfo;
 class QFile;
-class EntryNav;
 class FileDef;
-class FileStorage;
-class StorageIntf;
-class ArgumentList;
 struct ListItemInfo;
 
 /** This class stores information about an inheritance relation
- */ 
-struct BaseInfo 
+ */
+struct BaseInfo
 {
   /*! Creates an object representing an inheritance relation */
-  BaseInfo(const char *n,Protection p,Specifier v) : 
+  BaseInfo(const char *n,Protection p,Specifier v) :
     name(n),prot(p),virt(v) {}
   QCString   name; //!< the name of the base class
   Protection prot; //!< inheritance type
   Specifier  virt; //!< virtualness
 };
 
-/** This struct is used to capture the tag file information 
- *  for an Entry. 
+/** This struct is used to capture the tag file information
+ *  for an Entry.
  */
-struct TagInfo 
+struct TagInfo
 {
   QCString tagName;
   QCString fileName;
@@ -55,7 +54,7 @@ struct TagInfo
 };
 
 /** Represents an unstructured piece of information, about an
- *  entity found in the sources. 
+ *  entity found in the sources.
  *
  *  parseMain() in scanner.l will generate a tree of these
  *  entries.
@@ -65,13 +64,13 @@ class Entry
   public:
 
     /*! Kind of entries that are supported */
-    enum Sections { 
-      CLASS_SEC        = 0x00000001, 
+    enum Sections {
+      CLASS_SEC        = 0x00000001,
       NAMESPACE_SEC    = 0x00000010,
       COMPOUND_MASK    = CLASS_SEC,
       SCOPE_MASK       = COMPOUND_MASK | NAMESPACE_SEC,
-      
-      CLASSDOC_SEC     = 0x00000800, 
+
+      CLASSDOC_SEC     = 0x00000800,
       STRUCTDOC_SEC    = 0x00001000,
       UNIONDOC_SEC     = 0x00002000,
       EXCEPTIONDOC_SEC = 0x00004000,
@@ -81,7 +80,7 @@ class Entry
       CATEGORYDOC_SEC  = 0x00040000,
       SERVICEDOC_SEC   = 0x00080000,
       SINGLETONDOC_SEC = 0x00100000,
-      COMPOUNDDOC_MASK = CLASSDOC_SEC | STRUCTDOC_SEC | UNIONDOC_SEC | 
+      COMPOUNDDOC_MASK = CLASSDOC_SEC | STRUCTDOC_SEC | UNIONDOC_SEC |
                          INTERFACEDOC_SEC | EXCEPTIONDOC_SEC | PROTOCOLDOC_SEC |
                          CATEGORYDOC_SEC | SERVICEDOC_SEC | SINGLETONDOC_SEC,
 
@@ -91,14 +90,14 @@ class Entry
 
       ENUMDOC_SEC      = 0x01000000,
       ENUM_SEC         = 0x02000000,
-      EMPTY_SEC        = 0x03000000, 
-      PAGEDOC_SEC      = 0x04000000, 
+      EMPTY_SEC        = 0x03000000,
+      PAGEDOC_SEC      = 0x04000000,
       VARIABLE_SEC     = 0x05000000,
       FUNCTION_SEC     = 0x06000000,
       TYPEDEF_SEC      = 0x07000000,
-      MEMBERDOC_SEC    = 0x08000000, 
+      MEMBERDOC_SEC    = 0x08000000,
       OVERLOADDOC_SEC  = 0x09000000,
-      EXAMPLE_SEC      = 0x0a000000, 
+      EXAMPLE_SEC      = 0x0a000000,
       VARIABLEDOC_SEC  = 0x0b000000,
       FILEDOC_SEC      = 0x0c000000,
       DEFINEDOC_SEC    = 0x0d000000,
@@ -112,9 +111,10 @@ class Entry
       PACKAGE_SEC      = 0x15000000,
       PACKAGEDOC_SEC   = 0x16000000,
       OBJCIMPL_SEC     = 0x17000000,
-      DIRDOC_SEC       = 0x18000000
-      ,EXPORTED_INTERFACE_SEC = 0x19000000
-      ,INCLUDED_SERVICE_SEC = 0x1A000000
+      DIRDOC_SEC       = 0x18000000,
+      EXPORTED_INTERFACE_SEC = 0x19000000,
+      INCLUDED_SERVICE_SEC   = 0x1A000000,
+      EXAMPLE_LINENO_SEC     = 0x1B000000,
     };
 
     // class specifiers (add new items to the end)
@@ -133,9 +133,11 @@ class Entry
     static const uint64 Enum            = (1ULL<<12); // for Java-style enums
     static const uint64 Service         = (1ULL<<13); // UNO IDL
     static const uint64 Singleton       = (1ULL<<14); // UNO IDL
-    static const uint64 ForwardDecl     = (1ULL<<15); // forward declarad template classes
+    static const uint64 ForwardDecl     = (1ULL<<15); // forward declared template classes
+    static const uint64 Local           = (1ULL<<16); // for Slice types
 
     // member specifiers (add new items to the beginning)
+    static const uint64 ConstExpr       = (1ULL<<19); // C++11 constexpr
     static const uint64 PrivateGettable     = (1ULL<<20); // C# private getter
     static const uint64 ProtectedGettable   = (1ULL<<21); // C# protected getter
     static const uint64 PrivateSettable     = (1ULL<<22); // C# private setter
@@ -184,7 +186,7 @@ class Entry
     enum GroupDocType
     {
       GROUPDOC_NORMAL,        //!< defgroup
-      GROUPDOC_ADD,           //!< addgroup
+      GROUPDOC_ADD,           //!< addtogroup
       GROUPDOC_WEAK           //!< weakgroup
     };                        //!< kind of group
 
@@ -192,67 +194,75 @@ class Entry
     Entry(const Entry &);
    ~Entry();
 
-    /*! Returns the static size of the Entry (so excluding any dynamic memory) */
-    int getSize();
-
     void addSpecialListItem(const char *listName,int index);
-    void createNavigationIndex(EntryNav *rootNav,FileStorage *storage,FileDef *fd);
-
-    // while parsing a file these function can be used to navigate/build the tree
-    void setParent(Entry *parent) { m_parent = parent; }
 
     /*! Returns the parent for this Entry or 0 if this entry has no parent. */
     Entry *parent() const { return m_parent; }
 
-    /*! Returns the list of children for this Entry 
+    /*! Returns the list of children for this Entry
      *  @see addSubEntry() and removeSubEntry()
      */
-    const QList<Entry> *children() const { return m_sublist; }
+    const std::vector< std::shared_ptr<Entry> > &children() const { return m_sublist; }
 
-    /*! Adds entry \a e as a child to this entry */
-    void addSubEntry (Entry* e) ;
+    /*! @name add entry as a child and pass ownership.
+     *  @note This makes the entry passed invalid! (TODO: tclscanner.l still has use after move!)
+     *  @{
+     */
+    void moveToSubEntryAndKeep(Entry* e);
+    void moveToSubEntryAndKeep(std::shared_ptr<Entry> &e);
+    /*! @} */
 
-    /*! Removes entry \a e from the list of children. 
-     *  Returns a pointer to the entry or 0 if the entry was not a child. 
-     *  Note the entry will not be deleted.
-     */ 
-    Entry *removeSubEntry(Entry *e);
+    /*! @name add entry as a child, pass ownership and reinitialize entry */
+    void moveToSubEntryAndRefresh(Entry* &e);
+    void moveToSubEntryAndRefresh(std::shared_ptr<Entry> &e);
+
+    /*! take \a child of of to list of children and move it into \a moveTo */
+    void moveFromSubEntry(const Entry *child,std::shared_ptr<Entry> &moveTo);
+
+    /*! make a copy of \a e and add it as a child to this entry */
+    void copyToSubEntry (Entry* e);
+    void copyToSubEntry (const std::shared_ptr<Entry> &e);
+
+    /*! Removes entry \a e from the list of children.
+     *  The entry will be deleted if found.
+     */
+    void removeSubEntry(const Entry *e);
 
     /*! Restore the state of this Entry to the default value it has
-     *  at construction time. 
+     *  at construction time.
      */
     void reset();
 
-    /*! Serialize this entry to a persistent storage stream. */
-    void marshall(StorageIntf *);
-
-    /*! Reinitialize this entry from a persistent storage stream. */
-    void unmarshall(StorageIntf *);
-
-  public:
+    void markAsProcessed() const { ((Entry*)(this))->section = Entry::EMPTY_SEC; }
+    void setFileDef(FileDef *fd);
+    FileDef *fileDef() const { return m_fileDef; }
 
     // identification
     int          section;     //!< entry type (see Sections);
-    QCString	 type;        //!< member type 
+    QCString	 type;        //!< member type
     QCString	 name;        //!< member name
-    TagInfo     *tagInfo;     //!< tag file info
+    bool         hasTagInfo;  //!< is tag info valid
+    TagInfo      tagInfoData; //!< tag file info data
+    const TagInfo *tagInfo() const { return hasTagInfo ? &tagInfoData : 0; }
 
     // content
     Protection protection;    //!< class protection
     MethodTypes mtype;        //!< signal, slot, (dcop) method, or property?
     uint64 spec;              //!< class/member specifiers
-    int  initLines;           //!< define/variable initializer lines to show 
+    int  initLines;           //!< define/variable initializer lines to show
     bool stat;                //!< static ?
     bool explicitExternal;    //!< explicitly defined as external?
     bool proto;               //!< prototype ?
     bool subGrouping;         //!< automatically group class members?
     bool callGraph;           //!< do we need to draw the call graph?
     bool callerGraph;         //!< do we need to draw the caller graph?
-    Specifier    virt;        //!< virtualness of the entry 
+    bool referencedByRelation;//!< do we need to show the referenced by relation?
+    bool referencesRelation;  //!< do we need to show the references relation?
+    Specifier    virt;        //!< virtualness of the entry
     QCString     args;        //!< member argument string
     QCString     bitfields;   //!< member's bit fields
-    ArgumentList *argList;    //!< member arguments as a list
-    QList<ArgumentList> *tArgLists; //!< template argument declarations
+    ArgumentList argList;     //!< member arguments as a list
+    std::vector<ArgumentList> tArgLists; //!< template argument declarations
     QGString	 program;     //!< the program text
     QGString     initializer; //!< initial value (for variables)
     QCString     includeFile; //!< include file (2 arg of \\class, must be unique)
@@ -272,22 +282,24 @@ class Entry
     QCString     write;       //!< property write accessor
     QCString     inside;      //!< name of the class in which documents are found
     QCString     exception;   //!< throw specification
-    ArgumentList *typeConstr; //!< where clause (C#) for type constraints
+    ArgumentList typeConstr;  //!< where clause (C#) for type constraints
     int          bodyLine;    //!< line number of the definition in the source
     int          endBodyLine; //!< line number where the definition ends
     int          mGrpId;      //!< member group id
-    QList<BaseInfo> *extends; //!< list of base classes    
-    QList<Grouping> *groups;  //!< list of groups this entry belongs to
-    QList<SectionInfo> *anchors; //!< list of anchors defined in this entry
+    std::vector<BaseInfo> extends; //!< list of base classes
+    std::vector<Grouping> groups;  //!< list of groups this entry belongs to
+    std::vector<const SectionInfo*> anchors; //!< list of anchors defined in this entry
     QCString	fileName;     //!< file this entry was extracted from
     int		startLine;    //!< start line of entry in the source
     int		startColumn;  //!< start column of entry in the source
-    QList<ListItemInfo> *sli; //!< special lists (test/todo/bug/deprecated/..) this entry is in
+    std::vector<ListItemInfo> sli; //!< special lists (test/todo/bug/deprecated/..) this entry is in
     SrcLangExt  lang;         //!< programming language in which this entry was found
     bool        hidden;       //!< does this represent an entity that is hidden from the output
     bool        artificial;   //!< Artificially introduced item
     GroupDocType groupDocType;
     QCString    id;           //!< libclang id
+    LocalToc    localToc;
+    QCString    metaData;     //!< Slice metadata
 
 
     static int  num;          //!< counts the total number of entries
@@ -295,21 +307,21 @@ class Entry
     /// return the command name used to define GROUPDOC_SEC
     const char *groupDocCmd() const
     {
-      switch( groupDocType ) 
+      switch( groupDocType )
       {
         case GROUPDOC_NORMAL: return "\\defgroup";
-        case GROUPDOC_ADD: return "\\addgroup";
+        case GROUPDOC_ADD: return "\\addtogroup";
         case GROUPDOC_WEAK: return "\\weakgroup";
         default: return "unknown group command";
       }
     }
     Grouping::GroupPri_t groupingPri() const
     {
-      if( section != GROUPDOC_SEC ) 
+      if( section != GROUPDOC_SEC )
       {
         return Grouping::GROUPING_LOWEST;
       }
-      switch( groupDocType ) 
+      switch( groupDocType )
       {
         case GROUPDOC_NORMAL: return Grouping::GROUPING_AUTO_DEF;
         case GROUPDOC_ADD:    return Grouping::GROUPING_AUTO_ADD;
@@ -318,65 +330,11 @@ class Entry
       }
     }
 
-  private:  
-    void createSubtreeIndex(EntryNav *nav,FileStorage *storage,FileDef *fd);
-    Entry         *m_parent;    //!< parent node in the tree
-    QList<Entry>  *m_sublist;   //!< entries that are children of this one
-    Entry &operator=(const Entry &); 
-};
-
-/** Wrapper for a node in the Entry tree.
- *
- *  Allows navigating through the Entry tree and load and storing Entry
- *  objects persistently to disk.
- */
-class EntryNav
-{
-  public:
-    EntryNav(EntryNav *parent,Entry *e);
-   ~EntryNav();
-    void addChild(EntryNav *);
-    bool loadEntry(FileStorage *storage);
-    bool saveEntry(Entry *e,FileStorage *storage);
-    void setEntry(Entry *e);
-    void releaseEntry();
-    void changeSection(int section) { m_section = section; }
-    void setFileDef(FileDef *fd) { m_fileDef = fd; }
-
-    Entry *entry() const { return m_info; }
-    int section() const { return m_section; }
-    SrcLangExt lang() const { return m_lang; }
-    const QCString &type() const { return m_type; }
-    const QCString &name() const { return m_name; }
-    TagInfo *tagInfo() const { return m_tagInfo; }
-    const QList<EntryNav> *children() const { return m_subList; }
-    EntryNav *parent() const { return m_parent; }
-    FileDef *fileDef() const { return m_fileDef; }
-
   private:
-
-    // navigation 
-    EntryNav        *m_parent;    //!< parent node in the tree
-    QList<EntryNav> *m_subList;   //!< entries that are children of this one
-
-    // identification
-    int          m_section;     //!< entry type (see Sections);
-    QCString	 m_type;        //!< member type 
-    QCString	 m_name;        //!< member name
-    TagInfo     *m_tagInfo;      //!< tag file info
-    FileDef     *m_fileDef;
-    SrcLangExt   m_lang;         //!< programming language in which this entry was found
-
-    Entry       *m_info;
-    int64        m_offset;
-    bool         m_noLoad;
+    Entry         *m_parent;    //!< parent node in the tree
+    std::vector< std::shared_ptr<Entry> > m_sublist;
+    Entry &operator=(const Entry &);
+    FileDef       *m_fileDef;
 };
 
-
-typedef QList<Entry> EntryList;
-typedef QListIterator<Entry> EntryListIterator;
-
-typedef QList<EntryNav> EntryNavList;
-typedef QListIterator<EntryNav> EntryNavListIterator;
-
 #endif
