@@ -1,8 +1,8 @@
 /******************************************************************************
  *
- * $Id: example.h,v 1.10 2001/03/19 19:27:40 root Exp $
+ * 
  *
- * Copyright (C) 1997-2013 by Dimitri van Heesch.
+ * Copyright (C) 1997-2015 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -36,11 +36,12 @@ struct Example
 class ExampleSDict : public SDict<Example>
 {
   public:
-    ExampleSDict(int size=17) : SDict<Example>(size) {}
+    ExampleSDict(int size=17) : SDict<Example>(size) { setAutoDelete(TRUE); }
    ~ExampleSDict() {}
-    int compareItems(QCollection::Item item1,QCollection::Item item2)
+  private:
+    int compareValues(const Example *item1,const Example *item2) const
     {
-      return qstricmp(((Example *)item1)->name,((Example *)item2)->name);
+      return qstricmp(item1->name,item2->name);
     }
 };
 
