@@ -4,8 +4,8 @@
  * Copyright (C) 1997-2015 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
- * documentation under the terms of the GNU General Public License is hereby 
- * granted. No representations are made about the suitability of this software 
+ * documentation under the terms of the GNU General Public License is hereby
+ * granted. No representations are made about the suitability of this software
  * for any purpose. It is provided "as is" without express or implied warranty.
  * See the GNU General Public License for more details.
  *
@@ -35,6 +35,7 @@
 #include "docparser.h"
 #include "htmldocvisitor.h"
 #include "filedef.h"
+#include "classdef.h"
 #include "util.h"
 #include "resourcemgr.h"
 
@@ -45,7 +46,7 @@ static int folderId=1;
 struct FTVNode
 {
   FTVNode(bool dir,const char *r,const char *f,const char *a,
-          const char *n,bool sepIndex,bool navIndex,Definition *df)
+          const char *n,bool sepIndex,bool navIndex,const Definition *df)
     : isLast(TRUE), isDir(dir),ref(r),file(f),anchor(a),name(n), index(0),
       parent(0), separateIndex(sepIndex), addToNavIndex(navIndex),
       def(df) { children.setAutoDelete(TRUE); }
@@ -62,7 +63,7 @@ struct FTVNode
   FTVNode *parent;
   bool separateIndex;
   bool addToNavIndex;
-  Definition *def;
+  const Definition *def;
 };
 
 int FTVNode::computeTreeDepth(int level) const
@@ -99,11 +100,11 @@ int FTVNode::numNodesAtLevel(int level,int maxLevel) const
 
 //----------------------------------------------------------------------------
 
-/*! Constructs an ftv help object. 
- *  The object has to be \link initialize() initialized\endlink before it can 
+/*! Constructs an ftv help object.
+ *  The object has to be \link initialize() initialized\endlink before it can
  *  be used.
  */
-FTVHelp::FTVHelp(bool TLI) 
+FTVHelp::FTVHelp(bool TLI)
 {
   /* initial depth */
   m_indentNodes = new QList<FTVNode>[MAX_INDENT];
@@ -134,7 +135,7 @@ void FTVHelp::finalize()
   generateTreeView();
 }
 
-/*! Increase the level of the contents hierarchy. 
+/*! Increase the level of the contents hierarchy.
  *  This will start a new sublist in contents file.
  *  \sa decContentsDepth()
  */
@@ -171,11 +172,10 @@ void FTVHelp::decContentsDepth()
 
 /*! Add a list item to the contents file.
  *  \param isDir TRUE if the item is a directory, FALSE if it is a text
- *  \param name The name of the item.
+ *  \param name the name of the item.
  *  \param ref  the URL of to the item.
  *  \param file the file containing the definition of the item
  *  \param anchor the anchor within the file.
- *  \param name the name of the item.
  *  \param separateIndex put the entries in a separate index file
  *  \param addToNavIndex add this entry to the quick navigation index
  *  \param def Definition corresponding to this entry
@@ -187,7 +187,7 @@ void FTVHelp::addContentsItem(bool isDir,
                               const char *anchor,
                               bool separateIndex,
                               bool addToNavIndex,
-                              Definition *def
+                              const Definition *def
                               )
 {
   //printf("%p: m_indent=%d addContentsItem(%s,%s,%s,%s)\n",this,m_indent,name,ref,file,anchor);
@@ -204,10 +204,10 @@ void FTVHelp::addContentsItem(bool isDir,
     QList<FTVNode> *pnl = &m_indentNodes[m_indent-1];
     newNode->parent = pnl->getLast();
   }
-  
+
 }
 
-static QCString node2URL(FTVNode *n,bool overruleFile=FALSE,bool srcLink=FALSE)
+static QCString node2URL(const FTVNode *n,bool overruleFile=FALSE,bool srcLink=FALSE)
 {
   QCString url = n->file;
   if (!url.isEmpty() && url.at(0)=='!')  // relative URL
@@ -223,7 +223,7 @@ static QCString node2URL(FTVNode *n,bool overruleFile=FALSE,bool srcLink=FALSE)
   {
     if (overruleFile && n->def && n->def->definitionType()==Definition::TypeFile)
     {
-      FileDef *fd = (FileDef*)n->def;
+      const FileDef *fd = dynamic_cast<const FileDef*>(n->def);
       if (srcLink)
       {
         url = fd->getSourceFileBase();
@@ -274,6 +274,7 @@ void FTVHelp::generateLink(FTextStream &t,FTVNode *n)
 {
   //printf("FTVHelp::generateLink(ref=%s,file=%s,anchor=%s\n",
   //    n->ref.data(),n->file.data(),n->anchor.data());
+  bool setTarget = FALSE;
   if (n->file.isEmpty()) // no link
   {
     t << "<b>" << convertToHtml(n->name) << "</b>";
@@ -283,7 +284,9 @@ void FTVHelp::generateLink(FTextStream &t,FTVNode *n)
     if (!n->ref.isEmpty()) // link to entity imported via tag file
     {
       t << "<a class=\"elRef\" ";
-      t << externalLinkTarget() << externalRef("",n->ref,FALSE);
+      QCString result = externalLinkTarget();
+      if (result != "") setTarget = TRUE;
+      t << result;
     }
     else // local link
     {
@@ -292,10 +295,17 @@ void FTVHelp::generateLink(FTextStream &t,FTVNode *n)
     t << "href=\"";
     t << externalRef("",n->ref,TRUE);
     t << node2URL(n);
-    if (m_topLevelIndex)
-      t << "\" target=\"basefrm\">";
+    if (!setTarget)
+    {
+      if (m_topLevelIndex)
+        t << "\" target=\"basefrm\">";
+      else
+        t << "\" target=\"_self\">";
+    }
     else
-      t << "\" target=\"_self\">";
+    {
+      t << "\">";
+    }
     t << convertToHtml(n->name);
     t << "</a>";
     if (!n->ref.isEmpty())
@@ -305,7 +315,7 @@ void FTVHelp::generateLink(FTextStream &t,FTVNode *n)
   }
 }
 
-static void generateBriefDoc(FTextStream &t,Definition *def)
+static void generateBriefDoc(FTextStream &t,const Definition *def)
 {
   QCString brief = def->briefDescription(TRUE);
   //printf("*** %p: generateBriefDoc(%s)='%s'\n",def,def->name().data(),brief.data());
@@ -322,6 +332,27 @@ static void generateBriefDoc(FTextStream &t,Definition *def)
   }
 }
 
+static char compoundIcon(const ClassDef *cd)
+{
+  char icon='C';
+  if (cd->getLanguage() == SrcLangExt_Slice)
+  {
+    if (cd->compoundType()==ClassDef::Interface)
+    {
+      icon='I';
+    }
+    else if (cd->compoundType()==ClassDef::Struct)
+    {
+      icon='S';
+    }
+    else if (cd->compoundType()==ClassDef::Exception)
+    {
+      icon='E';
+    }
+  }
+  return icon;
+}
+
 void FTVHelp::generateTree(FTextStream &t, const QList<FTVNode> &nl,int level,int maxLevel,int &index)
 {
   QListIterator<FTVNode> nli(nl);
@@ -350,11 +381,19 @@ void FTVHelp::generateTree(FTextStream &t, const QList<FTVNode> &nl,int level,in
       }
       else if (n->def && n->def->definitionType()==Definition::TypeNamespace)
       {
-        t << "<span class=\"icona\"><span class=\"icon\">N</span></span>";
+        if (n->def->getLanguage() == SrcLangExt_Slice)
+        {
+          t << "<span class=\"icona\"><span class=\"icon\">M</span></span>";
+        }
+        else
+        {
+          t << "<span class=\"icona\"><span class=\"icon\">N</span></span>";
+        }
       }
       else if (n->def && n->def->definitionType()==Definition::TypeClass)
       {
-        t << "<span class=\"icona\"><span class=\"icon\">C</span></span>";
+        char icon=compoundIcon(dynamic_cast<const ClassDef*>(n->def));
+        t << "<span class=\"icona\"><span class=\"icon\">" << icon << "</span></span>";
       }
       else
       {
@@ -376,16 +415,16 @@ void FTVHelp::generateTree(FTextStream &t, const QList<FTVNode> &nl,int level,in
     }
     else // leaf node
     {
-      FileDef *srcRef=0;
+      const FileDef *srcRef=0;
       if (n->def && n->def->definitionType()==Definition::TypeFile &&
-          ((FileDef*)n->def)->generateSourceFile())
+          (dynamic_cast<const FileDef*>(n->def))->generateSourceFile())
       {
-        srcRef = (FileDef*)n->def;
+        srcRef = dynamic_cast<const FileDef*>(n->def);
       }
       if (srcRef)
       {
         t << "<a href=\"" << srcRef->getSourceFileBase()
-          << Doxygen::htmlFileExtension 
+          << Doxygen::htmlFileExtension
           << "\">";
       }
       if (n->def && n->def->definitionType()==Definition::TypeGroup)
@@ -398,11 +437,19 @@ void FTVHelp::generateTree(FTextStream &t, const QList<FTVNode> &nl,int level,in
       }
       else if (n->def && n->def->definitionType()==Definition::TypeNamespace)
       {
-        t << "<span class=\"icona\"><span class=\"icon\">N</span></span>";
+        if (n->def->getLanguage() == SrcLangExt_Slice)
+        {
+          t << "<span class=\"icona\"><span class=\"icon\">M</span></span>";
+        }
+        else
+        {
+          t << "<span class=\"icona\"><span class=\"icon\">N</span></span>";
+        }
       }
       else if (n->def && n->def->definitionType()==Definition::TypeClass)
       {
-        t << "<span class=\"icona\"><span class=\"icon\">C</span></span>";
+        char icon=compoundIcon(dynamic_cast<const ClassDef*>(n->def));
+        t << "<span class=\"icona\"><span class=\"icon\">" << icon << "</span></span>";
       }
       else
       {
@@ -445,7 +492,7 @@ class NavIndexEntryList : public QList<NavIndexEntry>
     }
 };
 
-static QCString pathToNode(FTVNode *leaf,FTVNode *n)
+static QCString pathToNode(const FTVNode *leaf,const FTVNode *n)
 {
   QCString result;
   if (n->parent)
@@ -464,7 +511,7 @@ static bool dupOfParent(const FTVNode *n)
   return FALSE;
 }
 
-static void generateJSLink(FTextStream &t,FTVNode *n)
+static void generateJSLink(FTextStream &t,const FTVNode *n)
 {
   if (n->file.isEmpty()) // no link
   {
@@ -487,7 +534,7 @@ static QCString convertFileId2Var(const QCString &fileId)
   return substitute(varId,"-","_");
 }
 
-static bool generateJSTree(NavIndexEntryList &navIndex,FTextStream &t, 
+static bool generateJSTree(NavIndexEntryList &navIndex,FTextStream &t,
                            const QList<FTVNode> &nl,int level,bool &first)
 {
   static QCString htmlOutput = Config_getString(HTML_OUTPUT);
@@ -495,7 +542,7 @@ static bool generateJSTree(NavIndexEntryList &navIndex,FTextStream &t,
   indentStr.fill(' ',level*2);
   bool found=FALSE;
   QListIterator<FTVNode> nli(nl);
-  FTVNode *n;
+  const FTVNode *n;
   for (nli.toFirst();(n=nli.current());++nli)
   {
     // terminate previous entry
@@ -513,7 +560,7 @@ static bool generateJSTree(NavIndexEntryList &navIndex,FTextStream &t,
     {
       if (n->def && n->def->definitionType()==Definition::TypeFile)
       {
-        FileDef *fd = (FileDef*)n->def;
+        const FileDef *fd = dynamic_cast<const FileDef*>(n->def);
         bool doc,src;
         doc = fileVisibleInIndex(fd,src);
         if (doc)
@@ -543,7 +590,7 @@ static bool generateJSTree(NavIndexEntryList &navIndex,FTextStream &t,
         {
           fileId+="_"+n->anchor;
         }
-        if (dupOfParent(n)) 
+        if (dupOfParent(n))
         {
           fileId+="_dup";
         }
@@ -553,7 +600,7 @@ static bool generateJSTree(NavIndexEntryList &navIndex,FTextStream &t,
           FTextStream tt(&f);
           tt << "var " << convertFileId2Var(fileId) << " =" << endl;
           generateJSTree(navIndex,tt,n->children,1,firstChild);
-          tt << endl << "];"; 
+          tt << endl << "];";
         }
         t << "\"" << fileId << "\" ]";
       }
@@ -571,7 +618,7 @@ static bool generateJSTree(NavIndexEntryList &navIndex,FTextStream &t,
       if (emptySection)
         t << "null ]";
       else
-        t << endl << indentStr << "  ] ]"; 
+        t << endl << indentStr << "  ] ]";
     }
   }
   return found;
@@ -588,13 +635,14 @@ static void generateJSNavTree(const QList<FTVNode> &nodeList)
     //tidx << "var NAVTREEINDEX =" << endl;
     //tidx << "{" << endl;
     FTextStream t(&f);
+    t << JAVASCRIPT_LICENSE_TEXT;
     t << "var NAVTREE =" << endl;
     t << "[" << endl;
     t << "  [ ";
     QCString &projName = Config_getString(PROJECT_NAME);
     if (projName.isEmpty())
     {
-      if (Doxygen::mainPage && !Doxygen::mainPage->title().isEmpty()) // Use title of main page as root
+      if (mainPageHasTitle()) // Use title of main page as root
       {
         t << "\"" << convertToJSString(Doxygen::mainPage->title()) << "\", ";
       }
@@ -618,9 +666,9 @@ static void generateJSNavTree(const QList<FTVNode> &nodeList)
     bool first=TRUE;
     generateJSTree(navIndex,t,nodeList,1,first);
 
-    if (first) 
+    if (first)
       t << "]" << endl;
-    else 
+    else
       t << endl << "  ] ]" << endl;
     t << "];" << endl << endl;
 
@@ -660,7 +708,7 @@ static void generateJSNavTree(const QList<FTVNode> &nodeList)
         ++li;
         if (li.current() && elemCount<maxElemCount-1) tsidx << ","; // not last entry
         tsidx << endl;
-  
+
         elemCount++;
         if (li.current() && elemCount>=maxElemCount) // switch to new sub-index
         {
@@ -678,8 +726,8 @@ static void generateJSNavTree(const QList<FTVNode> &nodeList)
       tsidx << "};" << endl;
       t << endl << "];" << endl;
     }
-    t << endl << "var SYNCONMSG = '"  << theTranslator->trPanelSynchronisationTooltip(FALSE) << "';"; 
-    t << endl << "var SYNCOFFMSG = '" << theTranslator->trPanelSynchronisationTooltip(TRUE)  << "';"; 
+    t << endl << "var SYNCONMSG = '"  << theTranslator->trPanelSynchronisationTooltip(FALSE) << "';";
+    t << endl << "var SYNCOFFMSG = '" << theTranslator->trPanelSynchronisationTooltip(TRUE)  << "';";
   }
   ResourceMgr::instance().copyResource("navtree.js",htmlOutput);
 }
@@ -731,7 +779,7 @@ void FTVHelp::generateTreeViewInline(FTextStream &t)
   if (depth>1)
   {
     t << "<div class=\"levels\">[";
-    t << theTranslator->trDetailLevel(); 
+    t << theTranslator->trDetailLevel();
     t << " ";
     int i;
     for (i=1;i<=depth;i++)
@@ -765,10 +813,13 @@ void FTVHelp::generateTreeViewInline(FTextStream &t)
   }
   //printf("preferred depth=%d\n",preferredDepth);
 
-  t << "<table class=\"directory\">\n";
-  int index=0;
-  generateTree(t,m_indentNodes[0],0,preferredDepth,index);
-  t << "</table>\n";
+  if (m_indentNodes[0].count())
+  {
+    t << "<table class=\"directory\">\n";
+    int index=0;
+    generateTree(t,m_indentNodes[0],0,preferredDepth,index);
+    t << "</table>\n";
+  }
 
   t << "</div><!-- directory -->\n";
 }
@@ -779,4 +830,3 @@ void FTVHelp::generateTreeView()
   generateTreeViewImages();
   generateTreeViewScripts();
 }
-
