@@ -11,11 +11,21 @@ class GrowBuf
 {
   public:
     GrowBuf() : str(0), pos(0), len(0) {}
+    GrowBuf(int initialSize) : pos(0), len(initialSize) { str=(char*)malloc(len); }
    ~GrowBuf()         { free(str); str=0; pos=0; len=0; }
     void clear()      { pos=0; }
     void addChar(char c)  { if (pos>=len) { len+=GROW_AMOUNT; str = (char*)realloc(str,len); } 
                         str[pos++]=c; 
                       }
+    void addStr(const QCString &s) {
+                        if (!s.isEmpty())
+                        {
+                          int l=s.length();
+                          if (pos+l>=len) { len+=l+GROW_AMOUNT; str = (char*)realloc(str,len); }
+                          strcpy(&str[pos],s.data());
+                          pos+=l;
+                        }
+                      }
     void addStr(const char *s) {
                         if (s)
                         {
@@ -37,6 +47,7 @@ class GrowBuf
                       }
     const char *get()     { return str; }
     int getPos() const    { return pos; }
+    void setPos(const int newPos) { pos = newPos; }
     char at(int i) const  { return str[i]; }
   private:
     char *str;
