@@ -52,7 +52,7 @@ class HtmlCodeGenerator : public CodeOutputInterface
     void startFontClass(const char *s);
     void endFontClass();
     void writeCodeAnchor(const char *anchor);
-    void setCurrentDoc(Definition *,const char *,bool) {}
+    void setCurrentDoc(const Definition *,const char *,bool) {}
     void addWord(const char *,bool) {}
 
   private:
@@ -86,12 +86,12 @@ class HtmlGenerator : public OutputGenerator
     static QCString writeSplitBarAsString(const char *name,const char *relpath);
    
     void enable() 
-    { if (genStack->top()) active=*genStack->top(); else active=TRUE; }
-    void disable() { active=FALSE; }
+    { if (m_genStack->top()) m_active=*m_genStack->top(); else m_active=TRUE; }
+    void disable() { m_active=FALSE; }
     void enableIf(OutputType o)  { if (o==Html) enable();  }
     void disableIf(OutputType o) { if (o==Html) disable(); }
     void disableIfNot(OutputType o) { if (o!=Html) disable(); }
-    bool isEnabled(OutputType o) { return (o==Html && active); } 
+    bool isEnabled(OutputType o) { return (o==Html && m_active); } 
     OutputGenerator *get(OutputType o) { return (o==Html) ? this : 0; }
 
     // ---- CodeOutputInterface
@@ -119,9 +119,9 @@ class HtmlGenerator : public OutputGenerator
     { m_codeGen.writeCodeAnchor(anchor); }
     // ---------------------------
 
-    void setCurrentDoc(Definition *context,const char *anchor,bool isSourceFile);
+    void setCurrentDoc(const Definition *context,const char *anchor,bool isSourceFile);
     void addWord(const char *word,bool hiPriority);
-    void writeDoc(DocNode *,Definition *,MemberDef *);
+    void writeDoc(DocNode *,const Definition *,const MemberDef *);
 
     void startFile(const char *name,const char *manName,const char *title);
     void writeFooter(const char *navPath);
@@ -175,7 +175,7 @@ class HtmlGenerator : public OutputGenerator
     void endMemberSections();
     void startHeaderSection();
     void endHeaderSection();
-    void startMemberHeader(const char *);
+    void startMemberHeader(const char *, int);
     void endMemberHeader();
     void startMemberSubtitle();
     void endMemberSubtitle();
@@ -200,7 +200,8 @@ class HtmlGenerator : public OutputGenerator
     void endMemberGroup(bool);
 
     void insertMemberAlign(bool);
-    void startMemberDescription(const char *anchor,const char *inheritId);
+    void insertMemberAlignLeft(int,bool);
+    void startMemberDescription(const char *anchor,const char *inheritId, bool typ);
     void endMemberDescription();
     void startMemberDeclaration() {}
     void endMemberDeclaration(const char *anchor,const char *inheritId);
@@ -211,8 +212,8 @@ class HtmlGenerator : public OutputGenerator
     void writeRuler()    { t << "<hr/>"; }
     void writeAnchor(const char *,const char *name) 
                          { t << "<a name=\"" << name <<"\" id=\"" << name << "\"></a>"; }
-    void startCodeFragment() { t << PREFRAG_START; }
-    void endCodeFragment()   { t << PREFRAG_END; } 
+    void startCodeFragment();
+    void endCodeFragment();
     void startEmphasis() { t << "<em>";  }
     void endEmphasis()   { t << "</em>"; }
     void startBold()     { t << "<b>"; }
@@ -245,13 +246,10 @@ class HtmlGenerator : public OutputGenerator
     void endCenter()          { t << "</center>" << endl; }
     void startSmall()         { t << "<small>" << endl; }
     void endSmall()           { t << "</small>" << endl; }
-    //void startDescList(SectionTypes)      { t << "<dl compact><dt><b>" << endl; }
-    //void endDescList()        { t << "</dl>"; }
-    void startSimpleSect(SectionTypes,const char *,const char *,const char *);
-    void endSimpleSect();
+    void startExamples();
+    void endExamples();
     void startParamList(ParamListTypes,const char *);
     void endParamList();
-    //void writeDescItem()      { t << "<dd>" << endl; }
     void startSection(const char *,const char *,SectionInfo::SectionType);
     void endSection(const char *,SectionInfo::SectionType);
     void addIndexItem(const char *,const char *);
@@ -271,6 +269,8 @@ class HtmlGenerator : public OutputGenerator
     void writeSummaryLink(const char *file,const char *anchor,const char *title,bool first);
     void startContents();
     void endContents();
+    void startPageDoc(const char *pageTitle);
+    void endPageDoc();
     void writeNonBreakableSpace(int);
 
     void startDescTable(const char *title);
@@ -283,16 +283,16 @@ class HtmlGenerator : public OutputGenerator
     void endDescTableData();
 
     void startDotGraph();
-    void endDotGraph(const DotClassGraph &g);
+    void endDotGraph(DotClassGraph &g);
     void startInclDepGraph();
-    void endInclDepGraph(const DotInclDepGraph &g);
+    void endInclDepGraph(DotInclDepGraph &g);
     void startGroupCollaboration();
-    void endGroupCollaboration(const DotGroupCollaboration &g);
+    void endGroupCollaboration(DotGroupCollaboration &g);
     void startCallGraph();
-    void endCallGraph(const DotCallGraph &g);
+    void endCallGraph(DotCallGraph &g);
     void startDirDepGraph();
-    void endDirDepGraph(const DotDirDeps &g);
-    void writeGraphicalHierarchy(const DotGfxHierarchyTable &g);
+    void endDirDepGraph(DotDirDeps &g);
+    void writeGraphicalHierarchy(DotGfxHierarchyTable &g);
 
     void startTextBlock(bool) 
     { t << "<div class=\"textblock\">"; }
@@ -339,9 +339,9 @@ class HtmlGenerator : public OutputGenerator
 
   private:
     static void writePageFooter(FTextStream &t,const QCString &,const QCString &,const QCString &);
-    QCString lastTitle;
-    QCString lastFile;
-    QCString relPath;
+    QCString m_lastTitle;
+    QCString m_lastFile;
+    QCString m_relPath;
     void docify(const char *text,bool inHtmlComment);
 
     HtmlGenerator &operator=(const HtmlGenerator &g);
