@@ -93,7 +93,7 @@ HtmlHelpIndex::~HtmlHelpIndex()
 }
 
 /*! Stores an item in the index if it is not already present. 
- *  Items are stored in alphetical order, by sorting on the
+ *  Items are stored in alphabetical order, by sorting on the
  *  concatenation of \a level1 and \a level2 (if present).
  *
  *  \param level1 the string at level 1 in the index.
@@ -115,7 +115,7 @@ void HtmlHelpIndex::addItem(const char *level1,const char *level2,
   {
     return;
   }
-  if (dict->find(key)==0) // new key
+  if (dict->find(key+anchor)==0) // new key
   {
     //printf(">>>>>>>>> HtmlHelpIndex::addItem(%s,%s,%s,%s)\n",
     //      level1,level2,url,anchor);
@@ -125,7 +125,7 @@ void HtmlHelpIndex::addItem(const char *level1,const char *level2,
     f->anchor   = anchor;
     f->link     = hasLink;
     f->reversed = reversed;
-    dict->append(key,f);
+    dict->append(key+anchor,f);
   }
 }
 
@@ -134,7 +134,8 @@ static QCString field2URL(const IndexField *f,bool checkReversed)
   QCString result = f->url + Doxygen::htmlFileExtension;
   if (!f->anchor.isEmpty() && (!checkReversed || f->reversed)) 
   {
-    result+="#"+f->anchor;  
+    // HTML Help needs colons in link anchors to be escaped in the .hhk file.
+    result+="#"+substitute(f->anchor,":","%3A");
   }
   return result;
 }
@@ -186,11 +187,11 @@ void HtmlHelpIndex::writeFields(FTextStream &t)
       level1  = f->name.copy();
     }
 
-    if (level1!=lastLevel1)
+    //if (level1!=lastLevel1)
     { // finish old list at level 2
       if (level2Started) t << "  </UL>" << endl;
       level2Started=FALSE;
-    
+
       // <Antony>
       // Added this code so that an item with only one subitem is written
       // without any subitem.
@@ -214,7 +215,7 @@ void HtmlHelpIndex::writeFields(FTextStream &t)
       if (level2.isEmpty())
       {
         t << "  <LI><OBJECT type=\"text/sitemap\">";
-        t << "<param name=\"Local\" value=\"" << field2URL(f,TRUE);
+        t << "<param name=\"Local\" value=\"" << field2URL(f,FALSE);
         t << "\">";
         t << "<param name=\"Name\" value=\"" << m_help->recode(level1) << "\">"
            "</OBJECT>\n";
@@ -302,22 +303,20 @@ static QDict<QCString> s_languageDict;
  */
 void HtmlHelp::initialize()
 {
-  const char *str = Config_getString("CHM_INDEX_ENCODING");
+  const char *str = Config_getString(CHM_INDEX_ENCODING);
   if (!str) str = "CP1250"; // use safe and likely default
   m_fromUtf8 = portable_iconv_open(str,"UTF-8"); 
   if (m_fromUtf8==(void *)(-1))
   {
-    err("unsupported character conversion for CHM_INDEX_ENCODING: '%s'->'UTF-8'\n", str);
-    exit(1);
+    term("unsupported character conversion for CHM_INDEX_ENCODING: '%s'->'UTF-8'\n", str);
   }
 
   /* open the contents file */
-  QCString fName = Config_getString("HTML_OUTPUT") + "/index.hhc";
+  QCString fName = Config_getString(HTML_OUTPUT) + "/index.hhc";
   cf = new QFile(fName);
   if (!cf->open(IO_WriteOnly))
   {
-    err("Could not open file %s for writing\n",fName.data());
-    exit(1);
+    term("Could not open file %s for writing\n",fName.data());
   }
   /* Write the header of the contents file */
   cts.setDevice(cf);
@@ -329,12 +328,11 @@ void HtmlHelp::initialize()
          "<UL>\n";
   
   /* open the contents file */
-  fName = Config_getString("HTML_OUTPUT") + "/index.hhk";
+  fName = Config_getString(HTML_OUTPUT) + "/index.hhk";
   kf = new QFile(fName);
   if (!kf->open(IO_WriteOnly))
   {
-    err("Could not open file %s for writing\n",fName.data());
-    exit(1);
+    term("Could not open file %s for writing\n",fName.data());
   }
   /* Write the header of the contents file */
   kts.setDevice(kf);
@@ -446,7 +444,7 @@ void HtmlHelp::initialize()
 }
 
 
-static QCString getLanguageString()
+QCString HtmlHelp::getLanguageString()
 {
   if (!theTranslator->idLanguage().isEmpty())
   {
@@ -465,7 +463,7 @@ static QCString getLanguageString()
 void HtmlHelp::createProjectFile()
 {
   /* Write the project file */
-  QCString fName = Config_getString("HTML_OUTPUT") + "/index.hhp";
+  QCString fName = Config_getString(HTML_OUTPUT) + "/index.hhp";
   QFile f(fName);
   if (f.open(IO_WriteOnly))
   {
@@ -473,9 +471,9 @@ void HtmlHelp::createProjectFile()
     
     QCString indexName="index"+Doxygen::htmlFileExtension;
     t << "[OPTIONS]\n";
-    if (!Config_getString("CHM_FILE").isEmpty())
+    if (!Config_getString(CHM_FILE).isEmpty())
     {
-      t << "Compiled file=" << Config_getString("CHM_FILE") << "\n";
+      t << "Compiled file=" << Config_getString(CHM_FILE) << "\n";
     }
     t << "Compatibility=1.1\n"
          "Full-text search=Yes\n"
@@ -484,9 +482,9 @@ void HtmlHelp::createProjectFile()
          "Default topic=" << indexName << "\n"
          "Index file=index.hhk\n"
          "Language=" << getLanguageString() << endl;
-    if (Config_getBool("BINARY_TOC")) t << "Binary TOC=YES\n";
-    if (Config_getBool("GENERATE_CHI")) t << "Create CHI file=YES\n";
-    t << "Title=" << recode(Config_getString("PROJECT_NAME")) << endl << endl;
+    if (Config_getBool(BINARY_TOC)) t << "Binary TOC=YES\n";
+    if (Config_getBool(GENERATE_CHI)) t << "Create CHI file=YES\n";
+    t << "Title=" << recode(Config_getString(PROJECT_NAME)) << endl << endl;
     
     t << "[WINDOWS]" << endl;
 
@@ -500,15 +498,15 @@ void HtmlHelp::createProjectFile()
     //       are shown. They can only be shown in case of a binary toc.
     //          dee http://www.mif2go.com/xhtml/htmlhelp_0016_943addingtabsandtoolbarbuttonstohtmlhelp.htm#Rz108x95873
     //       Value has been taken from htmlhelp.h file of the HTML Help Workshop
-    if (Config_getBool("BINARY_TOC"))
+    if (Config_getBool(BINARY_TOC))
     {
-      t << "main=\"" << recode(Config_getString("PROJECT_NAME")) << "\",\"index.hhc\","
+      t << "main=\"" << recode(Config_getString(PROJECT_NAME)) << "\",\"index.hhc\","
          "\"index.hhk\",\"" << indexName << "\",\"" << 
          indexName << "\",,,,,0x23520,,0x70387e,,,,,,,,0" << endl << endl;
     }
     else
     {
-      t << "main=\"" << recode(Config_getString("PROJECT_NAME")) << "\",\"index.hhc\","
+      t << "main=\"" << recode(Config_getString(PROJECT_NAME)) << "\",\"index.hhc\","
          "\"index.hhk\",\"" << indexName << "\",\"" << 
          indexName << "\",,,,,0x23520,,0x10387e,,,,,,,,0" << endl << endl;
     }
@@ -631,13 +629,13 @@ void HtmlHelp::addContentsItem(bool isDir,
                                const char *anchor,
                                bool /* separateIndex */,
                                bool /* addToNavIndex */,
-                               Definition * /* def */)
+                               const Definition * /* def */)
 {
   // If we're using a binary toc then folders cannot have links. 
   // Tried this and I didn't see any problems, when not using
   // the resetting of file and anchor the TOC works better
   // (prev / next button)
-  //if(Config_getBool("BINARY_TOC") && isDir) 
+  //if(Config_getBool(BINARY_TOC) && isDir) 
   //{
     //file = 0;
     //anchor = 0;
@@ -676,12 +674,12 @@ void HtmlHelp::addContentsItem(bool isDir,
 }
 
 
-void HtmlHelp::addIndexItem(Definition *context,MemberDef *md,
+void HtmlHelp::addIndexItem(const Definition *context,const MemberDef *md,
                             const char *sectionAnchor,const char *word)
 {
   if (md)
   {
-    static bool separateMemberPages = Config_getBool("SEPARATE_MEMBER_PAGES");
+    static bool separateMemberPages = Config_getBool(SEPARATE_MEMBER_PAGES);
     if (context==0) // global member
     {
       if (md->getGroupDef())
