@@ -18,6 +18,7 @@
 #include "htmlattrib.h"
 #include <qfileinfo.h> 
 #include "latexdocvisitor.h"
+#include "latexgen.h"
 #include "docparser.h"
 #include "language.h"
 #include "doxygen.h"
@@ -32,11 +33,12 @@
 #include "filedef.h"
 #include "config.h"
 #include "htmlentity.h"
+#include "emoji.h"
 #include "plantuml.h"
 
 const int maxLevels=5;
 static const char *secLabels[maxLevels] = 
-   { "section","subsection","subsubsection","paragraph","subparagraph" };
+   { "doxysection","doxysubsection","doxysubsubsection","doxyparagraph","doxysubparagraph" };
 
 static const char *getSectionName(int level)
 {
@@ -47,16 +49,23 @@ static const char *getSectionName(int level)
   return secLabels[QMIN(maxLevels-1,l)];
 }
 
-static void visitPreStart(FTextStream &t, const bool hasCaption, QCString name,  QCString width,  QCString height)
+static void visitPreStart(FTextStream &t, bool hasCaption, QCString name,  QCString width,  QCString height, bool inlineImage = FALSE)
 {
-    if (hasCaption)
+    if (inlineImage)
     {
-      t << "\n\\begin{DoxyImage}\n";
+      t << "\n\\begin{DoxyInlineImage}\n";
     }
     else
     {
-      t << "\n\\begin{DoxyImageNoCaption}\n"
-             "  \\mbox{";
+      if (hasCaption)
+      {
+        t << "\n\\begin{DoxyImage}\n";
+      }
+      else
+      {
+        t << "\n\\begin{DoxyImageNoCaption}\n"
+               "  \\mbox{";
+      }
     }
 
     t << "\\includegraphics";
@@ -79,7 +88,14 @@ static void visitPreStart(FTextStream &t, const bool hasCaption, QCString name,
     if (width.isEmpty() && height.isEmpty())
     {
       /* default setting */
-      t << "[width=\\textwidth,height=\\textheight/2,keepaspectratio=true]";
+      if (inlineImage)
+      {
+        t << "[height=\\baselineskip,keepaspectratio=true]";
+      }
+      else
+      {
+        t << "[width=\\textwidth,height=\\textheight/2,keepaspectratio=true]";
+      }
     }
     else
     {
@@ -90,21 +106,36 @@ static void visitPreStart(FTextStream &t, const bool hasCaption, QCString name,
 
     if (hasCaption)
     {
-      t << "\n\\doxyfigcaption{";
+      if (!inlineImage)
+      {
+        t << "\n\\doxyfigcaption{";
+      }
+      else
+      {
+        t << "%"; // to catch the caption
+      }
     }
 }
 
 
 
-static void visitPostEnd(FTextStream &t, const bool hasCaption)
+static void visitPostEnd(FTextStream &t, bool hasCaption, bool inlineImage = FALSE)
 {
-    t << "}\n"; // end mbox or caption
-    if (hasCaption)
+    if (inlineImage)
     {
-      t << "\\end{DoxyImage}\n";
+      t << "\n\\end{DoxyInlineImage}\n";
     }
-    else{
-      t << "\\end{DoxyImageNoCaption}\n";
+    else
+    {
+      t << "}\n"; // end mbox or caption
+      if (hasCaption)
+      {
+        t << "\\end{DoxyImage}\n";
+      }
+      else
+      {
+        t << "\\end{DoxyImageNoCaption}\n";
+      }
     }
 }
 
@@ -209,6 +240,23 @@ void LatexDocVisitor::visit(DocSymbol *s)
   }
 }
 
+void LatexDocVisitor::visit(DocEmoji *s)
+{
+  if (m_hide) return;
+  QCString emojiName = EmojiEntityMapper::instance()->name(s->index());
+  if (!emojiName.isEmpty())
+  {
+    QCString imageName=emojiName.mid(1,emojiName.length()-2); // strip : at start and end
+    m_t << "\\doxygenemoji{";
+    filter(emojiName);
+    m_t << "}{" << imageName << "}";
+  }
+  else
+  {
+    m_t << s->name();
+  }
+}
+
 void LatexDocVisitor::visit(DocURL *u)
 {
   if (m_hide) return;
@@ -216,11 +264,11 @@ void LatexDocVisitor::visit(DocURL *u)
   {
     m_t << "\\href{";
     if (u->isEmail()) m_t << "mailto:";
-    m_t << u->url() << "}";
+    m_t << latexFilterURL(u->url()) << "}";
   }
-  m_t << "{\\tt ";
+  m_t << "{\\texttt{ ";
   filter(u->url());
-  m_t << "}";
+  m_t << "}}";
 }
 
 void LatexDocVisitor::visit(DocLineBreak *)
@@ -232,7 +280,10 @@ void LatexDocVisitor::visit(DocLineBreak *)
 void LatexDocVisitor::visit(DocHorRuler *)
 {
   if (m_hide) return;
-  m_t << "\n\n";
+  if (insideTable())
+    m_t << "\\DoxyHorRuler{1}\n";
+  else
+    m_t << "\\DoxyHorRuler{0}\n";
 }
 
 void LatexDocVisitor::visit(DocStyleChange *s)
@@ -241,7 +292,16 @@ void LatexDocVisitor::visit(DocStyleChange *s)
   switch (s->style())
   {
     case DocStyleChange::Bold:
-      if (s->enable()) m_t << "{\\bfseries ";      else m_t << "}";
+      if (s->enable()) m_t << "{\\bfseries{";      else m_t << "}}";
+      break;
+    case DocStyleChange::S:
+    case DocStyleChange::Strike:
+    case DocStyleChange::Del:
+      if (s->enable()) m_t << "\\sout{";     else m_t << "}";
+      break;
+    case DocStyleChange::Underline:
+    case DocStyleChange::Ins:
+      if (s->enable()) m_t << "\\uline{";     else m_t << "}";
       break;
     case DocStyleChange::Italic:
       if (s->enable()) m_t << "{\\itshape ";     else m_t << "}";
@@ -291,10 +351,12 @@ void LatexDocVisitor::visit(DocVerbatim *s)
   {
     case DocVerbatim::Code: 
       {
-        m_t << "\n\\begin{DoxyCode}\n";
-        Doxygen::parserManager->getParser(lang)
-                              ->parseCode(m_ci,s->context(),s->text(),langExt,
+        m_t << "\n\\begin{DoxyCode}{" << usedTableLevels() << "}\n";
+	LatexCodeGenerator::setDoxyCodeOpen(TRUE);
+        Doxygen::parserManager->getCodeParser(lang)
+                               .parseCode(m_ci,s->context(),s->text(),langExt,
                                           s->isExample(),s->exampleFile());
+	LatexCodeGenerator::setDoxyCodeOpen(FALSE);
         m_t << "\\end{DoxyCode}\n";
       }
       break;
@@ -372,7 +434,7 @@ void LatexDocVisitor::visit(DocVerbatim *s)
     case DocVerbatim::PlantUML: 
       {
         QCString latexOutput = Config_getString(LATEX_OUTPUT);
-        QCString baseName = writePlantUMLSource(latexOutput,s->exampleFile(),s->text());
+        QCString baseName = PlantumlManager::instance()->writePlantUMLSource(latexOutput,s->exampleFile(),s->text(),PlantumlManager::PUML_EPS);
 
         writePlantUMLFile(baseName, s);
       }
@@ -399,29 +461,33 @@ void LatexDocVisitor::visit(DocInclude *inc)
   {
     case DocInclude::IncWithLines:
       { 
-         m_t << "\n\\begin{DoxyCodeInclude}\n";
+         m_t << "\n\\begin{DoxyCodeInclude}{" << usedTableLevels() << "}\n";
+	 LatexCodeGenerator::setDoxyCodeOpen(TRUE);
          QFileInfo cfi( inc->file() );
-         FileDef fd( cfi.dirPath().utf8(), cfi.fileName().utf8() );
-         Doxygen::parserManager->getParser(inc->extension())
-                               ->parseCode(m_ci,inc->context(),
+         FileDef *fd = createFileDef( cfi.dirPath().utf8(), cfi.fileName().utf8() );
+         Doxygen::parserManager->getCodeParser(inc->extension())
+                                .parseCode(m_ci,inc->context(),
                                            inc->text(),
                                            langExt,
                                            inc->isExample(),
                                            inc->exampleFile(),
-                                           &fd,   // fileDef,
+                                           fd,   // fileDef,
                                            -1,    // start line
                                            -1,    // end line
                                            FALSE, // inline fragment
                                            0,     // memberDef
                                            TRUE   // show line numbers
 					  );
+         delete fd;
+	 LatexCodeGenerator::setDoxyCodeOpen(FALSE);
          m_t << "\\end{DoxyCodeInclude}" << endl;
       }
       break;    
     case DocInclude::Include: 
-      m_t << "\n\\begin{DoxyCodeInclude}\n";
-      Doxygen::parserManager->getParser(inc->extension())
-                            ->parseCode(m_ci,inc->context(),
+      m_t << "\n\\begin{DoxyCodeInclude}{" << usedTableLevels() << "}\n";
+      LatexCodeGenerator::setDoxyCodeOpen(TRUE);
+      Doxygen::parserManager->getCodeParser(inc->extension())
+                             .parseCode(m_ci,inc->context(),
                                         inc->text(),langExt,inc->isExample(),
                                         inc->exampleFile(),
                                         0,     // fileDef
@@ -431,11 +497,12 @@ void LatexDocVisitor::visit(DocInclude *inc)
                                         0,     // memberDef
                                         FALSE
 			  		);
+      LatexCodeGenerator::setDoxyCodeOpen(FALSE);
       m_t << "\\end{DoxyCodeInclude}\n";
       break;
-    case DocInclude::DontInclude: 
-      break;
-    case DocInclude::HtmlInclude: 
+    case DocInclude::DontInclude:
+    case DocInclude::DontIncWithLines:
+    case DocInclude::HtmlInclude:
       break;
     case DocInclude::LatexInclude:
       m_t << inc->text();
@@ -447,37 +514,42 @@ void LatexDocVisitor::visit(DocInclude *inc)
       break;
     case DocInclude::Snippet:
       {
-         m_t << "\n\\begin{DoxyCodeInclude}\n";
-         Doxygen::parserManager->getParser(inc->extension())
-                               ->parseCode(m_ci,
+         m_t << "\n\\begin{DoxyCodeInclude}{" << usedTableLevels() << "}\n";
+         LatexCodeGenerator::setDoxyCodeOpen(TRUE);
+         Doxygen::parserManager->getCodeParser(inc->extension())
+                                .parseCode(m_ci,
                                            inc->context(),
                                            extractBlock(inc->text(),inc->blockId()),
                                            langExt,
                                            inc->isExample(),
                                            inc->exampleFile()
                                           );
+         LatexCodeGenerator::setDoxyCodeOpen(FALSE);
          m_t << "\\end{DoxyCodeInclude}" << endl;
       }
       break;
     case DocInclude::SnipWithLines:
       {
          QFileInfo cfi( inc->file() );
-         FileDef fd( cfi.dirPath().utf8(), cfi.fileName().utf8() );
-         m_t << "\n\\begin{DoxyCodeInclude}\n";
-         Doxygen::parserManager->getParser(inc->extension())
-                               ->parseCode(m_ci,
+         FileDef *fd = createFileDef( cfi.dirPath().utf8(), cfi.fileName().utf8() );
+         m_t << "\n\\begin{DoxyCodeInclude}{" << usedTableLevels() << "}\n";
+         LatexCodeGenerator::setDoxyCodeOpen(TRUE);
+         Doxygen::parserManager->getCodeParser(inc->extension())
+                                .parseCode(m_ci,
                                            inc->context(),
                                            extractBlock(inc->text(),inc->blockId()),
                                            langExt,
                                            inc->isExample(),
                                            inc->exampleFile(), 
-                                           &fd,
+                                           fd,
                                            lineBlock(inc->text(),inc->blockId()),
                                            -1,    // endLine
                                            FALSE, // inlineFragment
                                            0,     // memberDef
                                            TRUE   // show line number
                                           );
+         delete fd;
+         LatexCodeGenerator::setDoxyCodeOpen(FALSE);
          m_t << "\\end{DoxyCodeInclude}" << endl;
       }
       break;
@@ -491,23 +563,41 @@ void LatexDocVisitor::visit(DocInclude *inc)
 
 void LatexDocVisitor::visit(DocIncOperator *op)
 {
-  //printf("DocIncOperator: type=%d first=%d, last=%d text=`%s'\n",
+  //printf("DocIncOperator: type=%d first=%d, last=%d text='%s'\n",
   //    op->type(),op->isFirst(),op->isLast(),op->text().data());
   if (op->isFirst()) 
   {
-    if (!m_hide) m_t << "\n\\begin{DoxyCodeInclude}\n";
+    if (!m_hide) m_t << "\n\\begin{DoxyCodeInclude}{" << usedTableLevels() << "}\n";
+    LatexCodeGenerator::setDoxyCodeOpen(TRUE);
     pushEnabled();
     m_hide = TRUE;
   }
-  SrcLangExt langExt = getLanguageFromFileName(m_langExt);
+  QCString locLangExt = getFileNameExtension(op->includeFileName());
+  if (locLangExt.isEmpty()) locLangExt = m_langExt;
+  SrcLangExt langExt = getLanguageFromFileName(locLangExt);
   if (op->type()!=DocIncOperator::Skip) 
   {
     popEnabled();
     if (!m_hide) 
     {
-      Doxygen::parserManager->getParser(m_langExt)
-                            ->parseCode(m_ci,op->context(),op->text(),langExt,
-                                        op->isExample(),op->exampleFile());
+      FileDef *fd = 0;
+      if (!op->includeFileName().isEmpty())
+      {
+        QFileInfo cfi( op->includeFileName() );
+        fd = createFileDef( cfi.dirPath().utf8(), cfi.fileName().utf8() );
+      }
+
+      Doxygen::parserManager->getCodeParser(locLangExt)
+                             .parseCode(m_ci,op->context(),op->text(),langExt,
+                                        op->isExample(),op->exampleFile(),
+                                        fd,     // fileDef
+                                        op->line(),    // startLine
+                                        -1,    // endLine
+                                        FALSE, // inline fragment
+                                        0,     // memberDef
+                                        op->showLineNo()  // show line numbers
+                                       );
+      if (fd) delete fd;
     }
     pushEnabled();
     m_hide=TRUE;
@@ -515,6 +605,7 @@ void LatexDocVisitor::visit(DocIncOperator *op)
   if (op->isLast())  
   {
     popEnabled();
+    LatexCodeGenerator::setDoxyCodeOpen(FALSE);
     if (!m_hide) m_t << "\n\\end{DoxyCodeInclude}\n";
   }
   else
@@ -526,16 +617,28 @@ void LatexDocVisitor::visit(DocIncOperator *op)
 void LatexDocVisitor::visit(DocFormula *f)
 {
   if (m_hide) return;
-  m_t << f->text();
+  const char *p=f->text();
+  char c;
+  if (p)
+  {
+    while ((c=*p++))
+    {
+      switch (c)
+      {
+        case '\'': m_t << "\\textnormal{\\textquotesingle}"; break;
+        default:  m_t << c; break;
+      }
+    }
+  }
 }
 
 void LatexDocVisitor::visit(DocIndexEntry *i)
 {
   if (m_hide) return;
   m_t << "\\index{";
-  m_t << latexEscapeLabelName(i->entry(),false);
+  m_t << latexEscapeLabelName(i->entry());
   m_t << "@{";
-  m_t << latexEscapeIndexChars(i->entry(),false);
+  m_t << latexEscapeIndexChars(i->entry());
   m_t << "}}";
 }
 
@@ -923,11 +1026,11 @@ static void writeStartTableCommand(FTextStream &t,const DocNode *n,int cols)
 {
   if (tableIsNested(n))
   {
-    t << "\\begin{tabularx}{\\linewidth}{|*{" << cols << "}{>{\\raggedright\\arraybackslash}X|}}";
+    t << "{\\begin{tabularx}{\\linewidth}{|*{" << cols << "}{>{\\raggedright\\arraybackslash}X|}}";
   }
   else
   {
-    t << "\\tabulinesep=1mm\n\\begin{longtabu} spread 0pt [c]{*{" << cols << "}{|X[-1]}|}\n";
+    t << "\\tabulinesep=1mm\n\\begin{longtabu}spread 0pt [c]{*{" << cols << "}{|X[-1]}|}\n";
   }
   //return isNested ? "TabularNC" : "TabularC";
 }
@@ -936,7 +1039,7 @@ static void writeEndTableCommand(FTextStream &t,const DocNode *n)
 {
   if (tableIsNested(n))
   {
-    t << "\\end{tabularx}\n";
+    t << "\\end{tabularx}}\n";
   }
   else
   {
@@ -983,7 +1086,8 @@ void LatexDocVisitor::visitPre(DocHtmlTable *t)
   if (firstRow && firstRow->isHeading())
   {
     setFirstRow(TRUE);
-    firstRow->accept(this);
+    DocNode *n = t->parent();
+    if (!tableIsNested(n)) firstRow->accept(this);
     setFirstRow(FALSE);
   }
 }
@@ -1009,13 +1113,14 @@ void LatexDocVisitor::visitPost(DocHtmlCaption *c)
 void LatexDocVisitor::visitPre(DocHtmlRow *r)
 {
   setCurrentColumn(0);
-  if (r->isHeading()) m_t << "\\rowcolor{\\tableheadbgcolor}";
 }
 
 void LatexDocVisitor::visitPost(DocHtmlRow *row) 
 {
   if (m_hide) return;
 
+  DocNode *n = row->parent() ->parent();
+
   int c=currentColumn();
   while (c<=numCols()) // end of row while inside a row span?
   {
@@ -1033,10 +1138,7 @@ void LatexDocVisitor::visitPost(DocHtmlRow *row)
         if (span->colSpan>1) // row span is also part of a column span
         {
           m_t << "\\multicolumn{" << span->colSpan << "}{";
-          m_t << "p{(\\linewidth-\\tabcolsep*" 
-            << numCols() << "-\\arrayrulewidth*"
-            << row->visibleCells() << ")*" 
-            << span->colSpan <<"/"<< numCols() << "}|}{}";
+          m_t <<  "}|}{}";
         }
         else // solitary row span
         {
@@ -1077,7 +1179,8 @@ void LatexDocVisitor::visitPost(DocHtmlRow *row)
 
   m_t << "\n";
 
-  if (row->isHeading() && row->rowIndex()==1)
+
+  if (row->isHeading() && row->rowIndex()==1 && !tableIsNested(n))
   {
     if (firstRow())
     {
@@ -1119,10 +1222,7 @@ void LatexDocVisitor::visitPre(DocHtmlCell *c)
         {
           m_t << "|";
         }
-        m_t << "p{(\\linewidth-\\tabcolsep*" 
-            << numCols() << "-\\arrayrulewidth*"
-            << row->visibleCells() << ")*" 
-            << span->colSpan <<"/"<< numCols() << "}|}{}";
+        m_t << "l|}{" << (c->isHeading()? "\\columncolor{\\tableheadbgcolor}" : "") << "}"; // alignment not relevant, empty column
         setCurrentColumn(currentColumn()+span->colSpan);
       }
       else
@@ -1134,6 +1234,7 @@ void LatexDocVisitor::visitPre(DocHtmlCell *c)
   }
 
   int cs = c->colSpan();
+  int a = c->alignment();
   if (cs>1 && row)
   {
     setInColSpan(TRUE);
@@ -1142,11 +1243,18 @@ void LatexDocVisitor::visitPre(DocHtmlCell *c)
     {
       m_t << "|";
     }
-    m_t << "p{(\\linewidth-\\tabcolsep*" 
-        << numCols() << "-\\arrayrulewidth*"
-        << row->visibleCells() << ")*" 
-        << cs <<"/"<< numCols() << "}|}{";
-    if (c->isHeading()) m_t << "\\cellcolor{\\tableheadbgcolor}";
+    switch (a)
+    {
+      case DocHtmlCell::Right:
+        m_t << "r|}{";
+        break;
+      case DocHtmlCell::Center:
+        m_t << "c|}{";
+        break;
+      default:
+        m_t << "l|}{";
+        break;
+    }
   }
   int rs = c->rowSpan();
   if (rs>0)
@@ -1156,9 +1264,8 @@ void LatexDocVisitor::visitPre(DocHtmlCell *c)
     //                       c->rowIndex(),c->columnIndex(),c->rowSpan(),c->colSpan(),
     //                       currentColumn());
     addRowSpan(new ActiveRowSpan(c,rs,cs,currentColumn()));
-    m_t << "\\multirow{" << rs << "}{\\linewidth}{";
+    m_t << "\\multirow{" << rs << "}{*}{";
   }
-  int a = c->alignment();
   if (a==DocHtmlCell::Center)
   {
     m_t << "\\PBS\\centering ";
@@ -1169,7 +1276,7 @@ void LatexDocVisitor::visitPre(DocHtmlCell *c)
   }
   if (c->isHeading())
   {
-    m_t << "\\textbf{ ";
+    m_t << "\\cellcolor{\\tableheadbgcolor}\\textbf{ ";
   }
   if (cs>1)
   {
@@ -1217,16 +1324,16 @@ void LatexDocVisitor::visitPre(DocHRef *href)
   if (Config_getBool(PDF_HYPERLINKS))
   {
     m_t << "\\href{";
-    m_t << href->url();
+    m_t << latexFilterURL(href->url());
     m_t << "}";
   }
-  m_t << "{\\tt ";
+  m_t << "{\\texttt{ ";
 }
 
 void LatexDocVisitor::visitPost(DocHRef *) 
 {
   if (m_hide) return;
-  m_t << "}";
+  m_t << "}}";
 }
 
 void LatexDocVisitor::visitPre(DocHtmlHeader *header)
@@ -1251,7 +1358,7 @@ void LatexDocVisitor::visitPre(DocImage *img)
       gfxName=gfxName.left(gfxName.length()-4);
     }
 
-    visitPreStart(m_t,img->hasCaption(), gfxName, img->width(),  img->height());
+    visitPreStart(m_t,img->hasCaption(), gfxName, img->width(),  img->height(), img->isInlineImage());
   }
   else // other format -> skip
   {
@@ -1265,7 +1372,7 @@ void LatexDocVisitor::visitPost(DocImage *img)
   if (img->type()==DocImage::Latex)
   {
     if (m_hide) return;
-    visitPostEnd(m_t,img->hasCaption());
+    visitPostEnd(m_t,img->hasCaption(), img->isInlineImage());
   }
   else // other format
   {
@@ -1344,7 +1451,7 @@ void LatexDocVisitor::visitPost(DocRef *ref)
   }
   else
   {
-    if (!ref->file().isEmpty()) endLink(ref->ref(),ref->file(),ref->anchor());
+    if (!ref->file().isEmpty()) endLink(ref->ref(),ref->file(),ref->anchor(),ref->refToTable());
   }
 }
 
@@ -1355,7 +1462,7 @@ void LatexDocVisitor::visitPre(DocSecRefItem *ref)
   static bool pdfHyperlinks = Config_getBool(PDF_HYPERLINKS);
   if (pdfHyperlinks)
   {
-    m_t << "\\hyperlink{" << ref->file() << "_" << ref->anchor() << "}{" ;
+    m_t << "\\mbox{\\hyperlink{" << ref->file() << "_" << ref->anchor() << "}{" ;
   }
 }
 
@@ -1365,7 +1472,7 @@ void LatexDocVisitor::visitPost(DocSecRefItem *ref)
   static bool pdfHyperlinks = Config_getBool(PDF_HYPERLINKS);
   if (pdfHyperlinks)
   {
-    m_t << "}";
+    m_t << "}}";
   }
   m_t << "}{\\ref{" << ref->file() << "_" << ref->anchor() << "}}{}" << endl;
 }
@@ -1391,6 +1498,7 @@ void LatexDocVisitor::visitPre(DocParamSect *s)
   if (m_hide) return;
   bool hasInOutSpecs = s->hasInOutSpecifier();
   bool hasTypeSpecs  = s->hasTypeSpecifier();
+  incUsedTableLevels();
   switch(s->type())
   {
     case DocParamSect::Param:
@@ -1409,11 +1517,8 @@ void LatexDocVisitor::visitPre(DocParamSect *s)
       filter(theTranslator->trExceptions());
       break;
     case DocParamSect::TemplateParam: 
-      /* TODO: add this 
-      filter(theTranslator->trTemplateParam()); break;
-      */
       m_t << "\n\\begin{DoxyTemplParams}{";
-      filter("Template Parameters");
+      filter(theTranslator->trTemplateParameters());
       break;
     default:
       ASSERT(0);
@@ -1424,6 +1529,7 @@ void LatexDocVisitor::visitPre(DocParamSect *s)
 void LatexDocVisitor::visitPost(DocParamSect *s)
 {
   if (m_hide) return;
+  decUsedTableLevels();
   switch(s->type())
   {
     case DocParamSect::Param:
@@ -1465,7 +1571,7 @@ void LatexDocVisitor::visitPre(DocParamList *pl)
   {
     if (pl->direction()!=DocParamSect::Unspecified)
     {
-      m_t << "\\mbox{\\tt ";
+      m_t << "\\mbox{\\texttt{ ";
       if (pl->direction()==DocParamSect::In)
       {
         m_t << "in";
@@ -1478,7 +1584,7 @@ void LatexDocVisitor::visitPre(DocParamList *pl)
       {
         m_t << "in,out";
       }
-      m_t << "} ";
+      m_t << "}} ";
     }
     if (useTable) m_t << " & ";
   }
@@ -1486,10 +1592,8 @@ void LatexDocVisitor::visitPre(DocParamList *pl)
   {
     QListIterator<DocNode> li(pl->paramTypes());
     DocNode *type;
-    bool first=TRUE;
     for (li.toFirst();(type=li.current());++li)
     {
-      if (!first) m_t << " | "; else first=FALSE;
       if (type->kind()==DocNode::Kind_Word)
       {
         visit((DocWord*)type); 
@@ -1498,6 +1602,10 @@ void LatexDocVisitor::visitPre(DocParamList *pl)
       {
         visit((DocLinkedWord*)type); 
       }
+      else if (type->kind()==DocNode::Kind_Sep)
+      {
+        m_t << " " << ((DocSeparator *)type)->chars() << " ";
+      }
     }
     if (useTable) m_t << " & ";
   }
@@ -1553,6 +1661,7 @@ void LatexDocVisitor::visitPost(DocParamList *pl)
 
 void LatexDocVisitor::visitPre(DocXRefItem *x)
 {
+  static bool pdfHyperlinks = Config_getBool(PDF_HYPERLINKS);
   if (m_hide) return;
   if (x->title().isEmpty()) return;
   m_t << "\\begin{DoxyRefDesc}{";
@@ -1560,9 +1669,9 @@ void LatexDocVisitor::visitPre(DocXRefItem *x)
   m_t << "}" << endl;
   bool anonymousEnum = x->file()=="@";
   m_t << "\\item[";
-  if (Config_getBool(PDF_HYPERLINKS) && !anonymousEnum)
+  if (pdfHyperlinks && !anonymousEnum)
   {
-    m_t << "\\hyperlink{" << stripPath(x->file()) << "_" << x->anchor() << "}{";
+    m_t << "\\mbox{\\hyperlink{" << stripPath(x->file()) << "_" << x->anchor() << "}{";
   }
   else
   {
@@ -1571,6 +1680,10 @@ void LatexDocVisitor::visitPre(DocXRefItem *x)
   m_insideItem=TRUE;
   filter(x->title());
   m_insideItem=FALSE;
+  if (pdfHyperlinks && !anonymousEnum)
+  {
+    m_t << "}";
+  }
   m_t << "}]";
 }
 
@@ -1593,14 +1706,6 @@ void LatexDocVisitor::visitPost(DocInternalRef *ref)
   endLink(0,ref->file(),ref->anchor());
 }
 
-void LatexDocVisitor::visitPre(DocCopy *)
-{
-}
-
-void LatexDocVisitor::visitPost(DocCopy *)
-{
-}
-
 void LatexDocVisitor::visitPre(DocText *)
 {
 }
@@ -1657,7 +1762,7 @@ void LatexDocVisitor::startLink(const QCString &ref,const QCString &file,const Q
     }
     else
     {
-      m_t << "\\hyperlink{";
+      m_t << "\\mbox{\\hyperlink{";
     }
     if (!file.isEmpty()) m_t << stripPath(file);
     if (!file.isEmpty() && !anchor.isEmpty()) m_t << "_";
@@ -1678,7 +1783,7 @@ void LatexDocVisitor::startLink(const QCString &ref,const QCString &file,const Q
   }
 }
 
-void LatexDocVisitor::endLink(const QCString &ref,const QCString &file,const QCString &anchor)
+void LatexDocVisitor::endLink(const QCString &ref,const QCString &file,const QCString &anchor,bool refToTable)
 {
   m_t << "}";
   static bool pdfHyperLinks = Config_getBool(PDF_HYPERLINKS);
@@ -1690,6 +1795,13 @@ void LatexDocVisitor::endLink(const QCString &ref,const QCString &file,const QCS
     if (!file.isEmpty() && !anchor.isEmpty()) m_t << "_";
     m_t << anchor << "}";
   }
+  if (ref.isEmpty() && pdfHyperLinks) // internal PDF link
+  {
+    if (!refToTable)
+    {
+      m_t << "}";
+    }
+  }
 }
 
 void LatexDocVisitor::pushEnabled()
@@ -1834,7 +1946,7 @@ void LatexDocVisitor::writePlantUMLFile(const QCString &baseName, DocVerbatim *s
     shortName=shortName.right(shortName.length()-i-1);
   }
   QCString outDir = Config_getString(LATEX_OUTPUT);
-  generatePlantUMLOutput(baseName,outDir,PUML_EPS);
+  PlantumlManager::instance()->generatePlantUMLOutput(baseName,outDir,PlantumlManager::PUML_EPS);
   visitPreStart(m_t, s->hasCaption(), shortName, s->width(), s->height());
   visitCaption(this, s->children());
   visitPostEnd(m_t, s->hasCaption());
