@@ -33,15 +33,15 @@ class ManGenerator : public OutputGenerator
     //OutputGenerator *clone() { return new ManGenerator(*this); }
     //void append(const OutputGenerator *o);
     void enable() 
-    { if (genStack->top()) active=*genStack->top(); else active=TRUE; }
-    void disable() { active=FALSE; }
+    { if (m_genStack->top()) m_active=*m_genStack->top(); else m_active=TRUE; }
+    void disable() { m_active=FALSE; }
     void enableIf(OutputType o)  { if (o==Man) enable(); }
     void disableIf(OutputType o) { if (o==Man) disable(); }
     void disableIfNot(OutputType o) { if (o!=Man) disable(); }
-    bool isEnabled(OutputType o) { return (o==Man && active); } 
+    bool isEnabled(OutputType o) { return (o==Man && m_active); } 
     OutputGenerator *get(OutputType o) { return (o==Man) ? this : 0; }
 
-    void writeDoc(DocNode *,Definition *,MemberDef *);
+    void writeDoc(DocNode *,const Definition *,const MemberDef *);
 
     static void init();
     void startFile(const char *name,const char *manName,const char *title);
@@ -91,17 +91,18 @@ class ManGenerator : public OutputGenerator
     void endTextLink() {}
     void startHtmlLink(const char *url);
     void endHtmlLink();
-    void startTypewriter() { t << "\\fC"; firstCol=FALSE; }
-    void endTypewriter()   { t << "\\fP"; firstCol=FALSE; }
+    void startTypewriter() { t << "\\fC"; m_firstCol=FALSE; }
+    void endTypewriter()   { t << "\\fP"; m_firstCol=FALSE; }
     void startGroupHeader(int);
     void endGroupHeader(int);
     void startMemberSections() {}
     void endMemberSections() {}
     void startHeaderSection() {}
     void endHeaderSection();
-    void startMemberHeader(const char *);
+    void startMemberHeader(const char *,int);
     void endMemberHeader();
     void insertMemberAlign(bool) {}
+    void insertMemberAlignLeft(int,bool){}
     void startMemberSubtitle() {}
     void endMemberSubtitle() {}
     //void writeListItem();
@@ -131,13 +132,13 @@ class ManGenerator : public OutputGenerator
     void writeAnchor(const char *,const char *) {}
     void startCodeFragment();
     void endCodeFragment();
-    void writeLineNumber(const char *,const char *,const char *,int l) { t << l << " "; }
+    void writeLineNumber(const char *,const char *,const char *,int l) { t << l << " "; m_col=0; }
     void startCodeLine(bool) {}
-    void endCodeLine() { codify("\n"); col=0; }
-    void startEmphasis() { t << "\\fI"; firstCol=FALSE; }
-    void endEmphasis()   { t << "\\fP"; firstCol=FALSE; }
-    void startBold()     { t << "\\fB"; firstCol=FALSE; }
-    void endBold()       { t << "\\fP"; firstCol=FALSE; }
+    void endCodeLine() { codify("\n"); m_col=0; }
+    void startEmphasis() { t << "\\fI"; m_firstCol=FALSE; }
+    void endEmphasis()   { t << "\\fP"; m_firstCol=FALSE; }
+    void startBold()     { t << "\\fB"; m_firstCol=FALSE; }
+    void endBold()       { t << "\\fP"; m_firstCol=FALSE; }
     void startDescription() {}
     void endDescription()   {}
     void startDescItem();
@@ -151,7 +152,7 @@ class ManGenerator : public OutputGenerator
     void writeLatexSpacing() {}
     void writeStartAnnoItem(const char *type,const char *file,
                             const char *path,const char *name);
-    void writeEndAnnoItem(const char *) { t << endl; firstCol=TRUE; }
+    void writeEndAnnoItem(const char *) { t << endl; m_firstCol=TRUE; }
     void startSubsection();
     void endSubsection();
     void startSubsubsection();
@@ -160,16 +161,16 @@ class ManGenerator : public OutputGenerator
     void endCenter()          {}
     void startSmall()         {}
     void endSmall()           {}
-    void startMemberDescription(const char *,const char *) { t << "\n.RI \""; firstCol=FALSE; }
-    void endMemberDescription()   { t << "\""; firstCol=FALSE; }
+    void startMemberDescription(const char *,const char *,bool) { t << "\n.RI \""; m_firstCol=FALSE; }
+    void endMemberDescription()   { t << "\""; m_firstCol=FALSE; }
     void startMemberDeclaration() {} 
     void endMemberDeclaration(const char *,const char *) {}
     void writeInheritedSectionTitle(const char *,const char *,const char *,
                       const char *,const char *,const char *) {}
     void startDescList(SectionTypes);
     void endDescList()        {}
-    void startSimpleSect(SectionTypes,const char *,const char *,const char *);
-    void endSimpleSect();
+    void startExamples();
+    void endExamples();
     void startParamList(ParamListTypes,const char *title);
     void endParamList();
     //void writeDescItem();
@@ -196,27 +197,26 @@ class ManGenerator : public OutputGenerator
     void endContents() {}
     void writeNonBreakableSpace(int n) { int i; for (i=0;i<n;i++) t << " "; }
     
-    void startDescTable(const char *t) 
-    { startSimpleSect(EnumValues,0,0,t); startDescForItem(); }
-    void endDescTable() { endDescForItem(); endSimpleSect(); }
+    void startDescTable(const char *t);
+    void endDescTable();
     void startDescTableRow() {}
     void endDescTableRow() {}
     void startDescTableTitle() { startItemListItem(); startBold(); startEmphasis(); endItemListItem(); }
     void endDescTableTitle() { endEmphasis(); endBold(); }
-    void startDescTableData() { t << endl; firstCol=TRUE; }
+    void startDescTableData() { t << endl; m_firstCol=TRUE; }
     void endDescTableData() {}
 
     void startDotGraph() {}
-    void endDotGraph(const DotClassGraph &) {}
+    void endDotGraph(DotClassGraph &) {}
     void startInclDepGraph() {}
-    void endInclDepGraph(const DotInclDepGraph &) {}
+    void endInclDepGraph(DotInclDepGraph &) {}
     void startGroupCollaboration() {}
-    void endGroupCollaboration(const DotGroupCollaboration &) {}
+    void endGroupCollaboration(DotGroupCollaboration &) {}
     void startCallGraph() {}
-    void endCallGraph(const DotCallGraph &) {}
+    void endCallGraph(DotCallGraph &) {}
     void startDirDepGraph() {} 
-    void endDirDepGraph(const DotDirDeps &) {}
-    void writeGraphicalHierarchy(const DotGfxHierarchyTable &) {}
+    void endDirDepGraph(DotDirDeps &) {}
+    void writeGraphicalHierarchy(DotGfxHierarchyTable &) {}
 
     void startTextBlock(bool) {}
     void endTextBlock(bool) {}
@@ -260,16 +260,16 @@ class ManGenerator : public OutputGenerator
     void endLabels();
 
     void writeCodeAnchor(const char *) {}
-    void setCurrentDoc(Definition *,const char *,bool) {}
+    void setCurrentDoc(const Definition *,const char *,bool) {}
     void addWord(const char *,bool) {}
 
   private:
-    bool firstCol;
-    bool paragraph;
-    int col;
-    bool upperCase;
-    bool insideTabbing;
-    bool inHeader;
+    bool m_firstCol;
+    bool m_paragraph;
+    int  m_col;
+    bool m_upperCase;
+    bool m_insideTabbing;
+    bool m_inHeader;
 
     ManGenerator(const ManGenerator &g);
     ManGenerator &operator=(const ManGenerator &g);
