@@ -124,7 +124,7 @@ class CodeOutputInterface
      */
     virtual void writeCodeAnchor(const char *name) = 0;
 
-    virtual void setCurrentDoc(Definition *context,const char *anchor,bool isSourceFile) = 0;
+    virtual void setCurrentDoc(const Definition *context,const char *anchor,bool isSourceFile) = 0;
     virtual void addWord(const char *word,bool hiPriority) = 0;
 };
 
@@ -145,11 +145,12 @@ class BaseOutputDocInterface : public CodeOutputInterface
                         Since, Date, Bug, Note,
                         Warning, Par, Deprecated, Pre, 
                         Post, Invar, Remark, Attention, 
-                        Todo, Test, RCS, */ EnumValues, 
+                        Todo, Test, RCS, */
+	                EnumValues, 
                         Examples 
                       };
 
-    virtual bool parseText(const QCString &s)  { return s.isEmpty(); }
+    virtual void parseText(const QCString &s) {}
     
     /*! Start of a bullet list: e.g. \c \<ul\> in html. startItemListItem() is
      *  Used for the bullet items.
@@ -188,7 +189,7 @@ class BaseOutputDocInterface : public CodeOutputInterface
     //virtual void newParagraph()   = 0;
 
     /*! Starts a new paragraph */
-    virtual void startParagraph() = 0;
+    virtual void startParagraph(const char *classDef) = 0;
     /*! Ends a paragraph */
     virtual void endParagraph() = 0;
 
@@ -279,9 +280,8 @@ class BaseOutputDocInterface : public CodeOutputInterface
     virtual void startSmall() = 0;
     virtual void endSmall() = 0;
 
-    virtual void startSimpleSect(SectionTypes t,const char *file,
-                                 const char *anchor,const char *title) = 0;
-    virtual void endSimpleSect() = 0;
+    virtual void startExamples() = 0;
+    virtual void endExamples() = 0;
     virtual void startParamList(ParamListTypes t,const char *title) = 0;
     virtual void endParamList() = 0;
 
@@ -322,7 +322,7 @@ class BaseOutputDocInterface : public CodeOutputInterface
 class OutputGenerator : public BaseOutputDocInterface
 {
   public:
-    enum OutputType { Html, Latex, Man, RTF, XML, DEF, Perl };
+    enum OutputType { Html, Latex, Man, RTF, XML, DEF, Perl , Docbook};
 
     OutputGenerator();
     virtual ~OutputGenerator();
@@ -340,13 +340,13 @@ class OutputGenerator : public BaseOutputDocInterface
     void startPlainFile(const char *name);
     void endPlainFile();
     //QCString getContents() const;
-    bool isEnabled() const { return active; }
+    bool isEnabled() const { return m_active; }
     void pushGeneratorState();
     void popGeneratorState();
     //void setEncoding(const QCString &enc) { encoding = enc; }
     //virtual void postProcess(QByteArray &) { }
 
-    virtual void writeDoc(DocNode *,Definition *ctx,MemberDef *md) = 0;
+    virtual void writeDoc(DocNode *,const Definition *ctx,const MemberDef *md) = 0;
 
     ///////////////////////////////////////////////////////////////
     // structural output interface
@@ -380,7 +380,7 @@ class OutputGenerator : public BaseOutputDocInterface
     virtual void endMemberSections() = 0;
     virtual void startHeaderSection() = 0;
     virtual void endHeaderSection() = 0;
-    virtual void startMemberHeader(const char *anchor) = 0;
+    virtual void startMemberHeader(const char *anchor, int typ) = 0;
     virtual void endMemberHeader() = 0;
     virtual void startMemberSubtitle() = 0;
     virtual void endMemberSubtitle() = 0;
@@ -403,6 +403,7 @@ class OutputGenerator : public BaseOutputDocInterface
     virtual void startMemberGroup() = 0;
     virtual void endMemberGroup(bool) = 0;
     virtual void insertMemberAlign(bool) = 0;
+    virtual void insertMemberAlignLeft(int,bool) = 0;
     virtual void startMemberDoc(const char *,const char *,
                                 const char *,const char *,int,int,bool) = 0;
     virtual void endMemberDoc(bool) = 0;
@@ -414,7 +415,7 @@ class OutputGenerator : public BaseOutputDocInterface
     virtual void writeStartAnnoItem(const char *type,const char *file,
                                     const char *path,const char *name) = 0;
     virtual void writeEndAnnoItem(const char *name) = 0;
-    virtual void startMemberDescription(const char *anchor,const char *inheritId) = 0;
+    virtual void startMemberDescription(const char *anchor,const char *inheritId, bool typ) = 0;
     virtual void endMemberDescription() = 0;
     virtual void startMemberDeclaration() = 0;
     virtual void endMemberDeclaration(const char *anchor,const char *inheritId) = 0;
@@ -427,16 +428,16 @@ class OutputGenerator : public BaseOutputDocInterface
     virtual void startClassDiagram() = 0;
     virtual void endClassDiagram(const ClassDiagram &,const char *,const char *) = 0;
     virtual void startDotGraph() = 0;
-    virtual void endDotGraph(const DotClassGraph &g) = 0;
+    virtual void endDotGraph(DotClassGraph &g) = 0;
     virtual void startInclDepGraph() = 0;
-    virtual void endInclDepGraph(const DotInclDepGraph &g) = 0;
+    virtual void endInclDepGraph(DotInclDepGraph &g) = 0;
     virtual void startGroupCollaboration() = 0;
-    virtual void endGroupCollaboration(const DotGroupCollaboration &g) = 0;
+    virtual void endGroupCollaboration(DotGroupCollaboration &g) = 0;
     virtual void startCallGraph() = 0;
-    virtual void endCallGraph(const DotCallGraph &g) = 0;
+    virtual void endCallGraph(DotCallGraph &g) = 0;
     virtual void startDirDepGraph() = 0;
-    virtual void endDirDepGraph(const DotDirDeps &g) = 0;
-    virtual void writeGraphicalHierarchy(const DotGfxHierarchyTable &g) = 0;
+    virtual void endDirDepGraph(DotDirDeps &g) = 0;
+    virtual void writeGraphicalHierarchy(DotGfxHierarchyTable &g) = 0;
     virtual void startQuickIndices() = 0;
     virtual void endQuickIndices() = 0;
     virtual void writeSplitBar(const char *) = 0;
@@ -446,6 +447,8 @@ class OutputGenerator : public BaseOutputDocInterface
     virtual void writeSummaryLink(const char *file,const char *anchor,const char *title,bool first) = 0;
     virtual void startContents() = 0;
     virtual void endContents() = 0;
+    virtual void startPageDoc(const char *pageTitle) {};
+    virtual void endPageDoc() {};
     virtual void startTextBlock(bool) = 0;
     virtual void endTextBlock(bool) = 0;
     virtual void lastIndexPage() = 0;
@@ -486,11 +489,11 @@ class OutputGenerator : public BaseOutputDocInterface
 
   protected:
     FTextStream t;
-    QFile *file;
-    QCString fileName;
-    QCString dir;
-    bool active;
-    QStack<bool> *genStack;
+    QFile *m_file;
+    QCString m_fileName;
+    QCString m_dir;
+    bool m_active;
+    QStack<bool> *m_genStack;
 
   private:
     OutputGenerator(const OutputGenerator &o);
