@@ -43,6 +43,7 @@
 #include "section.h"
 #include "util.h"
 #include "htmlentity.h"
+#include "emoji.h"
 
 #define PERLOUTPUT_MAX_INDENTATION 40
 
@@ -299,6 +300,7 @@ public:
   void visit(DocLinkedWord *);
   void visit(DocWhiteSpace *);
   void visit(DocSymbol *);
+  void visit(DocEmoji *);
   void visit(DocURL *);
   void visit(DocLineBreak *);
   void visit(DocHorRuler *);
@@ -386,8 +388,6 @@ public:
   void visitPost(DocXRefItem *);
   void visitPre(DocInternalRef *);
   void visitPost(DocInternalRef *);
-  void visitPre(DocCopy *);
-  void visitPost(DocCopy *);
   void visitPre(DocText *);
   void visitPost(DocText *);
   void visitPre(DocHtmlBlockQuote *);
@@ -428,7 +428,7 @@ private:
 };
 
 PerlModDocVisitor::PerlModDocVisitor(PerlModOutput &output)
-  : DocVisitor(DocVisitor_Other), m_output(output), m_textmode(false)
+  : DocVisitor(DocVisitor_Other), m_output(output), m_textmode(false), m_textblockstart(FALSE)
 {
   m_output.openList("doc");
 }
@@ -609,6 +609,19 @@ void PerlModDocVisitor::visit(DocSymbol *sy)
     err("perl: non supported HTML-entity found: %s\n",HtmlEntityMapper::instance()->html(sy->symbol(),TRUE));
   }
 }
+void PerlModDocVisitor::visit(DocEmoji *sy)
+{
+  enterText();
+  const char *name = EmojiEntityMapper::instance()->name(sy->index());
+  if (name)
+  {
+    m_output.add(name);
+  }
+  else
+  {
+    m_output.add(sy->name());
+  }
+}
 
 void PerlModDocVisitor::visit(DocURL *u)
 {
@@ -626,6 +639,11 @@ void PerlModDocVisitor::visit(DocStyleChange *s)
   switch (s->style())
   {
     case DocStyleChange::Bold:          style = "bold"; break;
+    case DocStyleChange::S:             style = "s"; break;
+    case DocStyleChange::Strike:        style = "strike"; break;
+    case DocStyleChange::Del:           style = "del"; break;
+    case DocStyleChange::Underline:     style = "underline"; break;
+    case DocStyleChange::Ins:           style = "ins"; break;
     case DocStyleChange::Italic:        style = "italic"; break;
     case DocStyleChange::Code:          style = "code"; break;
     case DocStyleChange::Subscript:     style = "subscript"; break;
@@ -653,8 +671,8 @@ void PerlModDocVisitor::visit(DocVerbatim *s)
       m_output.add("<programlisting>");
       parseCode(m_ci,s->context(),s->text(),FALSE,0);
       m_output.add("</programlisting>");
-#endif
       return;
+#endif
     case DocVerbatim::Verbatim:  type = "preformatted"; break;
     case DocVerbatim::HtmlOnly:  type = "htmlonly";     break;
     case DocVerbatim::RtfOnly:   type = "rtfonly";      break;
@@ -667,6 +685,14 @@ void PerlModDocVisitor::visit(DocVerbatim *s)
     case DocVerbatim::PlantUML:  type = "plantuml";     break;
   }
   openItem(type);
+  if (s->hasCaption())
+  {
+     openSubBlock("caption");
+     QListIterator<DocNode> cli(s->children());
+     DocNode *n;
+     for (cli.toFirst();(n=cli.current());++cli) n->accept(this);
+     closeSubBlock();
+  }
   m_output.addFieldQuotedString("content", s->text());
   closeItem();
 }
@@ -704,10 +730,17 @@ void PerlModDocVisitor::visit(DocInclude *inc)
 #endif
     return;
   case DocInclude::DontInclude:	return;
+  case DocInclude::DontIncWithLines: return;
   case DocInclude::HtmlInclude:	type = "htmlonly"; break;
   case DocInclude::LatexInclude: type = "latexonly"; break;
   case DocInclude::VerbInclude:	type = "preformatted"; break;
   case DocInclude::Snippet: return;
+  case DocInclude::SnipWithLines: return;
+  case DocInclude::SnippetDoc: 
+  case DocInclude::IncludeDoc: 
+    err("Internal inconsistency: found switch SnippetDoc / IncludeDoc in file: %s"
+        "Please create a bug report\n",__FILE__);
+    break;
   }
   openItem(type);
   m_output.addFieldQuotedString("content", inc->text());
@@ -717,7 +750,7 @@ void PerlModDocVisitor::visit(DocInclude *inc)
 void PerlModDocVisitor::visit(DocIncOperator *)
 {
 #if 0
-  //printf("DocIncOperator: type=%d first=%d, last=%d text=`%s'\n",
+  //printf("DocIncOperator: type=%d first=%d, last=%d text='%s'\n",
   //    op->type(),op->isFirst(),op->isLast(),op->text().data());
   if (op->isFirst())
   {
@@ -897,6 +930,7 @@ void PerlModDocVisitor::visitPre(DocSection *s)
 {
   QCString sect = QCString().sprintf("sect%d",s->level());
   openItem(sect);
+  m_output.addFieldQuotedString("title", s->title());
   openSubBlock("content");
 }
 
@@ -1239,6 +1273,7 @@ void PerlModDocVisitor::visitPre(DocParamSect *s)
     err("unknown parameter section found\n");
     break;
   }
+  m_output.openHash();
   openOther();
   openSubBlock(type);
 }
@@ -1247,6 +1282,7 @@ void PerlModDocVisitor::visitPost(DocParamSect *)
 {
   closeSubBlock();
   closeOther();
+  m_output.closeHash();
 }
 
 void PerlModDocVisitor::visitPre(DocParamList *pl)
@@ -1260,17 +1296,43 @@ void PerlModDocVisitor::visitPre(DocParamList *pl)
   DocNode *param;
   for (li.toFirst();(param=li.current());++li)
   {
-    QCString s;
+    QCString name;
     if (param->kind()==DocNode::Kind_Word)
     {
-      s = ((DocWord*)param)->word(); 
+      name = ((DocWord*)param)->word();
     }
     else if (param->kind()==DocNode::Kind_LinkedWord)
     {
-      s = ((DocLinkedWord*)param)->word(); 
+      name = ((DocLinkedWord*)param)->word();
     }
+
+    QCString dir = "";
+    DocParamSect *sect = 0;
+    if (pl->parent()->kind()==DocNode::Kind_ParamSect)
+    {
+      sect=(DocParamSect*)pl->parent();
+    }
+    if (sect && sect->hasInOutSpecifier())
+    {
+      if (pl->direction()!=DocParamSect::Unspecified)
+      {
+        if (pl->direction()==DocParamSect::In)
+        {
+          dir = "in";
+        }
+        else if (pl->direction()==DocParamSect::Out)
+        {
+          dir = "out";
+        }
+        else if (pl->direction()==DocParamSect::InOut)
+        {
+          dir = "in,out";
+        }
+      }
+    }
+
     m_output.openHash()
-      .addFieldQuotedString("name", s)
+      .addFieldQuotedString("name", name).addFieldQuotedString("dir", dir)
       .closeHash();
   }
   m_output.closeList()
@@ -1324,14 +1386,6 @@ void PerlModDocVisitor::visitPost(DocInternalRef *)
   closeItem();
 }
 
-void PerlModDocVisitor::visitPre(DocCopy *)
-{
-}
-
-void PerlModDocVisitor::visitPost(DocCopy *)
-{
-}
-
 void PerlModDocVisitor::visitPre(DocText *)
 {
 }
@@ -1369,23 +1423,20 @@ void PerlModDocVisitor::visitPost(DocParBlock *)
 }
 
 
-static void addTemplateArgumentList(ArgumentList *al,PerlModOutput &output,const char *)
+static void addTemplateArgumentList(const ArgumentList &al,PerlModOutput &output,const char *)
 {
-  if (!al)
-    return;
+  if (!al.hasParameters()) return;
   output.openList("template_parameters");
-  ArgumentListIterator ali(*al);
-  Argument *a;
-  for (ali.toFirst();(a=ali.current());++ali)
+  for (const Argument &a : al)
   {
     output.openHash();
-    if (!a->type.isEmpty())
-      output.addFieldQuotedString("type", a->type);
-    if (!a->name.isEmpty())
-      output.addFieldQuotedString("declaration_name", a->name)
-	.addFieldQuotedString("definition_name", a->name);
-    if (!a->defval.isEmpty())
-      output.addFieldQuotedString("default", a->defval);
+    if (!a.type.isEmpty())
+      output.addFieldQuotedString("type", a.type);
+    if (!a.name.isEmpty())
+      output.addFieldQuotedString("declaration_name", a.name)
+	.addFieldQuotedString("definition_name", a.name);
+    if (!a.defval.isEmpty())
+      output.addFieldQuotedString("default", a.defval);
     output.closeHash();
   }
   output.closeList();
@@ -1401,7 +1452,7 @@ static void addMemberTemplateLists(MemberDef *md,PerlModOutput &output)
 }
 #endif
 
-static void addTemplateList(ClassDef *cd,PerlModOutput &output)
+static void addTemplateList(const ClassDef *cd,PerlModOutput &output)
 {
   addTemplateArgumentList(cd->templateArguments(),output,cd->name());
 }
@@ -1410,8 +1461,8 @@ static void addPerlModDocBlock(PerlModOutput &output,
 			    const char *name,
 			    const QCString &fileName,
 			    int lineNr,
-			    Definition *scope,
-			    MemberDef *md,
+			    const Definition *scope,
+			    const MemberDef *md,
 			    const QCString &text)
 {
   QCString stext = text.stripWhiteSpace();
@@ -1482,14 +1533,14 @@ public:
 
   inline PerlModGenerator(bool pretty) : m_output(pretty) { }
 
-  void generatePerlModForMember(MemberDef *md, Definition *);
-  void generatePerlModSection(Definition *d, MemberList *ml,
+  void generatePerlModForMember(const MemberDef *md, const Definition *);
+  void generatePerlModSection(const Definition *d, MemberList *ml,
 			      const char *name, const char *header=0);
-  void addListOfAllMembers(ClassDef *cd);
-  void generatePerlModForClass(ClassDef *cd);
-  void generatePerlModForNamespace(NamespaceDef *nd);
-  void generatePerlModForFile(FileDef *fd);
-  void generatePerlModForGroup(GroupDef *gd);
+  void addListOfAllMembers(const ClassDef *cd);
+  void generatePerlModForClass(const ClassDef *cd);
+  void generatePerlModForNamespace(const NamespaceDef *nd);
+  void generatePerlModForFile(const FileDef *fd);
+  void generatePerlModForGroup(const GroupDef *gd);
   void generatePerlModForPage(PageDef *pi);
   
   bool createOutputFile(QFile &f, const char *s);
@@ -1506,7 +1557,7 @@ public:
   void generate();
 };
 
-void PerlModGenerator::generatePerlModForMember(MemberDef *md,Definition *)
+void PerlModGenerator::generatePerlModForMember(const MemberDef *md,const Definition *)
 {
   // + declaration/definition arg lists
   // + reimplements
@@ -1525,21 +1576,22 @@ void PerlModGenerator::generatePerlModForMember(MemberDef *md,Definition *)
   bool isFunc=FALSE;
   switch (md->memberType())
   {
-  case MemberType_Define:      memType="define";    break;
-  case MemberType_EnumValue:   memType="enumvalue"; break;
-  case MemberType_Property:    memType="property";  break;
-  case MemberType_Variable:    memType="variable";  break;
-  case MemberType_Typedef:     memType="typedef";   break;
-  case MemberType_Enumeration: memType="enum";      break;
-  case MemberType_Function:    memType="function";  isFunc=TRUE; break;
-  case MemberType_Signal:      memType="signal";    isFunc=TRUE; break;
-  //case MemberType_Prototype:   memType="prototype"; isFunc=TRUE; break;
-  case MemberType_Friend:      memType="friend";    isFunc=TRUE; break;
-  case MemberType_DCOP:        memType="dcop";      isFunc=TRUE; break;
-  case MemberType_Slot:        memType="slot";      isFunc=TRUE; break;
-  case MemberType_Event:       memType="event";     break;
-  case MemberType_Interface:   memType="interface"; break;
-  case MemberType_Service:     memType="service";   break;
+    case MemberType_Define:      memType="define";     break;
+    case MemberType_EnumValue:   memType="enumvalue";  break;
+    case MemberType_Property:    memType="property";   break;
+    case MemberType_Variable:    memType="variable";   break;
+    case MemberType_Typedef:     memType="typedef";    break;
+    case MemberType_Enumeration: memType="enum";       break;
+    case MemberType_Function:    memType="function";   isFunc=TRUE; break;
+    case MemberType_Signal:      memType="signal";     isFunc=TRUE; break;
+    case MemberType_Friend:      memType="friend";     isFunc=TRUE; break;
+    case MemberType_DCOP:        memType="dcop";       isFunc=TRUE; break;
+    case MemberType_Slot:        memType="slot";       isFunc=TRUE; break;
+    case MemberType_Event:       memType="event";      break;
+    case MemberType_Interface:   memType="interface";  break;
+    case MemberType_Service:     memType="service";    break;
+    case MemberType_Sequence:    memType="sequence";   break;
+    case MemberType_Dictionary:  memType="dictionary"; break;
   }
 
   m_output.openHash()
@@ -1555,45 +1607,46 @@ void PerlModGenerator::generatePerlModForMember(MemberDef *md,Definition *)
       md->memberType()!=MemberType_Enumeration)
     m_output.addFieldQuotedString("type", md->typeString());
   
-  ArgumentList *al = md->argumentList();
+  const ArgumentList &al = md->argumentList();
   if (isFunc) //function
   {
-    m_output.addFieldBoolean("const", al!=0 && al->constSpecifier)
-      .addFieldBoolean("volatile", al!=0 && al->volatileSpecifier);
+    m_output.addFieldBoolean("const",    al.constSpecifier)
+            .addFieldBoolean("volatile", al.volatileSpecifier);
 
     m_output.openList("parameters");
-    ArgumentList *declAl = md->declArgumentList();
-    ArgumentList *defAl  = md->argumentList();
-    if (declAl && declAl->count()>0)
+    const ArgumentList &declAl = md->declArgumentList();
+    if (!declAl.empty())
     {
-      ArgumentListIterator declAli(*declAl);
-      ArgumentListIterator defAli(*defAl);
-      Argument *a;
-      for (declAli.toFirst();(a=declAli.current());++declAli)
+      auto defIt = al.begin();
+      for (const Argument &a : declAl)
       {
-	Argument *defArg = defAli.current();
+	const Argument *defArg = 0;
+        if (defIt!=al.end())
+        {
+          defArg = &(*defIt);
+          ++defIt;
+        }
 	m_output.openHash();
 
-	if (!a->name.isEmpty())
-	  m_output.addFieldQuotedString("declaration_name", a->name);
+	if (!a.name.isEmpty())
+	  m_output.addFieldQuotedString("declaration_name", a.name);
 
-	if (defArg && !defArg->name.isEmpty() && defArg->name!=a->name)
+	if (defArg && !defArg->name.isEmpty() && defArg->name!=a.name)
 	  m_output.addFieldQuotedString("definition_name", defArg->name);
 
-	if (!a->type.isEmpty())
-	  m_output.addFieldQuotedString("type", a->type);
+	if (!a.type.isEmpty())
+	  m_output.addFieldQuotedString("type", a.type);
 
-	if (!a->array.isEmpty())
-	  m_output.addFieldQuotedString("array", a->array);
+	if (!a.array.isEmpty())
+	  m_output.addFieldQuotedString("array", a.array);
 
-	if (!a->defval.isEmpty())
-	  m_output.addFieldQuotedString("default_value", a->defval);
+	if (!a.defval.isEmpty())
+	  m_output.addFieldQuotedString("default_value", a.defval);
 
-	if (!a->attrib.isEmpty())
-	  m_output.addFieldQuotedString("attributes", a->attrib);
+	if (!a.attrib.isEmpty())
+	  m_output.addFieldQuotedString("attributes", a.attrib);
 	
 	m_output.closeHash();
-	if (defArg) ++defAli;
       }
     }
     m_output.closeList();
@@ -1602,12 +1655,10 @@ void PerlModGenerator::generatePerlModForMember(MemberDef *md,Definition *)
 	   md->argsString()!=0) // define
   {
     m_output.openList("parameters");
-    ArgumentListIterator ali(*al);
-    Argument *a;
-    for (ali.toFirst();(a=ali.current());++ali)
+    for (const Argument &a : al)
     {
       m_output.openHash()
-	.addFieldQuotedString("name", a->type)
+	.addFieldQuotedString("name", a.type)
 	.closeHash();
     }
     m_output.closeList();
@@ -1625,12 +1676,12 @@ void PerlModGenerator::generatePerlModForMember(MemberDef *md,Definition *)
   
   if (md->memberType()==MemberType_Enumeration) // enum
   {
-    MemberList *enumFields = md->enumFieldList();
+    const MemberList *enumFields = md->enumFieldList();
     if (enumFields)
     {
       m_output.openList("values");
       MemberListIterator emli(*enumFields);
-      MemberDef *emd;
+      const MemberDef *emd;
       for (emli.toFirst();(emd=emli.current());++emli)
       {
 	m_output.openHash()
@@ -1649,7 +1700,7 @@ void PerlModGenerator::generatePerlModForMember(MemberDef *md,Definition *)
     }
   }
 
-  MemberDef *rmd = md->reimplements();
+  const MemberDef *rmd = md->reimplements();
   if (rmd)
     m_output.openHash("reimplements")
       .addFieldQuotedString("name", rmd->name())
@@ -1670,7 +1721,7 @@ void PerlModGenerator::generatePerlModForMember(MemberDef *md,Definition *)
   m_output.closeHash();
 }
 
-void PerlModGenerator::generatePerlModSection(Definition *d,
+void PerlModGenerator::generatePerlModSection(const Definition *d,
 					      MemberList *ml,const char *name,const char *header)
 {
   if (ml==0) return; // empty list
@@ -1682,7 +1733,7 @@ void PerlModGenerator::generatePerlModSection(Definition *d,
   
   m_output.openList("members");
   MemberListIterator mli(*ml);
-  MemberDef *md;
+  const MemberDef *md;
   for (mli.toFirst();(md=mli.current());++mli)
   {
     generatePerlModForMember(md,d);
@@ -1691,7 +1742,7 @@ void PerlModGenerator::generatePerlModSection(Definition *d,
     .closeHash();
 }
 
-void PerlModGenerator::addListOfAllMembers(ClassDef *cd)
+void PerlModGenerator::addListOfAllMembers(const ClassDef *cd)
 {
   m_output.openList("all_members");
   if (cd->memberNameInfoSDict())
@@ -1704,9 +1755,9 @@ void PerlModGenerator::addListOfAllMembers(ClassDef *cd)
       MemberInfo *mi;
       for (mii.toFirst();(mi=mii.current());++mii)
       {
-        MemberDef *md=mi->memberDef;
-        ClassDef  *cd=md->getClassDef();
-        Definition *d=md->getGroupDef();
+        const MemberDef *md=mi->memberDef;
+        const ClassDef  *cd=md->getClassDef();
+        const Definition *d=md->getGroupDef();
         if (d==0) d = cd;
 
         m_output.openHash()
@@ -1725,7 +1776,7 @@ void PerlModGenerator::addListOfAllMembers(ClassDef *cd)
   m_output.closeList();
 }
 
-void PerlModGenerator::generatePerlModForClass(ClassDef *cd)
+void PerlModGenerator::generatePerlModForClass(const ClassDef *cd)
 {
   // + brief description
   // + detailed description
@@ -1742,9 +1793,9 @@ void PerlModGenerator::generatePerlModForClass(ClassDef *cd)
   // + standard member sections
   // + detailed member documentation
   // - examples using the class
-  
+
   if (cd->isReference())        return; // skip external references.
-  if (cd->name().find('@')!=-1) return; // skip anonymous compounds.
+  if (cd->isAnonymous())        return; // skip anonymous compounds.
   if (cd->templateMaster()!=0)  return; // skip generated template instances.
 
   m_output.openHash()
@@ -1783,7 +1834,7 @@ void PerlModGenerator::generatePerlModForClass(ClassDef *cd)
   {
     m_output.openList("inner");
     ClassSDict::Iterator cli(*cl);
-    ClassDef *cd;
+    const ClassDef *cd;
     for (cli.toFirst();(cd=cli.current());++cli)
       m_output.openHash()
 	.addFieldQuotedString("name", cd->name())
@@ -1875,7 +1926,7 @@ void PerlModGenerator::generatePerlModForClass(ClassDef *cd)
   m_output.closeHash();
 }
 
-void PerlModGenerator::generatePerlModForNamespace(NamespaceDef *nd)
+void PerlModGenerator::generatePerlModForNamespace(const NamespaceDef *nd)
 {
   // + contained class definitions
   // + contained namespace definitions
@@ -1896,7 +1947,7 @@ void PerlModGenerator::generatePerlModForNamespace(NamespaceDef *nd)
   {
     m_output.openList("classes");
     ClassSDict::Iterator cli(*cl);
-    ClassDef *cd;
+    const ClassDef *cd;
     for (cli.toFirst();(cd=cli.current());++cli)
       m_output.openHash()
 	.addFieldQuotedString("name", cd->name())
@@ -1904,12 +1955,12 @@ void PerlModGenerator::generatePerlModForNamespace(NamespaceDef *nd)
     m_output.closeList();
   }
 
-  NamespaceSDict *nl = nd->getNamespaceSDict();
+  const NamespaceSDict *nl = nd->getNamespaceSDict();
   if (nl)
   {
     m_output.openList("namespaces");
     NamespaceSDict::Iterator nli(*nl);
-    NamespaceDef *nd;
+    const NamespaceDef *nd;
     for (nli.toFirst();(nd=nli.current());++nli)
       m_output.openHash()
 	.addFieldQuotedString("name", nd->name())
@@ -1920,7 +1971,7 @@ void PerlModGenerator::generatePerlModForNamespace(NamespaceDef *nd)
   if (nd->getMemberGroupSDict())
   {
     MemberGroupSDict::Iterator mgli(*nd->getMemberGroupSDict());
-    MemberGroup *mg;
+    const MemberGroup *mg;
     for (;(mg=mgli.current());++mgli)
       generatePerlModSection(nd,mg->members(),"user-defined",mg->header());
   }
@@ -1938,7 +1989,7 @@ void PerlModGenerator::generatePerlModForNamespace(NamespaceDef *nd)
   m_output.closeHash();
 }
 
-void PerlModGenerator::generatePerlModForFile(FileDef *fd)
+void PerlModGenerator::generatePerlModForFile(const FileDef *fd)
 {
   // + includes files
   // + includedby files
@@ -2007,7 +2058,7 @@ void PerlModGenerator::generatePerlModForFile(FileDef *fd)
   m_output.closeHash();
 }
 
-void PerlModGenerator::generatePerlModForGroup(GroupDef *gd)
+void PerlModGenerator::generatePerlModForGroup(const GroupDef *gd)
 {
   // + members
   // + member groups
@@ -2032,7 +2083,7 @@ void PerlModGenerator::generatePerlModForGroup(GroupDef *gd)
   {
     m_output.openList("files");
     QListIterator<FileDef> fli(*fl);
-    FileDef *fd;
+    const FileDef *fd;
     for (fli.toFirst();(fd=fli.current());++fli)
       m_output.openHash()
 	.addFieldQuotedString("name", fd->name())
@@ -2045,7 +2096,7 @@ void PerlModGenerator::generatePerlModForGroup(GroupDef *gd)
   {
     m_output.openList("classes");
     ClassSDict::Iterator cli(*cl);
-    ClassDef *cd;
+    const ClassDef *cd;
     for (cli.toFirst();(cd=cli.current());++cli)
       m_output.openHash()
 	.addFieldQuotedString("name", cd->name())
@@ -2058,7 +2109,7 @@ void PerlModGenerator::generatePerlModForGroup(GroupDef *gd)
   {
     m_output.openList("namespaces");
     NamespaceSDict::Iterator nli(*nl);
-    NamespaceDef *nd;
+    const NamespaceDef *nd;
     for (nli.toFirst();(nd=nli.current());++nli)
       m_output.openHash()
 	.addFieldQuotedString("name", nd->name())
@@ -2084,7 +2135,7 @@ void PerlModGenerator::generatePerlModForGroup(GroupDef *gd)
   {
     m_output.openList("groups");
     GroupListIterator gli(*gl);
-    GroupDef *sgd;
+    const GroupDef *sgd;
     for (gli.toFirst();(sgd=gli.current());++gli)
       m_output.openHash()
 	.addFieldQuotedString("title", sgd->groupTitle())
@@ -2145,14 +2196,14 @@ bool PerlModGenerator::generatePerlModOutput()
   
   m_output.openList("classes");
   ClassSDict::Iterator cli(*Doxygen::classSDict);
-  ClassDef *cd;
+  const ClassDef *cd;
   for (cli.toFirst();(cd=cli.current());++cli)
     generatePerlModForClass(cd);
   m_output.closeList();
 
   m_output.openList("namespaces");
   NamespaceSDict::Iterator nli(*Doxygen::namespaceSDict);
-  NamespaceDef *nd;
+  const NamespaceDef *nd;
   for (nli.toFirst();(nd=nli.current());++nli)
     generatePerlModForNamespace(nd);
   m_output.closeList();
@@ -2163,7 +2214,7 @@ bool PerlModGenerator::generatePerlModOutput()
   for (;(fn=fnli.current());++fnli)
   {
     FileNameIterator fni(*fn);
-    FileDef *fd;
+    const FileDef *fd;
     for (;(fd=fni.current());++fni)
       generatePerlModForFile(fd);
   }
@@ -2171,7 +2222,7 @@ bool PerlModGenerator::generatePerlModOutput()
 
   m_output.openList("groups");
   GroupSDict::Iterator gli(*Doxygen::groupSDict);
-  GroupDef *gd;
+  const GroupDef *gd;
   for (;(gd=gli.current());++gli)
   {
     generatePerlModForGroup(gd);
@@ -2208,7 +2259,7 @@ bool PerlModGenerator::createOutputFile(QFile &f, const char *s)
 
 bool PerlModGenerator::createOutputDir(QDir &perlModDir)
 {
-  QCString outputDirectory = Config_getString("OUTPUT_DIRECTORY");
+  QCString outputDirectory = Config_getString(OUTPUT_DIRECTORY);
   if (outputDirectory.isEmpty())
   {
     outputDirectory=QDir::currentDirPath().utf8();
@@ -2221,13 +2272,12 @@ bool PerlModGenerator::createOutputDir(QDir &perlModDir)
       dir.setPath(QDir::currentDirPath());
       if (!dir.mkdir(outputDirectory))
       {
-	err("tag OUTPUT_DIRECTORY: Output directory `%s' does not "
+	term("tag OUTPUT_DIRECTORY: Output directory '%s' does not "
 	    "exist and cannot be created\n",outputDirectory.data());
-	exit(1);
       }
       else
       {
-	msg("Notice: Output directory `%s' does not exist. "
+	msg("Notice: Output directory '%s' does not exist. "
 	    "I have created it for you.\n", outputDirectory.data());
       }
       dir.cd(outputDirectory);
@@ -2445,8 +2495,8 @@ bool PerlModGenerator::generateDoxyRules()
   if (!createOutputFile(doxyRules, pathDoxyRules))
     return false;
 
-  bool perlmodLatex = Config_getBool("PERLMOD_LATEX");
-  QCString prefix = Config_getString("PERLMOD_MAKEVAR_PREFIX");
+  bool perlmodLatex = Config_getBool(PERLMOD_LATEX);
+  QCString prefix = Config_getString(PERLMOD_MAKEVAR_PREFIX);
 
   FTextStream doxyRulesStream(&doxyRules);
   doxyRulesStream <<
@@ -2542,8 +2592,8 @@ bool PerlModGenerator::generateMakefile()
   if (!createOutputFile(makefile, pathMakefile))
     return false;
 
-  bool perlmodLatex = Config_getBool("PERLMOD_LATEX");
-  QCString prefix = Config_getString("PERLMOD_MAKEVAR_PREFIX");
+  bool perlmodLatex = Config_getBool(PERLMOD_LATEX);
+  QCString prefix = Config_getString(PERLMOD_MAKEVAR_PREFIX);
 
   FTextStream makefileStream(&makefile);
   makefileStream <<
@@ -2923,7 +2973,7 @@ void PerlModGenerator::generate()
   if (!createOutputDir(perlModDir))
     return;
 
-  bool perlmodLatex = Config_getBool("PERLMOD_LATEX");
+  bool perlmodLatex = Config_getBool(PERLMOD_LATEX);
 
   QCString perlModAbsPath = perlModDir.absPath().utf8();
   pathDoxyDocsPM = perlModAbsPath + "/DoxyDocs.pm";
@@ -2959,7 +3009,7 @@ void PerlModGenerator::generate()
 
 void generatePerlMod()
 {
-  PerlModGenerator pmg(Config_getBool("PERLMOD_PRETTY"));
+  PerlModGenerator pmg(Config_getBool(PERLMOD_PRETTY));
   pmg.generate();
 }
 
