@@ -22,6 +22,7 @@
 #include <qglobal.h>
 #include "docvisitor.h"
 #include "htmlentity.h"
+#include "emoji.h"
 #include "message.h"
 
 /*! Concrete visitor implementation for pretty printing */
@@ -68,6 +69,19 @@ class PrintDocVisitor : public DocVisitor
         printf("print: non supported HTML-entity found: %s\n",HtmlEntityMapper::instance()->html(s->symbol(),TRUE));
       }
     }
+    void visit(DocEmoji *s)
+    {
+      indent_leaf();
+      const char *res = EmojiEntityMapper::instance()->name(s->index());
+      if (res)
+      {
+        printf("%s",res);
+      }
+      else
+      {
+        printf("print: non supported emoji found: %s\n",qPrint(s->name()));
+      }
+    }
     void visit(DocURL *u)
     {
       indent_leaf();
@@ -91,6 +105,21 @@ class PrintDocVisitor : public DocVisitor
         case DocStyleChange::Bold:
           if (s->enable()) printf("<bold>"); else printf("</bold>");
           break;
+        case DocStyleChange::S:
+          if (s->enable()) printf("<s>"); else printf("</s>");
+          break;
+        case DocStyleChange::Strike:
+          if (s->enable()) printf("<strike>"); else printf("</strike>");
+          break;
+        case DocStyleChange::Del:
+          if (s->enable()) printf("<del>"); else printf("</del>");
+          break;
+        case DocStyleChange::Underline:
+          if (s->enable()) printf("<underline>"); else printf("</underline>");
+          break;
+        case DocStyleChange::Ins:
+          if (s->enable()) printf("<ins>"); else printf("</ins>");
+          break;
         case DocStyleChange::Italic:
           if (s->enable()) printf("<italic>"); else printf("</italic>");
           break;
@@ -167,7 +196,11 @@ class PrintDocVisitor : public DocVisitor
         case DocInclude::Include: printf("include"); break;
         case DocInclude::IncWithLines: printf("incwithlines"); break;
         case DocInclude::DontInclude: printf("dontinclude"); break;
-        case DocInclude::HtmlInclude: printf("htmlinclude"); break;
+        case DocInclude::DontIncWithLines: printf("dontinwithlines"); break;
+        case DocInclude::HtmlInclude:
+               printf("htmlinclude");
+               if (inc->isBlock()) printf(" block=\"yes\"");
+               break;
         case DocInclude::LatexInclude: printf("latexinclude"); break;
         case DocInclude::VerbInclude: printf("verbinclude"); break;
         case DocInclude::Snippet: printf("snippet"); break;
@@ -490,7 +523,7 @@ class PrintDocVisitor : public DocVisitor
         case DocImage::Rtf:     printf("rtf"); break;
         case DocImage::DocBook: printf("docbook"); break;
       }
-      printf("\" %s %s>\n",img->width().data(),img->height().data());
+      printf("\" %s %s inline=\"%s\">\n",img->width().data(),img->height().data(),img->isInlineImage() ? "yes" : "no");
     }
     void visitPost(DocImage *) 
     {
@@ -592,16 +625,24 @@ class PrintDocVisitor : public DocVisitor
       //const char *s;
       DocNode *param;
       printf("<parameters>");
-      for (sli.toFirst();(param=sli.current());++sli)
+      if (sli.count() > 0)
       {
         printf("<param>");
-        if (param->kind()==DocNode::Kind_Word)
+        for (sli.toFirst();(param=sli.current());++sli)
         {
-          visit((DocWord*)param); 
-        }
-        else if (param->kind()==DocNode::Kind_LinkedWord)
-        {
-          visit((DocLinkedWord*)param); 
+          if (param->kind()==DocNode::Kind_Word)
+          {
+            visit((DocWord*)param);
+          }
+          else if (param->kind()==DocNode::Kind_LinkedWord)
+          {
+            visit((DocLinkedWord*)param);
+          }
+          else if (param->kind()==DocNode::Kind_Sep)
+          {
+            printf("</param>");
+            printf("<param>");
+          }
         }
         printf("</param>");
       }
@@ -634,13 +675,13 @@ class PrintDocVisitor : public DocVisitor
     void visitPre(DocXRefItem *x)
     {
       indent_pre();
-      printf("<xrefitem file=\"%s\" anchor=\"%s\" title=\"%s\"/>\n",
+      printf("<xrefitem file=\"%s\" anchor=\"%s\" title=\"%s\">\n",
           x->file().data(),x->anchor().data(),x->title().data());
     }
     void visitPost(DocXRefItem *)
     {
       indent_post();
-      printf("<xrefitem/>\n");
+      printf("</xrefitem>\n");
     }
     void visitPre(DocInternalRef *r)
     {
@@ -652,16 +693,6 @@ class PrintDocVisitor : public DocVisitor
       indent_post();
       printf("</internalref>\n");
     }
-    void visitPre(DocCopy *c)
-    {
-      indent_pre();
-      printf("<copy link=\"%s\">\n",c->link().data());
-    }
-    void visitPost(DocCopy *)
-    {
-      indent_post();
-      printf("</copy>\n");
-    }
     void visitPre(DocText *)
     {
       indent_pre();
