@@ -3,7 +3,7 @@
  * 
  *
  *
- * Copyright (C) 1997-2014 by Dimitri van Heesch.
+ * Copyright (C) 1997-2015 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -20,6 +20,7 @@
 #include "reflist.h"
 #include "util.h"
 #include "ftextstream.h"
+#include "definition.h"
 
 /*! Create a list of items that are cross referenced with documentation blocks
  *  @param listName String representing the name of the list.
@@ -36,6 +37,7 @@ RefList::RefList(const char *listName,
   m_dictIterator = 0;
   m_id = 0;
   m_listName = listName;
+  m_fileName = convertNameToFile(listName,FALSE,TRUE);
   m_pageTitle = pageTitle;
   m_secTitle = secTitle;
 }
@@ -98,6 +100,11 @@ QCString RefList::listName() const
   return m_listName;
 }
 
+QCString RefList::fileName() const
+{
+  return m_fileName;
+}
+
 QCString RefList::pageTitle() const
 {
   return m_pageTitle;
@@ -124,7 +131,15 @@ void RefList::insertIntoList(const char *key,RefItem *item)
   {
     if (ri!=item)
     {
-      ri->extraItems.append(item);
+      // We also have to check if the item is not already in the "extra" list
+      QListIterator<RefItem> li(ri->extraItems);
+      RefItem *extraItem;
+      bool doubleItem = false;
+      for (li.toFirst();(extraItem=li.current());++li)
+      {
+        if (item == extraItem) doubleItem = true;
+      }
+      if (!doubleItem) ri->extraItems.append(item);
     }
   }
 }
@@ -141,31 +156,56 @@ void RefList::generatePage()
   for (it.toFirst();(item=it.current());++it)
   {
     doc += " <dt>";
-    doc +=  "\\anchor ";
-    doc += item->listAnchor;
     doc += "\n";
+    if (item->scope)
+    {
+      if (item->scope->name() != "<globalScope>")
+      {
+        doc += "\\_setscope ";
+        doc += item->scope->name();
+        doc += " ";
+      }
+    }
     doc += item->prefix;
     doc += " \\_internalref ";
     doc += item->name;
-    doc += " \"";
-    doc += item->title;
-    doc += "\" ";
+    // escape \'s in title, see issue #5901
+    QCString escapedTitle = substitute(item->title,"\\","\\\\");
+    if (item->scope &&
+        (item->scope->definitionType()==Definition::TypeClass ||
+         item->scope->definitionType()==Definition::TypeNamespace ||
+         item->scope->definitionType()==Definition::TypeMember ||
+         item->scope->definitionType()==Definition::TypePackage)
+       )
+    {
+      // prevent Obj-C names in e.g. todo list are seen as emoji
+      escapedTitle = substitute(escapedTitle,":","&Colon;");
+    }
+    doc += " \""+escapedTitle+"\" ";
     // write declaration in case a function with arguments
     if (!item->args.isEmpty()) 
     {
-      doc += item->args;
+      // escape @'s in argument list, needed for Java annotations (see issue #6208)
+      // escape \'s in argument list (see issue #6533)
+      doc += substitute(substitute(item->args,"@","@@"),"\\","\\\\");
     }
-    doc += "</dt><dd> ";
+    doc += "</dt><dd> \\anchor ";
+    doc += item->listAnchor;
+    doc += " ";
     doc += item->text;
     QListIterator<RefItem> li(item->extraItems);
     RefItem *extraItem;
     for (li.toFirst();(extraItem=li.current());++li)
     {
-      doc += "<p>" + extraItem->text;
+      doc += "<p> \\anchor ";
+      doc += extraItem->listAnchor;
+      doc += " ";
+      doc += extraItem->text;
     }
     doc += "</dd>";
   }
   doc += "</dl>\n";
-  addRelatedPage(m_listName,m_pageTitle,doc,0,m_listName,1,0,0,0);
+  //printf("generatePage('%s')\n",doc.data());
+  addRelatedPage(m_listName,m_pageTitle,doc,m_fileName,1,std::vector<ListItemInfo>(),0,0,TRUE);
 }
 
