@@ -18,8 +18,11 @@
 
 #include "tagreader.h"
 
+#include <assert.h>
 #include <stdio.h>
 #include <stdarg.h>
+#include <algorithm>
+
 
 #include <qxml.h>
 #include <qstack.h>
@@ -27,7 +30,7 @@
 #include <qfileinfo.h>
 #include <qlist.h>
 #include <qstring.h>
-#include <qstringlist.h>
+#include <qcstringlist.h>
 
 #include "entry.h"
 #include "classdef.h"
@@ -39,6 +42,7 @@
 #include "filedef.h"
 #include "filename.h"
 #include "section.h"
+#include "groupdef.h"
 
 /** Information about an linkable anchor */
 class TagAnchorInfo
@@ -95,17 +99,18 @@ class TagMemberInfo
 class TagClassInfo
 {
   public:
-    enum Kind { Class, Struct, Union, Interface, Exception, Protocol, Category, Enum, Service, Singleton };
-    TagClassInfo() { bases=0, templateArguments=0; members.setAutoDelete(TRUE); isObjC=FALSE; }
-   ~TagClassInfo() { delete bases; delete templateArguments; }
+    enum Kind { None=-1, Class, Struct, Union, Interface, Exception, Protocol, Category, Enum, Service, Singleton };
+    TagClassInfo() { templateArguments=0; members.setAutoDelete(TRUE); isObjC=FALSE; kind = None; }
+   ~TagClassInfo() { delete templateArguments; }
     QCString name;
     QCString filename;
     QCString clangId;
+    QCString anchor;
     TagAnchorInfoList docAnchors;
-    QList<BaseInfo> *bases;
+    std::vector<BaseInfo> bases;
     QList<TagMemberInfo> members;
     QList<QCString> *templateArguments;
-    QStringList classList;
+    QCStringList classList;
     Kind kind;
     bool isObjC;
 };
@@ -118,8 +123,8 @@ class TagNamespaceInfo
     QCString name;
     QCString filename;
     QCString clangId;
-    QStringList classList;
-    QStringList namespaceList;
+    QCStringList classList;
+    QCStringList namespaceList;
     TagAnchorInfoList docAnchors;
     QList<TagMemberInfo> members;
 };
@@ -133,7 +138,7 @@ class TagPackageInfo
     QCString filename;
     TagAnchorInfoList docAnchors;
     QList<TagMemberInfo> members;
-    QStringList classList;
+    QCStringList classList;
 };
 
 /** Container for include info that can be read from a tagfile */
@@ -157,8 +162,8 @@ class TagFileInfo
     QCString filename;
     TagAnchorInfoList docAnchors;
     QList<TagMemberInfo> members;
-    QStringList classList;
-    QStringList namespaceList;
+    QCStringList classList;
+    QCStringList namespaceList;
     QList<TagIncludeInfo> includes;
 };
 
@@ -172,12 +177,12 @@ class TagGroupInfo
     QCString filename;
     TagAnchorInfoList docAnchors;
     QList<TagMemberInfo> members;
-    QStringList subgroupList;
-    QStringList classList;
-    QStringList namespaceList;
-    QStringList fileList;
-    QStringList pageList;
-    QStringList dirList;
+    QCStringList subgroupList;
+    QCStringList classList;
+    QCStringList namespaceList;
+    QCStringList fileList;
+    QCStringList pageList;
+    QCStringList dirList;
 };
 
 /** Container for page specific info that can be read from a tagfile */
@@ -197,8 +202,8 @@ class TagDirInfo
     QCString name;
     QCString filename;
     QCString path;
-    QStringList subdirList;
-    QStringList fileList;
+    QCStringList subdirList;
+    QCStringList fileList;
     TagAnchorInfoList docAnchors;
 };
 
@@ -381,7 +386,7 @@ class TagFileParser : public QXmlDefaultHandler
       }
       else
       {
-        warn("Unknown compound attribute `%s' found!\n",kind.data());
+        warn("Unknown compound attribute '%s' found!",kind.data());
         m_state = Invalid;
       }
       if (isObjC=="yes" && m_curClass)
@@ -409,7 +414,7 @@ class TagFileParser : public QXmlDefaultHandler
         case InPackage:   m_tagFilePackages.append(m_curPackage); 
                           m_curPackage=0; break; 
         default:
-                          warn("tag `compound' was not expected!\n");
+                          warn("tag 'compound' was not expected!");
       }
     }
 
@@ -455,7 +460,7 @@ class TagFileParser : public QXmlDefaultHandler
         case InNamespace: m_curNamespace->members.append(m_curMember); break;
         case InGroup:     m_curGroup->members.append(m_curMember); break;
         case InPackage:   m_curPackage->members.append(m_curMember); break;
-        default:   warn("Unexpected tag `member' found\n"); break; 
+        default:   warn("Unexpected tag 'member' found"); break; 
       }
     }
 
@@ -473,7 +478,7 @@ class TagFileParser : public QXmlDefaultHandler
       }
       else
       {
-        warn("Found enumvalue tag outside of member tag\n");
+        warn("Found 'enumvalue' tag outside of member tag");
       }
     }
 
@@ -491,17 +496,34 @@ class TagFileParser : public QXmlDefaultHandler
 
     void endDocAnchor()
     {
+      // Check whether or not the tag is automatically generate, in that case ignore the tag.
       switch(m_state)
       {
-        case InClass:     m_curClass->docAnchors.append(new TagAnchorInfo(m_fileName,m_curString)); break;
-        case InFile:      m_curFile->docAnchors.append(new TagAnchorInfo(m_fileName,m_curString)); break;
-        case InNamespace: m_curNamespace->docAnchors.append(new TagAnchorInfo(m_fileName,m_curString)); break;
-        case InGroup:     m_curGroup->docAnchors.append(new TagAnchorInfo(m_fileName,m_curString)); break;
+        case InClass:
+        case InFile:
+        case InNamespace:
+        case InGroup:
+        case InPage:
+        case InMember:
+        case InPackage:
+        case InDir:
+          if (QString(m_curString).startsWith("autotoc_md")) return;
+          break;
+        default:
+          warn("Unexpected tag 'docanchor' found");
+          return;
+      }
+      switch(m_state)
+      {
+        case InClass:     m_curClass->docAnchors.append(new TagAnchorInfo(m_fileName,m_curString,m_title)); break;
+        case InFile:      m_curFile->docAnchors.append(new TagAnchorInfo(m_fileName,m_curString,m_title)); break;
+        case InNamespace: m_curNamespace->docAnchors.append(new TagAnchorInfo(m_fileName,m_curString,m_title)); break;
+        case InGroup:     m_curGroup->docAnchors.append(new TagAnchorInfo(m_fileName,m_curString,m_title)); break;
         case InPage:      m_curPage->docAnchors.append(new TagAnchorInfo(m_fileName,m_curString,m_title)); break;
-        case InMember:    m_curMember->docAnchors.append(new TagAnchorInfo(m_fileName,m_curString)); break;
-        case InPackage:   m_curPackage->docAnchors.append(new TagAnchorInfo(m_fileName,m_curString)); break;
-        case InDir:       m_curDir->docAnchors.append(new TagAnchorInfo(m_fileName,m_curString)); break;
-        default:   warn("Unexpected tag `member' found\n"); break; 
+        case InMember:    m_curMember->docAnchors.append(new TagAnchorInfo(m_fileName,m_curString,m_title)); break;
+        case InPackage:   m_curPackage->docAnchors.append(new TagAnchorInfo(m_fileName,m_curString,m_title)); break;
+        case InDir:       m_curDir->docAnchors.append(new TagAnchorInfo(m_fileName,m_curString,m_title)); break;
+        default: break; // will not be reached
       }
     }
 
@@ -514,7 +536,7 @@ class TagFileParser : public QXmlDefaultHandler
         case InNamespace: m_curNamespace->classList.append(m_curString); break;
         case InGroup:     m_curGroup->classList.append(m_curString); break;
         case InPackage:   m_curPackage->classList.append(m_curString); break;
-        default:   warn("Unexpected tag `class' found\n"); break; 
+        default:   warn("Unexpected tag 'class' found"); break; 
       }
     }
 
@@ -525,7 +547,7 @@ class TagFileParser : public QXmlDefaultHandler
         case InNamespace: m_curNamespace->classList.append(m_curString); break;
         case InFile:      m_curFile->namespaceList.append(m_curString); break;
         case InGroup:     m_curGroup->namespaceList.append(m_curString); break;
-        default:   warn("Unexpected tag `namespace' found\n"); break; 
+        default:   warn("Unexpected tag 'namespace' found"); break; 
       }
     }
 
@@ -535,7 +557,7 @@ class TagFileParser : public QXmlDefaultHandler
       {
         case InGroup:      m_curGroup->fileList.append(m_curString); break;
         case InDir:        m_curDir->fileList.append(m_curString); break;
-        default:   warn("Unexpected tag `file' found\n"); break; 
+        default:   warn("Unexpected tag 'file' found"); break; 
       }
     }
 
@@ -544,7 +566,7 @@ class TagFileParser : public QXmlDefaultHandler
       switch(m_state)
       {
         case InGroup:      m_curGroup->fileList.append(m_curString); break;
-        default:   warn("Unexpected tag `page' found\n"); break; 
+        default:   warn("Unexpected tag 'page' found"); break; 
       }
     }
 
@@ -553,7 +575,7 @@ class TagFileParser : public QXmlDefaultHandler
       switch(m_state)
       {
         case InDir:      m_curDir->subdirList.append(m_curString); break;
-        default:   warn("Unexpected tag `page' found\n"); break; 
+        default:   warn("Unexpected tag 'dir' found"); break; 
       }
     }
 
@@ -577,7 +599,7 @@ class TagFileParser : public QXmlDefaultHandler
       }
       else
       {
-        warn("Unexpected tag `type' found\n");
+        warn("Unexpected tag 'type' found");
       }
     }
 
@@ -593,7 +615,7 @@ class TagFileParser : public QXmlDefaultHandler
         case InDir:       m_curDir->name       = m_curString; break;
         case InMember:    m_curMember->name    = m_curString; break;
         case InPackage:   m_curPackage->name   = m_curString; break;
-        default: warn("Unexpected tag `name' found\n"); break; 
+        default: warn("Unexpected tag 'name' found"); break; 
       }
     }
 
@@ -618,16 +640,11 @@ class TagFileParser : public QXmlDefaultHandler
         {
           virt = Virtual;
         }
-        if (m_curClass->bases==0) 
-        {
-          m_curClass->bases = new QList<BaseInfo>;
-          m_curClass->bases->setAutoDelete(TRUE);
-        }
-        m_curClass->bases->append(new BaseInfo(m_curString,prot,virt));
+        m_curClass->bases.push_back(BaseInfo(m_curString,prot,virt));
       }
       else
       {
-        warn("Unexpected tag `base' found\n");
+        warn("Unexpected tag 'base' found");
       }
     }
 
@@ -635,11 +652,11 @@ class TagFileParser : public QXmlDefaultHandler
     {
       if (m_state==InClass && m_curClass)
       {
-        m_curClass->bases->getLast()->name = m_curString;
+        m_curClass->bases.back().name = m_curString;
       }
       else
       {
-        warn("Unexpected tag `base' found\n");
+        warn("Unexpected tag 'base' found");
       }
     }
 
@@ -656,7 +673,7 @@ class TagFileParser : public QXmlDefaultHandler
       }
       else
       {
-        warn("Unexpected tag `includes' found\n");
+        warn("Unexpected tag 'includes' found");
       }
       m_curString="";
     }
@@ -679,7 +696,7 @@ class TagFileParser : public QXmlDefaultHandler
       }
       else
       {
-        warn("Unexpected tag `templarg' found\n");
+        warn("Unexpected tag 'templarg' found");
       }
     }
 
@@ -694,7 +711,7 @@ class TagFileParser : public QXmlDefaultHandler
         case InPage:      m_curPage->filename      = m_curString;    break;
         case InPackage:   m_curPackage->filename   = m_curString;    break;
         case InDir:       m_curDir->filename       = m_curString;    break;
-        default: warn("Unexpected tag `filename' found\n"); break; 
+        default: warn("Unexpected tag 'filename' found"); break; 
       }
     }
 
@@ -704,7 +721,7 @@ class TagFileParser : public QXmlDefaultHandler
       {
         case InFile:      m_curFile->path          = m_curString;    break;
         case InDir:       m_curDir->path           = m_curString;    break;
-        default: warn("Unexpected tag `path' found\n");     break; 
+        default: warn("Unexpected tag 'path' found");     break; 
       }
     }
     
@@ -714,9 +731,13 @@ class TagFileParser : public QXmlDefaultHandler
       {
         m_curMember->anchor = m_curString; 
       }
+      else if (m_state==InClass)
+      {
+        m_curClass->anchor = m_curString; 
+      }
       else
       {
-        warn("Unexpected tag `anchor' found\n");
+        warn("Unexpected tag 'anchor' found");
       }
     }
 
@@ -736,7 +757,7 @@ class TagFileParser : public QXmlDefaultHandler
       }
       else
       {
-        warn("warning: Unexpected tag `anchor' found\n");
+        warn("Unexpected tag 'clangid' found");
       }
     }
 
@@ -750,7 +771,7 @@ class TagFileParser : public QXmlDefaultHandler
       }
       else
       {
-        warn("Unexpected tag `anchorfile' found\n");
+        warn("Unexpected tag 'anchorfile' found");
       }
     }
     
@@ -762,7 +783,7 @@ class TagFileParser : public QXmlDefaultHandler
       }
       else
       {
-        warn("Unexpected tag `arglist' found\n");
+        warn("Unexpected tag 'arglist' found");
       }
     }
     void endTitle()
@@ -771,7 +792,7 @@ class TagFileParser : public QXmlDefaultHandler
       {
         case InGroup:     m_curGroup->title     = m_curString;    break;
         case InPage:      m_curPage->title      = m_curString;    break;
-        default: warn("Unexpected tag `title' found\n"); break; 
+        default: warn("Unexpected tag 'title' found"); break; 
       }
     }
 
@@ -783,7 +804,7 @@ class TagFileParser : public QXmlDefaultHandler
       }
       else
       {
-        warn("Unexpected tag `subgroup' found\n");
+        warn("Unexpected tag 'subgroup' found");
       }
     }
 
@@ -870,7 +891,7 @@ class TagFileParser : public QXmlDefaultHandler
     bool startElement( const QString&, const QString&, 
                        const QString&name, const QXmlAttributes& attrib )
     {
-      //printf("startElement `%s'\n",name.data());
+      //printf("startElement '%s'\n",name.data());
       StartElementHandler *handler = m_startElementHandlers[name.utf8()];
       if (handler)
       {
@@ -878,14 +899,14 @@ class TagFileParser : public QXmlDefaultHandler
       }
       else 
       {
-        warn("Unknown tag `%s' found!\n",name.data());
+        warn("Unknown tag '%s' found!",name.data());
       }
       return TRUE;
     }
 
     bool endElement( const QString&, const QString&, const QString& name )
     {
-      //printf("endElement `%s'\n",name.data());
+      //printf("endElement '%s'\n",name.data());
       EndElementHandler *handler = m_endElementHandlers[name.utf8()];
       if (handler)
       {
@@ -893,7 +914,7 @@ class TagFileParser : public QXmlDefaultHandler
       }
       else 
       {
-        warn("Unknown tag `%s' found!\n",name.data());
+        warn("Unknown tag '%s' found!",name.data());
       }
       return TRUE;
     }
@@ -905,12 +926,12 @@ class TagFileParser : public QXmlDefaultHandler
     }
 
     void dump();
-    void buildLists(Entry *root);
+    void buildLists(const std::shared_ptr<Entry> &root);
     void addIncludes();
     
   private:
-    void buildMemberList(Entry *ce,QList<TagMemberInfo> &members);
-    void addDocAnchors(Entry *e,const TagAnchorInfoList &l);
+    void buildMemberList(const std::shared_ptr<Entry> &ce,QList<TagMemberInfo> &members);
+    void addDocAnchors(const std::shared_ptr<Entry> &e,const TagAnchorInfoList &l);
     QList<TagClassInfo>        m_tagFileClasses;
     QList<TagFileInfo>         m_tagFileFiles;
     QList<TagNamespaceInfo>    m_tagFileNamespaces;
@@ -979,16 +1000,11 @@ void TagFileParser::dump()
   TagClassInfo *cd;
   for (;(cd=lci.current());++lci)
   {
-    msg("class `%s'\n",cd->name.data());
-    msg("  filename `%s'\n",cd->filename.data());
-    if (cd->bases)
+    msg("class '%s'\n",cd->name.data());
+    msg("  filename '%s'\n",cd->filename.data());
+    for (const BaseInfo &bi : cd->bases)
     {
-      QListIterator<BaseInfo> bii(*cd->bases);
-      BaseInfo *bi;
-      for ( bii.toFirst() ; (bi=bii.current()) ; ++bii) 
-      {
-        msg( "  base: %s \n", bi->name.data() );
-      }
+      msg( "  base: %s \n", bi.name.data() );
     }
 
     QListIterator<TagMemberInfo> mci(cd->members);
@@ -996,10 +1012,10 @@ void TagFileParser::dump()
     for (;(md=mci.current());++mci)
     {
       msg("  member:\n");
-      msg("    kind: `%s'\n",md->kind.data());
-      msg("    name: `%s'\n",md->name.data());
-      msg("    anchor: `%s'\n",md->anchor.data());
-      msg("    arglist: `%s'\n",md->arglist.data());
+      msg("    kind: '%s'\n",md->kind.data());
+      msg("    name: '%s'\n",md->name.data());
+      msg("    anchor: '%s'\n",md->anchor.data());
+      msg("    arglist: '%s'\n",md->arglist.data());
     }
   }
   //============== NAMESPACES
@@ -1007,13 +1023,13 @@ void TagFileParser::dump()
   TagNamespaceInfo *nd;
   for (;(nd=lni.current());++lni)
   {
-    msg("namespace `%s'\n",nd->name.data());
-    msg("  filename `%s'\n",nd->filename.data());
-    QStringList::Iterator it;
+    msg("namespace '%s'\n",nd->name.data());
+    msg("  filename '%s'\n",nd->filename.data());
+    QCStringList::Iterator it;
     for ( it = nd->classList.begin(); 
         it != nd->classList.end(); ++it ) 
     {
-      msg( "  class: %s \n", (*it).latin1() );
+      msg( "  class: %s \n", (*it).data() );
     }
 
     QListIterator<TagMemberInfo> mci(nd->members);
@@ -1021,10 +1037,10 @@ void TagFileParser::dump()
     for (;(md=mci.current());++mci)
     {
       msg("  member:\n");
-      msg("    kind: `%s'\n",md->kind.data());
-      msg("    name: `%s'\n",md->name.data());
-      msg("    anchor: `%s'\n",md->anchor.data());
-      msg("    arglist: `%s'\n",md->arglist.data());
+      msg("    kind: '%s'\n",md->kind.data());
+      msg("    name: '%s'\n",md->name.data());
+      msg("    anchor: '%s'\n",md->anchor.data());
+      msg("    arglist: '%s'\n",md->arglist.data());
     }
   }
   //============== FILES
@@ -1032,18 +1048,18 @@ void TagFileParser::dump()
   TagFileInfo *fd;
   for (;(fd=lfi.current());++lfi)
   {
-    msg("file `%s'\n",fd->name.data());
-    msg("  filename `%s'\n",fd->filename.data());
-    QStringList::Iterator it;
+    msg("file '%s'\n",fd->name.data());
+    msg("  filename '%s'\n",fd->filename.data());
+    QCStringList::Iterator it;
     for ( it = fd->namespaceList.begin(); 
         it != fd->namespaceList.end(); ++it ) 
     {
-      msg( "  namespace: %s \n", (*it).latin1() );
+      msg( "  namespace: %s \n", (*it).data() );
     }
     for ( it = fd->classList.begin(); 
         it != fd->classList.end(); ++it ) 
     {
-      msg( "  class: %s \n", (*it).latin1() );
+      msg( "  class: %s \n", (*it).data() );
     }
 
     QListIterator<TagMemberInfo> mci(fd->members);
@@ -1051,10 +1067,10 @@ void TagFileParser::dump()
     for (;(md=mci.current());++mci)
     {
       msg("  member:\n");
-      msg("    kind: `%s'\n",md->kind.data());
-      msg("    name: `%s'\n",md->name.data());
-      msg("    anchor: `%s'\n",md->anchor.data());
-      msg("    arglist: `%s'\n",md->arglist.data());
+      msg("    kind: '%s'\n",md->kind.data());
+      msg("    name: '%s'\n",md->name.data());
+      msg("    anchor: '%s'\n",md->anchor.data());
+      msg("    arglist: '%s'\n",md->arglist.data());
     }
 
     QListIterator<TagIncludeInfo> mii(fd->includes);
@@ -1070,33 +1086,33 @@ void TagFileParser::dump()
   TagGroupInfo *gd;
   for (;(gd=lgi.current());++lgi)
   {
-    msg("group `%s'\n",gd->name.data());
-    msg("  filename `%s'\n",gd->filename.data());
-    QStringList::Iterator it;
+    msg("group '%s'\n",gd->name.data());
+    msg("  filename '%s'\n",gd->filename.data());
+    QCStringList::Iterator it;
     for ( it = gd->namespaceList.begin(); 
         it != gd->namespaceList.end(); ++it ) 
     {
-      msg( "  namespace: %s \n", (*it).latin1() );
+      msg( "  namespace: %s \n", (*it).data() );
     }
     for ( it = gd->classList.begin(); 
         it != gd->classList.end(); ++it ) 
     {
-      msg( "  class: %s \n", (*it).latin1() );
+      msg( "  class: %s \n", (*it).data() );
     }
     for ( it = gd->fileList.begin(); 
         it != gd->fileList.end(); ++it ) 
     {
-      msg( "  file: %s \n", (*it).latin1() );
+      msg( "  file: %s \n", (*it).data() );
     }
     for ( it = gd->subgroupList.begin(); 
         it != gd->subgroupList.end(); ++it ) 
     {
-      msg( "  subgroup: %s \n", (*it).latin1() );
+      msg( "  subgroup: %s \n", (*it).data() );
     }
     for ( it = gd->pageList.begin(); 
         it != gd->pageList.end(); ++it ) 
     {
-      msg( "  page: %s \n", (*it).latin1() );
+      msg( "  page: %s \n", (*it).data() );
     }
 
     QListIterator<TagMemberInfo> mci(gd->members);
@@ -1104,10 +1120,10 @@ void TagFileParser::dump()
     for (;(md=mci.current());++mci)
     {
       msg("  member:\n");
-      msg("    kind: `%s'\n",md->kind.data());
-      msg("    name: `%s'\n",md->name.data());
-      msg("    anchor: `%s'\n",md->anchor.data());
-      msg("    arglist: `%s'\n",md->arglist.data());
+      msg("    kind: '%s'\n",md->kind.data());
+      msg("    name: '%s'\n",md->name.data());
+      msg("    anchor: '%s'\n",md->anchor.data());
+      msg("    arglist: '%s'\n",md->arglist.data());
     }
   }
   //============== PAGES
@@ -1115,32 +1131,32 @@ void TagFileParser::dump()
   TagPageInfo *pd;
   for (;(pd=lpi.current());++lpi)
   {
-    msg("page `%s'\n",pd->name.data());
-    msg("  title `%s'\n",pd->title.data());
-    msg("  filename `%s'\n",pd->filename.data());
+    msg("page '%s'\n",pd->name.data());
+    msg("  title '%s'\n",pd->title.data());
+    msg("  filename '%s'\n",pd->filename.data());
   }
   //============== DIRS
   QListIterator<TagDirInfo> ldi(m_tagFileDirs);
   TagDirInfo *dd;
   for (;(dd=ldi.current());++ldi)
   {
-    msg("dir `%s'\n",dd->name.data());
-    msg("  path `%s'\n",dd->path.data());
-    QStringList::Iterator it;
+    msg("dir '%s'\n",dd->name.data());
+    msg("  path '%s'\n",dd->path.data());
+    QCStringList::Iterator it;
     for ( it = dd->fileList.begin(); 
         it != dd->fileList.end(); ++it ) 
     {
-      msg( "  file: %s \n", (*it).latin1() );
+      msg( "  file: %s \n", (*it).data() );
     }
     for ( it = dd->subdirList.begin(); 
         it != dd->subdirList.end(); ++it ) 
     {
-      msg( "  subdir: %s \n", (*it).latin1() );
+      msg( "  subdir: %s \n", (*it).data() );
     }
   }
 }
 
-void TagFileParser::addDocAnchors(Entry *e,const TagAnchorInfoList &l)
+void TagFileParser::addDocAnchors(const std::shared_ptr<Entry> &e,const TagAnchorInfoList &l)
 {
   QListIterator<TagAnchorInfo> tli(l);
   TagAnchorInfo *ta;
@@ -1153,30 +1169,28 @@ void TagFileParser::addDocAnchors(Entry *e,const TagAnchorInfoList &l)
       SectionInfo *si=new SectionInfo(ta->fileName,-1,ta->label,ta->title,
           SectionInfo::Anchor,0,m_tagName);
       Doxygen::sectionDict->append(ta->label,si);
-      e->anchors->append(si);
+      e->anchors.push_back(si);
     }
     else
     {
-      warn("Duplicate anchor %s found\n",ta->label.data());
+      warn("Duplicate anchor %s found",ta->label.data());
     }
   }
 }
 
-void TagFileParser::buildMemberList(Entry *ce,QList<TagMemberInfo> &members)
+void TagFileParser::buildMemberList(const std::shared_ptr<Entry> &ce,QList<TagMemberInfo> &members)
 {
   QListIterator<TagMemberInfo> mii(members);
   TagMemberInfo *tmi;
   for (;(tmi=mii.current());++mii)
   {
-    Entry *me      = new Entry;
+    std::shared_ptr<Entry> me = std::make_shared<Entry>();
     me->type       = tmi->type;
     me->name       = tmi->name;
     me->args       = tmi->arglist;
     if (!me->args.isEmpty())
     {
-      delete me->argList;
-      me->argList = new ArgumentList;
-      stringToArgumentList(me->args,me->argList);
+      stringToArgumentList(SrcLangExt_Cpp,me->args,me->argList);
     }
     if (tmi->enumValues.count()>0)
     {
@@ -1185,17 +1199,16 @@ void TagFileParser::buildMemberList(Entry *ce,QList<TagMemberInfo> &members)
       TagEnumValueInfo *evi;
       for (evii.toFirst();(evi=evii.current());++evii)
       {
-        Entry *ev      = new Entry;
+        std::shared_ptr<Entry> ev = std::make_shared<Entry>();
         ev->type       = "@";
         ev->name       = evi->name;
         ev->id         = evi->clangid;
         ev->section    = Entry::VARIABLE_SEC;
-        TagInfo *ti    = new TagInfo;
-        ti->tagName    = m_tagName;
-        ti->anchor     = evi->anchor;
-        ti->fileName   = evi->file;
-        ev->tagInfo    = ti;
-        me->addSubEntry(ev);
+        ev->tagInfoData.tagName    = m_tagName;
+        ev->tagInfoData.anchor     = evi->anchor;
+        ev->tagInfoData.fileName   = evi->file;
+        ev->hasTagInfo    = TRUE;
+        me->moveToSubEntryAndKeep(ev);
       }
     }
     me->protection = tmi->prot;
@@ -1205,14 +1218,13 @@ void TagFileParser::buildMemberList(Entry *ce,QList<TagMemberInfo> &members)
     me->id         = tmi->clangId;
     if (ce->section == Entry::GROUPDOC_SEC)
     {
-      me->groups->append(new Grouping(ce->name,Grouping::GROUPING_INGROUP));
+      me->groups.push_back(Grouping(ce->name,Grouping::GROUPING_INGROUP));
     }
     addDocAnchors(me,tmi->docAnchors);
-    TagInfo *ti    = new TagInfo;
-    ti->tagName    = m_tagName;
-    ti->anchor     = tmi->anchor;
-    ti->fileName   = tmi->anchorFile;
-    me->tagInfo    = ti;
+    me->tagInfoData.tagName    = m_tagName;
+    me->tagInfoData.anchor     = tmi->anchor;
+    me->tagInfoData.fileName   = tmi->anchorFile;
+    me->hasTagInfo    = TRUE;
     if (tmi->kind=="define")
     {
       me->type="#define";
@@ -1280,7 +1292,7 @@ void TagFileParser::buildMemberList(Entry *ce,QList<TagMemberInfo> &members)
       me->section = Entry::FUNCTION_SEC;
       me->mtype = Slot;
     }
-    ce->addSubEntry(me);
+    ce->moveToSubEntryAndKeep(me);
   }
 }
 
@@ -1301,14 +1313,14 @@ static QCString stripPath(const QCString &s)
  *  This tree contains the information extracted from the input in a 
  *  "unrelated" form.
  */
-void TagFileParser::buildLists(Entry *root)
+void TagFileParser::buildLists(const std::shared_ptr<Entry> &root)
 {
   // build class list
   QListIterator<TagClassInfo> cit(m_tagFileClasses);
   TagClassInfo *tci;
   for (cit.toFirst();(tci=cit.current());++cit)
   {
-    Entry *ce = new Entry;
+    std::shared_ptr<Entry> ce = std::make_shared<Entry>();
     ce->section = Entry::CLASS_SEC;
     switch (tci->kind)
     {
@@ -1322,6 +1334,9 @@ void TagFileParser::buildLists(Entry *root)
       case TagClassInfo::Category:  ce->spec = Entry::Category;  break;
       case TagClassInfo::Service:   ce->spec = Entry::Service;   break;
       case TagClassInfo::Singleton: ce->spec = Entry::Singleton; break;
+      case TagClassInfo::None:      // should never happen, means not properly initialized
+        assert(tci->kind != TagClassInfo::None);
+        break;
     }
     ce->name     = tci->name;
     if (tci->kind==TagClassInfo::Protocol)
@@ -1329,41 +1344,32 @@ void TagFileParser::buildLists(Entry *root)
       ce->name+="-p";
     }
     addDocAnchors(ce,tci->docAnchors);
-    TagInfo *ti  = new TagInfo;
-    ti->tagName  = m_tagName;
-    ti->fileName = tci->filename;
+    ce->tagInfoData.tagName  = m_tagName;
+    ce->tagInfoData.anchor   = tci->anchor;
+    ce->tagInfoData.fileName = tci->filename;
+    ce->hasTagInfo  = TRUE;
     ce->id       = tci->clangId;
-    ce->tagInfo  = ti;
     ce->lang     = tci->isObjC ? SrcLangExt_ObjC : SrcLangExt_Unknown;
     // transfer base class list
-    if (tci->bases)
-    {
-      delete ce->extends;
-      ce->extends = tci->bases; tci->bases = 0;
-    }
+    ce->extends  = tci->bases;
+    tci->bases.clear();
     if (tci->templateArguments)
     {
-      if (ce->tArgLists==0)
-      {
-        ce->tArgLists = new QList<ArgumentList>;
-        ce->tArgLists->setAutoDelete(TRUE);
-      }
-      ArgumentList *al = new ArgumentList;
-      ce->tArgLists->append(al);
-
+      ArgumentList al;
       QListIterator<QCString> sli(*tci->templateArguments);
       QCString *argName;
       for (;(argName=sli.current());++sli)
       {
-        Argument *a = new Argument;
-        a->type = "class";
-        a->name = *argName;
-        al->append(a);
+        Argument a;
+        a.type = "class";
+        a.name = *argName;
+        al.push_back(a);
       }
+      ce->tArgLists.push_back(al);
     }
 
     buildMemberList(ce,tci->members);
-    root->addSubEntry(ce);
+    root->moveToSubEntryAndKeep(ce);
   }
 
   // build file list
@@ -1371,19 +1377,18 @@ void TagFileParser::buildLists(Entry *root)
   TagFileInfo *tfi;
   for (fit.toFirst();(tfi=fit.current());++fit)
   {
-    Entry *fe = new Entry;
+    std::shared_ptr<Entry> fe = std::make_shared<Entry>();
     fe->section = guessSection(tfi->name);
     fe->name     = tfi->name;
     addDocAnchors(fe,tfi->docAnchors);
-    TagInfo *ti  = new TagInfo;
-    ti->tagName  = m_tagName;
-    ti->fileName = tfi->filename;
-    fe->tagInfo  = ti;
-    
+    fe->tagInfoData.tagName  = m_tagName;
+    fe->tagInfoData.fileName = tfi->filename;
+    fe->hasTagInfo = TRUE;
+
     QCString fullName = m_tagName+":"+tfi->path+stripPath(tfi->name);
     fe->fileName = fullName;
-    //printf("new FileDef() filename=%s\n",tfi->filename.data());
-    FileDef *fd = new FileDef(m_tagName+":"+tfi->path,
+    //printf("createFileDef() filename=%s\n",tfi->filename.data());
+    FileDef *fd = createFileDef(m_tagName+":"+tfi->path,
                               tfi->name,m_tagName,
                               tfi->filename
                              );
@@ -1400,7 +1405,7 @@ void TagFileParser::buildLists(Entry *root)
       Doxygen::inputNameDict->insert(tfi->name,mn);
     }
     buildMemberList(fe,tfi->members);
-    root->addSubEntry(fe);
+    root->moveToSubEntryAndKeep(fe);
   }
 
   // build namespace list
@@ -1408,18 +1413,17 @@ void TagFileParser::buildLists(Entry *root)
   TagNamespaceInfo *tni;
   for (nit.toFirst();(tni=nit.current());++nit)
   {
-    Entry *ne    = new Entry;
+    std::shared_ptr<Entry> ne = std::make_shared<Entry>();
     ne->section  = Entry::NAMESPACE_SEC;
     ne->name     = tni->name;
     addDocAnchors(ne,tni->docAnchors);
-    TagInfo *ti  = new TagInfo;
-    ti->tagName  = m_tagName;
-    ti->fileName = tni->filename;
+    ne->tagInfoData.tagName  = m_tagName;
+    ne->tagInfoData.fileName = tni->filename;
+    ne->hasTagInfo  = TRUE;
     ne->id       = tni->clangId;
-    ne->tagInfo  = ti;
 
     buildMemberList(ne,tni->members);
-    root->addSubEntry(ne);
+    root->moveToSubEntryAndKeep(ne);
   }
 
   // build package list
@@ -1427,17 +1431,16 @@ void TagFileParser::buildLists(Entry *root)
   TagPackageInfo *tpgi;
   for (pit.toFirst();(tpgi=pit.current());++pit)
   {
-    Entry *pe    = new Entry;
+    std::shared_ptr<Entry> pe = std::make_shared<Entry>();
     pe->section  = Entry::PACKAGE_SEC;
     pe->name     = tpgi->name;
     addDocAnchors(pe,tpgi->docAnchors);
-    TagInfo *ti  = new TagInfo;
-    ti->tagName  = m_tagName;
-    ti->fileName = tpgi->filename;
-    pe->tagInfo  = ti;
+    pe->tagInfoData.tagName  = m_tagName;
+    pe->tagInfoData.fileName = tpgi->filename;
+    pe->hasTagInfo  = TRUE;
 
     buildMemberList(pe,tpgi->members);
-    root->addSubEntry(pe);
+    root->moveToSubEntryAndKeep(pe);
   }
 
   // build group list
@@ -1445,18 +1448,36 @@ void TagFileParser::buildLists(Entry *root)
   TagGroupInfo *tgi;
   for (git.toFirst();(tgi=git.current());++git)
   {
-    Entry *ge    = new Entry;
+    std::shared_ptr<Entry> ge = std::make_shared<Entry>();
     ge->section  = Entry::GROUPDOC_SEC;
     ge->name     = tgi->name;
     ge->type     = tgi->title;
     addDocAnchors(ge,tgi->docAnchors);
-    TagInfo *ti  = new TagInfo;
-    ti->tagName  = m_tagName;
-    ti->fileName = tgi->filename;
-    ge->tagInfo  = ti;
+    ge->tagInfoData.tagName  = m_tagName;
+    ge->tagInfoData.fileName = tgi->filename;
+    ge->hasTagInfo  = TRUE;
 
     buildMemberList(ge,tgi->members);
-    root->addSubEntry(ge);
+    root->moveToSubEntryAndKeep(ge);
+  }
+
+  // set subgroup relations bug_774118
+  for (git.toFirst();(tgi=git.current());++git)
+  {
+    QCStringList::Iterator it;
+    for ( it = tgi->subgroupList.begin(); it != tgi->subgroupList.end(); ++it )
+    {
+      //QListIterator<Entry> eli(*(root->children()));
+      //Entry *childNode;
+      //for (eli.toFirst();(childNode=eli.current());++eli)
+      const auto &children = root->children();
+      auto i = std::find_if(children.begin(),children.end(),
+          [&](const std::shared_ptr<Entry> &e) { return e->name = *it; });
+      if (i!=children.end())
+      {
+        (*i)->groups.push_back(Grouping(tgi->name,Grouping::GROUPING_INGROUP));
+      }
+    }
   }
 
   // build page list
@@ -1464,16 +1485,15 @@ void TagFileParser::buildLists(Entry *root)
   TagPageInfo *tpi;
   for (pgit.toFirst();(tpi=pgit.current());++pgit)
   {
-    Entry *pe    = new Entry;
+    std::shared_ptr<Entry> pe = std::make_shared<Entry>();
     pe->section  = tpi->filename=="index" ? Entry::MAINPAGEDOC_SEC : Entry::PAGEDOC_SEC;
     pe->name     = tpi->name;
     pe->args     = tpi->title;
     addDocAnchors(pe,tpi->docAnchors);
-    TagInfo *ti  = new TagInfo;
-    ti->tagName  = m_tagName;
-    ti->fileName = tpi->filename;
-    pe->tagInfo  = ti;
-    root->addSubEntry(pe);
+    pe->tagInfoData.tagName  = m_tagName;
+    pe->tagInfoData.fileName = tpi->filename;
+    pe->hasTagInfo  = TRUE;
+    root->moveToSubEntryAndKeep(pe);
   }
 }
 
@@ -1500,7 +1520,7 @@ void TagFileParser::addIncludes()
           TagIncludeInfo *ii;
           for (;(ii=mii.current());++mii)
           {
-            //printf("ii->name=`%s'\n",ii->name.data());
+            //printf("ii->name='%s'\n",ii->name.data());
             FileName *ifn = Doxygen::inputNameDict->find(ii->name);
             ASSERT(ifn!=0);
             if (ifn)
@@ -1524,7 +1544,7 @@ void TagFileParser::addIncludes()
   }
 }
 
-void parseTagFile(Entry *root,const char *fullName)
+void parseTagFile(const std::shared_ptr<Entry> &root,const char *fullName)
 {
   QFileInfo fi(fullName);
   if (!fi.exists()) return;
