@@ -24,7 +24,7 @@
 */
 #define CN_SPC " "
 
-class TranslatorChinese : public Translator
+class TranslatorChinese : public TranslatorAdapter_1_8_15
 {
   public:
     /*! Used for identification of the language. The identification
@@ -52,9 +52,21 @@ class TranslatorChinese : public Translator
      * the empty string is returned in this implementation.
      */
     virtual QCString latexLanguageSupportCommand()
+    {
+      return "\\usepackage{CJKutf8}\n";
+    }
+    virtual QCString latexFontenc()
     {
       return "";
     }
+    virtual QCString latexDocumentPre()
+    {
+      return "\\begin{CJK}{UTF8}{min}\n";
+    }
+    virtual QCString latexDocumentPost()
+    {
+      return "\\end{CJK}\n";
+    }
 
     /*! used in the compound documentation before a list of related functions.
      */
@@ -100,7 +112,7 @@ class TranslatorChinese : public Translator
     virtual QCString trMore()
     { return "更多..."; }
 
-    /*! put in the class documention */
+    /*! put in the class documentation */
     virtual QCString trListOfAllMembers()
     { return "所有成员列表"; }
 
@@ -843,7 +855,7 @@ class TranslatorChinese : public Translator
 
     virtual QCString trReferencedBy()
     {
-      return "参考自";
+      return "被这些函数引用";
     }
 
     virtual QCString trRemarks()
@@ -1204,7 +1216,7 @@ class TranslatorChinese : public Translator
      */
     virtual QCString trReferences()
     {
-      return "参考";
+      return "引用了";
     }
 
 //////////////////////////////////////////////////////////////////////////
