@@ -103,7 +103,7 @@
 // Translator class (by the local maintainer) when the localized
 // translator is made up-to-date again.
 
-class TranslatorFrench : public Translator
+class TranslatorFrench : public TranslatorAdapter_1_8_15
 {
    public:
 
@@ -131,7 +131,8 @@ class TranslatorFrench : public Translator
      */
        virtual QCString latexLanguageSupportCommand()
       {
-         return "\\usepackage[french]{babel}\n";
+         return "\\usepackage[french]{babel}\n"
+		"\\NoAutoSpaceBeforeFDP\n";
       }
 
     // --- Language translation methods -------------------
@@ -2053,6 +2054,258 @@ class TranslatorFrench : public Translator
       return result;
     }
 
+//////////////////////////////////////////////////////////////////////////
+// new since 1.8.15
+//////////////////////////////////////////////////////////////////////////
+
+    /** VHDL design unit hierarchy */
+    virtual QCString trDesignUnitHierarchy()
+    { return "Hiérarchie des unités de conception"; }
+    /** VHDL design unit list */
+    virtual QCString trDesignUnitList()
+    { return "Liste des unités de conception"; }
+    /** VHDL design unit members */
+    virtual QCString trDesignUnitMembers()
+    { return "Membres des unités de conception"; }
+    /** VHDL design unit list description */
+    virtual QCString trDesignUnitListDescription()
+    {
+        return "Liste de tous les membres des unités de conception avec liens vers "
+            "les entités auxquelles ils appartiennent :";
+    }
+    /** VHDL design unit index */
+    virtual QCString trDesignUnitIndex()
+    { return "Index des unités de conception"; }
+    /** VHDL design units */
+    virtual QCString trDesignUnits()
+    { return "Unités de conception"; }
+    /** VHDL functions/procedures/processes */
+    virtual QCString trFunctionAndProc()
+    { return "Fonctions/Procédures/Processes"; }
+    /** VHDL type */
+    virtual QCString trVhdlType(uint64 type,bool single)
+    {
+      switch(type)
+      {
+        case VhdlDocGen::LIBRARY:
+          if (single) return "Librairie";
+          else        return "Librairies";
+        case VhdlDocGen::PACKAGE:
+          if (single) return "Paquetage";
+          else        return "Paquetages";
+        case VhdlDocGen::SIGNAL:
+          if (single) return "Signal";
+          else        return "Signaux";
+        case VhdlDocGen::COMPONENT:
+          if (single) return "Composant";
+          else        return "Composants";
+        case VhdlDocGen::CONSTANT:
+          if (single) return "Constante";
+          else        return "Constantes";
+        case VhdlDocGen::ENTITY:
+          if (single) return "Entité";
+          else        return "Entités";
+        case VhdlDocGen::TYPE:
+          if (single) return "Type";
+          else        return "Types";
+        case VhdlDocGen::SUBTYPE:
+          if (single) return "Sous-type";
+          else        return "Sous-types";
+        case VhdlDocGen::FUNCTION:
+          if (single) return "Fonction";
+          else        return "Fonctions";
+        case VhdlDocGen::RECORD:
+          if (single) return "Enregistrement";
+          else        return "Enregistrements";
+        case VhdlDocGen::PROCEDURE:
+          if (single) return "Procédure";
+          else        return "Procédures";
+        case VhdlDocGen::ARCHITECTURE:
+          if (single) return "Architecture";
+          else        return "Architectures";
+        case VhdlDocGen::ATTRIBUTE:
+          if (single) return "Attribut";
+          else        return "Attributs";
+        case VhdlDocGen::PROCESS:
+          if (single) return "Process";
+          else        return "Processes";
+        case VhdlDocGen::PORT:
+          if (single) return "Port";
+          else        return "Ports";
+        case VhdlDocGen::USE:
+          if (single) return "Clause d'utilisation";
+          else        return "Clauses d'utilisation";
+        case VhdlDocGen::GENERIC:
+          if (single) return "Generique";
+          else        return "Generiques";
+        case VhdlDocGen::PACKAGE_BODY:
+          return "Corps du paquetage";
+        case VhdlDocGen::UNITS:
+          return "Unités";
+        case VhdlDocGen::SHAREDVARIABLE:
+          if (single) return "Variable partagée";
+          else        return "Variables partagées";
+        case VhdlDocGen::VFILE:
+          if (single) return "Fichier";
+          else        return "Fichiers";
+        case VhdlDocGen::GROUP:
+          if (single) return "Groupe";
+          else        return "Groupes";
+        case VhdlDocGen::INSTANTIATION:
+          if (single) return "Instanciation";
+          else        return "Instanciations";
+        case VhdlDocGen::ALIAS:
+          if (single) return "Alias";
+          else        return "Alias";
+        case VhdlDocGen::CONFIG:
+          if (single) return "Configuration";
+          else        return "Configurations";
+        case VhdlDocGen::MISCELLANEOUS:
+          return "Divers";
+        case VhdlDocGen::UCF_CONST:
+          return "Contraintes";
+        default:
+          return "Classe";
+      }
+    }
+    virtual QCString trCustomReference(const char *name)
+    { return QCString("Référence ") + QCString(name); }
+
+    virtual QCString trConstants()
+    {
+        return "Constantes";
+    }
+    virtual QCString trConstantDocumentation()
+    {
+        return "Documentation des constantes";
+    }
+    virtual QCString trSequences()
+    {
+        return "Séquences";
+    }
+    virtual QCString trSequenceDocumentation()
+    {
+        return "Documentation des séquences";
+    }
+    virtual QCString trDictionaries()
+    {
+        return "Dictionnaires";
+    }
+    virtual QCString trDictionaryDocumentation()
+    {
+        return "Documentation des dictionnaires";
+    }
+    virtual QCString trSliceInterfaces()
+    {
+        return "Interfaces";
+    }
+    virtual QCString trInterfaceIndex()
+    {
+        return "Index des interfaces";
+    }
+    virtual QCString trInterfaceList()
+    {
+        return "Liste des interfaces";
+    }
+    virtual QCString trInterfaceListDescription()
+    {
+        return "Liste des interfaces avec une brève description :";
+    }
+    virtual QCString trInterfaceHierarchy()
+    {
+        return "Hiérarchies des interfaces";
+    }
+    virtual QCString trInterfaceHierarchyDescription()
+    {
+        return "Cette liste d'héritage est classée approximativement par ordre alphabétique :";
+    }
+    virtual QCString trInterfaceDocumentation()
+    {
+        return "Documentation des interfaces";
+    }
+    virtual QCString trStructs()
+    {
+        return "Structures";
+    }
+    virtual QCString trStructIndex()
+    {
+        return "Index des structures";
+    }
+    virtual QCString trStructList()
+    {
+        return "Liste des structures";
+    }
+    virtual QCString trStructListDescription()
+    {
+        return "Liste des structures avec une brève description :";
+    }
+    virtual QCString trStructDocumentation()
+    {
+        return "Documentation des structures";
+    }
+    virtual QCString trExceptionIndex()
+    {
+        return "Index des exceptions";
+    }
+    virtual QCString trExceptionList()
+    {
+        return "Liste des exceptions";
+    }
+    virtual QCString trExceptionListDescription()
+    {
+        return "Liste des exceptions avec une brève description :";
+    }
+    virtual QCString trExceptionHierarchy()
+    {
+        return "Hiérarchies des exceptions";
+    }
+    virtual QCString trExceptionHierarchyDescription()
+    {
+        return "Cette liste d'héritage est classée approximativement par ordre alphabétique :";
+    }
+    virtual QCString trExceptionDocumentation()
+    {
+        return "Documentation des exceptions";
+    }
+    virtual QCString trCompoundReferenceSlice(const char *clName, ClassDef::CompoundType compType, bool isLocal)
+    {
+      QCString result = "Référence de ";
+
+      switch(compType)
+      {
+        case ClassDef::Class:      result+="la classe "; break;
+        case ClassDef::Struct:     result+="la structure "; break;
+        case ClassDef::Interface:  result+="l'interface "; break;
+        case ClassDef::Exception:  result+="l'exception "; break;
+        default: break;
+      }
+
+      if(isLocal)
+      {
+        result += "locale ";
+      }
+
+      result += (QCString)clName;
+
+      return result;
+    }
+    virtual QCString trOperations()
+    {
+        return "Opérations";
+    }
+    virtual QCString trOperationDocumentation()
+    {
+        return "Documentation des opérations";
+    }
+    virtual QCString trDataMembers()
+    {
+        return "Champs de données";
+    }
+    virtual QCString trDataMemberDocumentation()
+    {
+        return "Documentation des champs de données";
+    }
+
 //////////////////////////////////////////////////////////////////////////
 
 };
