@@ -69,16 +69,28 @@ Doxygen の開発の方でもそれはそれでいーんじゃん？みたいな
 #ifndef TRANSLATOR_JP_H
 #define TRANSLATOR_JP_H
 
-class TranslatorJapanese : public Translator
+class TranslatorJapanese : public TranslatorAdapter_1_8_15
 {
   public:
     virtual QCString idLanguage()
     { return "japanese"; }
 
     virtual QCString latexLanguageSupportCommand()
+    {
+      return "\\usepackage{CJKutf8}\n";
+    }
+    virtual QCString latexFontenc()
     {
       return "";
     }
+    virtual QCString latexDocumentPre()
+    {
+      return "\\begin{CJK}{UTF8}{min}\n";
+    }
+    virtual QCString latexDocumentPost()
+    {
+      return "\\end{CJK}\n";
+    }
 
     /*! used in the compound documentation before a list of related functions. */
     virtual QCString trRelatedFunctions()
