@@ -35,12 +35,22 @@ class TranslatorKoreanEn : public TranslatorEnglish
     { return "korean-en"; }
     virtual QCString latexLanguageSupportCommand()
     {
-      return "\\usepackage{hfont}\n";
+      return "\\usepackage{kotex}\n";
     }
     virtual QCString trRTFansicp()
     {
       return "949";
     }
+    virtual QCString latexCommandName()
+    {
+      QCString latex_command = Config_getString(LATEX_CMD_NAME);
+      if (latex_command.isEmpty()) latex_command = "latex";
+      if (Config_getBool(USE_PDFLATEX))
+      {
+        if (latex_command == "latex") latex_command = "xelatex";
+      }
+      return latex_command;
+    }
 
     /*! Used as ansicpg for RTF fcharset
      *  \see trRTFansicp() for a table of possible values.
