@@ -95,7 +95,7 @@ class TranslatorMacedonian : public TranslatorAdapter_1_6_0
     /*! header that is put before the list of member attributes. */
     virtual QCString trMemberDataDocumentation()
     {
-      //if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
+      //if (Config_getBool(OPTIMIZE_OUTPUT_FOR_C))
       {
         return "Документација на членови";
       }
@@ -158,7 +158,7 @@ class TranslatorMacedonian : public TranslatorAdapter_1_6_0
     /*! This is put above each page as a link to the list of annotated classes */
     virtual QCString trCompoundList()
     {
-      if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
+      if (Config_getBool(OPTIMIZE_OUTPUT_FOR_C))
       {
         return "Список на Структури";
       }
@@ -175,7 +175,7 @@ class TranslatorMacedonian : public TranslatorAdapter_1_6_0
     /*! This is put above each page as a link to all members of compounds. */
     virtual QCString trCompoundMembers()
     {
-      if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
+      if (Config_getBool(OPTIMIZE_OUTPUT_FOR_C))
       {
         return "Членови";
       }
@@ -188,7 +188,7 @@ class TranslatorMacedonian : public TranslatorAdapter_1_6_0
     /*! This is put above each page as a link to all members of files. */
     virtual QCString trFileMembers()
     {
-      if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
+      if (Config_getBool(OPTIMIZE_OUTPUT_FOR_C))
       {
         return "Глобални Членови";
       }
@@ -228,7 +228,7 @@ class TranslatorMacedonian : public TranslatorAdapter_1_6_0
     virtual QCString trCompoundListDescription()
     {
 
-      if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
+      if (Config_getBool(OPTIMIZE_OUTPUT_FOR_C))
       {
         return "Список на структури со кратки описи:";
       }
@@ -247,7 +247,7 @@ class TranslatorMacedonian : public TranslatorAdapter_1_6_0
       {
         result+="документирани ";
       }
-      if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
+      if (Config_getBool(OPTIMIZE_OUTPUT_FOR_C))
       {
         result+="структури и унии";
       }
@@ -258,7 +258,7 @@ class TranslatorMacedonian : public TranslatorAdapter_1_6_0
       result+=" со врски до ";
       if (!extractAll)
       {
-        if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
+        if (Config_getBool(OPTIMIZE_OUTPUT_FOR_C))
         {
           result+="документацијата за секој член на структурата/унијата:";
         }
@@ -269,7 +269,7 @@ class TranslatorMacedonian : public TranslatorAdapter_1_6_0
       }
       else
       {
-        if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
+        if (Config_getBool(OPTIMIZE_OUTPUT_FOR_C))
         {
           result+="структурите/униите на кои што припаѓаат:";
         }
@@ -287,7 +287,7 @@ class TranslatorMacedonian : public TranslatorAdapter_1_6_0
       QCString result="Список на сите ";
       if (!extractAll) result+="документирани ";
 
-      if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
+      if (Config_getBool(OPTIMIZE_OUTPUT_FOR_C))
       {
         result+="функции, променливи, дефиниции, набројувања и дефиниции на тип";
       }
@@ -338,7 +338,7 @@ class TranslatorMacedonian : public TranslatorAdapter_1_6_0
      */
     virtual QCString trCompoundIndex()
     {
-      if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
+      if (Config_getBool(OPTIMIZE_OUTPUT_FOR_C))
       {
         return "Попис на Структури";
       }
@@ -365,7 +365,7 @@ class TranslatorMacedonian : public TranslatorAdapter_1_6_0
      */
     virtual QCString trClassDocumentation()
     {
-      if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
+      if (Config_getBool(OPTIMIZE_OUTPUT_FOR_C))
       {
         return "Документација на Структури";
       }
@@ -468,7 +468,7 @@ class TranslatorMacedonian : public TranslatorAdapter_1_6_0
      */
     virtual QCString trCompounds()
     {
-      if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
+      if (Config_getBool(OPTIMIZE_OUTPUT_FOR_C))
       {
         return "Структури";
       }
@@ -876,7 +876,7 @@ class TranslatorMacedonian : public TranslatorAdapter_1_6_0
     }
     virtual QCString trPublicAttribs()
     {
-      if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
+      if (Config_getBool(OPTIMIZE_OUTPUT_FOR_C))
       {
         return "Членови";
       }
@@ -1071,7 +1071,7 @@ class TranslatorMacedonian : public TranslatorAdapter_1_6_0
     /*! Used for Java classes in the summary section of Java packages */
     virtual QCString trClasses()
     {
-      if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
+      if (Config_getBool(OPTIMIZE_OUTPUT_FOR_C))
       {
         return "Структури";
       }
