@@ -70,6 +70,11 @@ class TranslatorSerbianCyrillic : public TranslatorAdapter_1_6_0
      * the empty string is returned in this implementation.
      */
     virtual QCString latexLanguageSupportCommand()
+    {
+      return "\\usepackage[T2A]{fontenc}\n"
+             "\\usepackage[russian]{babel}\n";
+    }
+    virtual QCString latexFontenc()
     {
       return "";
     }
