@@ -36,7 +36,7 @@ class TranslatorSlovene : public TranslatorAdapter_1_4_6
      */
     QCString latexLanguageSupportCommand()
     {
-      return "\\usepackage[slovene]{babel}\n\\usepackage[T1]{fontenc}\n";
+      return "\\usepackage[slovene]{babel}\n";
     }
     QCString trRelatedFunctions()
     { return "Povezane funkcije"; }
@@ -755,7 +755,7 @@ class TranslatorSlovene : public TranslatorAdapter_1_4_6
     /*! Used for Java classes in the summary section of Java packages */
     virtual QCString trClasses()
     {
-      if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
+      if (Config_getBool(OPTIMIZE_OUTPUT_FOR_C))
       {
         return "Podatkovne strukture";
       }
