@@ -77,10 +77,24 @@ class TranslatorVietnamese : public TranslatorAdapter_1_6_0
      * the empty string is returned in this implementation.
      */
     virtual QCString latexLanguageSupportCommand()
+    {
+      return
+        "\\usepackage[vietnamese]{babel}\n";
+    }
+    virtual QCString latexFontenc()
     {
       return "";
     }
-
+    virtual QCString latexCommandName()
+    {
+      QCString latex_command = Config_getString(LATEX_CMD_NAME);
+      if (latex_command.isEmpty()) latex_command = "latex";
+      if (Config_getBool(USE_PDFLATEX))
+      {
+        if (latex_command == "latex") latex_command = "xelatex";
+      }
+      return latex_command;
+    }
     // --- Language translation methods -------------------
 
     /*! used in the compound documentation before a list of related functions. */
@@ -110,7 +124,7 @@ class TranslatorVietnamese : public TranslatorAdapter_1_6_0
     /*! header that is put before the list of member attributes. */
     virtual QCString trMemberDataDocumentation()
     {
-      if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
+      if (Config_getBool(OPTIMIZE_OUTPUT_FOR_C))
       {
         return "Thông tin về trường";
       }
@@ -177,7 +191,7 @@ class TranslatorVietnamese : public TranslatorAdapter_1_6_0
     /*! This is put above each page as a link to the list of annotated classes */
     virtual QCString trCompoundList()
     {
-      if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
+      if (Config_getBool(OPTIMIZE_OUTPUT_FOR_C))
       {
         return "Cấu trúc cơ sở dữ liệu (Data Structures)";
       }
@@ -194,7 +208,7 @@ class TranslatorVietnamese : public TranslatorAdapter_1_6_0
     /*! This is put above each page as a link to all members of compounds. */
     virtual QCString trCompoundMembers()
     {
-      if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
+      if (Config_getBool(OPTIMIZE_OUTPUT_FOR_C))
       {
         return "Các trường dữ liệu";
       }
@@ -207,7 +221,7 @@ class TranslatorVietnamese : public TranslatorAdapter_1_6_0
     /*! This is put above each page as a link to all members of files. */
     virtual QCString trFileMembers()
     {
-      if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
+      if (Config_getBool(OPTIMIZE_OUTPUT_FOR_C))
       {
         return "Toàn cục";
       }
@@ -248,7 +262,7 @@ class TranslatorVietnamese : public TranslatorAdapter_1_6_0
     virtual QCString trCompoundListDescription()
     {
 
-      if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
+      if (Config_getBool(OPTIMIZE_OUTPUT_FOR_C))
       {
         return "Đây là cấu trúc cơ sở dữ liệu với mô tả tóm tắt:";
       }
@@ -267,7 +281,7 @@ class TranslatorVietnamese : public TranslatorAdapter_1_6_0
       {
         result+="(đã được mô tả) ";
       }
-      if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
+      if (Config_getBool(OPTIMIZE_OUTPUT_FOR_C))
       {
         result+="struct và union fields";
       }
@@ -278,7 +292,7 @@ class TranslatorVietnamese : public TranslatorAdapter_1_6_0
       result+=" cùng với các các liên kết đến ";
       if (!extractAll)
       {
-        if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
+        if (Config_getBool(OPTIMIZE_OUTPUT_FOR_C))
         {
           result+="Thông tin về struct/union cho từng trường:";
         }
@@ -289,7 +303,7 @@ class TranslatorVietnamese : public TranslatorAdapter_1_6_0
       }
       else
       {
-        if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
+        if (Config_getBool(OPTIMIZE_OUTPUT_FOR_C))
         {
           result+="các structures/unions thuộc:";
         }
@@ -307,7 +321,7 @@ class TranslatorVietnamese : public TranslatorAdapter_1_6_0
       QCString result="Danh sách tất cả các ";
       if (!extractAll) result+="(đã được mô tat) ";
 
-      if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
+      if (Config_getBool(OPTIMIZE_OUTPUT_FOR_C))
       {
         result+="functions, variables, defines, enums, và typedefs";
       }
@@ -358,7 +372,7 @@ class TranslatorVietnamese : public TranslatorAdapter_1_6_0
      */
     virtual QCString trCompoundIndex()
     {
-      if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
+      if (Config_getBool(OPTIMIZE_OUTPUT_FOR_C))
       {
         return "Index cấu trúc cơ sở dữ liệu";
       }
@@ -385,7 +399,7 @@ class TranslatorVietnamese : public TranslatorAdapter_1_6_0
      */
     virtual QCString trClassDocumentation()
     {
-      if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
+      if (Config_getBool(OPTIMIZE_OUTPUT_FOR_C))
       {
         return "Thông tin về cấu trúc cơ sở dữ liệu";
       }
@@ -488,7 +502,7 @@ class TranslatorVietnamese : public TranslatorAdapter_1_6_0
      */
     virtual QCString trCompounds()
     {
-      if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
+      if (Config_getBool(OPTIMIZE_OUTPUT_FOR_C))
       {
         return "Cấu trúc cơ sở dữ liệu";
       }
@@ -895,7 +909,7 @@ class TranslatorVietnamese : public TranslatorAdapter_1_6_0
     }
     virtual QCString trPublicAttribs()
     {
-      if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
+      if (Config_getBool(OPTIMIZE_OUTPUT_FOR_C))
       {
         return "các trường đữ liệu";
       }
@@ -1090,7 +1104,7 @@ class TranslatorVietnamese : public TranslatorAdapter_1_6_0
     /*! Used for Java classes in the summary section of Java packages */
     virtual QCString trClasses()
     {
-      if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
+      if (Config_getBool(OPTIMIZE_OUTPUT_FOR_C))
       {
         return "Cấu trúc dữ liệu";
       }
