@@ -95,7 +95,6 @@ class VhdlDocGen
     static bool     deleteCharRev(QCString &s,char c);
     static void     deleteAllChars(QCString &s,char c);
     static void     parseFuncProto(const char* text,
-                                   QList<Argument>& , 
                                    QCString& name,
                                    QCString& ret,
                                    bool doc=false);
@@ -113,9 +112,8 @@ class VhdlDocGen
                                 const QCString& key,
                                 MemberListType type);
     static ClassDef *getClass(const char *name);
-    static MemberDef* findFunction(const QList<Argument> &ql,
-                                   const QCString& name,
-                                   const QCString& package, bool type);
+    static MemberDef* findFunction(const QCString& name,
+                                   const QCString& package);
     static QCString getClassTitle(const ClassDef*);
     static void writeInlineClassLink(const ClassDef*,
                                      OutputList &ol);
@@ -149,63 +147,37 @@ class VhdlDocGen
     static bool isCompInst(const MemberDef *mdef);
     static bool isMisc(const MemberDef *mdef);
 
-    //-----------------------------------------------------
-    // translatable items
-    
-    static QCString trTypeString(uint64 type);
-    static QCString trVhdlType(uint64 type,bool sing=true);
-
-    // trClassHierarchy.
-    static QCString trDesignUnitHierarchy();
-
-    // trCompoundList
-    static QCString trDesignUnitList();
-
-    // trCompoundMembers.
-    static QCString trDesignUnitMembers();
-
-    // trCompoundListDescription
-    static QCString trDesignUnitListDescription();
-
-    // trCompounds
-    static QCString trDesignUnits();
-
-    // trCompoundIndex
-    static QCString trDesignUnitIndex();
-
-    // trFunctions
-    static QCString trFunctionAndProc();
-
     //-----------------------------------------------------
 
     static void prepareComment(QCString&);
     static void formatString(const QCString&,OutputList& ol,const MemberDef*);
 
     static void writeFormatString(const QCString&,OutputList& ol,const MemberDef*);
-    static void writeFunctionProto(OutputList& ol,const ArgumentList *al,const MemberDef*);
-    static void writeProcessProto(OutputList& ol,const ArgumentList *al,const MemberDef*);
-    static void writeProcedureProto(OutputList& ol, const ArgumentList *al,const MemberDef*);
-    static bool writeFuncProcDocu(const MemberDef *mdef, OutputList& ol,const ArgumentList* al,bool type=false);
-    static void writeRecordProto(const MemberDef *mdef, OutputList& ol,const ArgumentList *al);
+    static void writeFunctionProto(OutputList& ol,const ArgumentList &al,const MemberDef*);
+    static void writeProcessProto(OutputList& ol,const ArgumentList &al,const MemberDef*);
+    static void writeProcedureProto(OutputList& ol, const ArgumentList &al,const MemberDef*);
+    static bool writeFuncProcDocu(const MemberDef *mdef, OutputList& ol,const ArgumentList &al,bool type=false);
+    static void writeRecordProto(const MemberDef *mdef, OutputList& ol,const ArgumentList &al);
 
     static bool writeVHDLTypeDocumentation(const MemberDef* mdef, const Definition* d, OutputList &ol);
 
-    static void writeVhdlDeclarations(MemberList*,OutputList&,GroupDef*,ClassDef*,FileDef*,NamespaceDef*);
+    static void writeVhdlDeclarations(const MemberList*,OutputList&,const GroupDef*,const ClassDef*,const FileDef*,const NamespaceDef*);
 
-    static void writeVHDLDeclaration(MemberDef* mdef,OutputList &ol,
-        ClassDef *cd,NamespaceDef *nd,FileDef *fd,GroupDef *gd,
+    static void writeVHDLDeclaration(const MemberDef* mdef,OutputList &ol,
+        const ClassDef *cd,const NamespaceDef *nd,const FileDef *fd,const GroupDef *gd,
         bool inGroup);
 
-    static void writePlainVHDLDeclarations(MemberList* ml,OutputList &ol,
-        ClassDef *cd,NamespaceDef *nd,FileDef *fd,GroupDef *gd,int specifier);
+    static void writePlainVHDLDeclarations(const MemberList* ml,OutputList &ol,
+        const ClassDef *cd,const NamespaceDef *nd,const FileDef *fd,const GroupDef *gd,
+        int specifier);
 
-    static void writeVHDLDeclarations(MemberList* ml,OutputList &ol,
-        ClassDef *cd,NamespaceDef *nd,FileDef *fd,GroupDef *gd,
+    static void writeVHDLDeclarations(const MemberList* ml,OutputList &ol,
+        const ClassDef *cd,const NamespaceDef *nd,const FileDef *fd,const GroupDef *gd,
         const char *title,const char *subtitle,bool showEnumValues,int type);
 
-    static bool writeClassType(ClassDef *&,OutputList &ol ,QCString & cname);
+    static bool writeClassType(const ClassDef *,OutputList &ol ,QCString & cname);
 
-    static QCString convertArgumentListToString(const ArgumentList* al,bool f);
+    static QCString convertArgumentListToString(const ArgumentList &al,bool f);
     static QCString getProcessNumber();
     static QCString getRecordNumber();
    
@@ -219,9 +191,9 @@ class VhdlDocGen
     static ClassDef*  findArchitecture(const ClassDef *cd);
     static ClassDef*  findArchitecture(QCString identifier, QCString entity_name);
 
+    static void correctMemberProperties(MemberDef *md);
     
-    static void writeSource(MemberDef *mdef,OutputList& ol,QCString & cname);
-    static void writeAlphbeticalClass(OutputList& ol,const ClassDef* cd,const QCString &);
+    static void writeSource(const MemberDef *mdef,OutputList& ol,const QCString & cname);
 
     static QCString  parseForConfig(QCString & entity,QCString & arch);
     static QCString  parseForBinding(QCString & entity,QCString & arch);
@@ -250,7 +222,7 @@ class VhdlDocGen
 
   private:
     static void findAllArchitectures(QList<QCString>& ql,const ClassDef *cd);
-    static bool compareArgList(ArgumentList*,ArgumentList*);
+    static bool compareArgList(const ArgumentList &,const ArgumentList &);
     static void writeVhdlLink(const ClassDef* cdd ,OutputList& ol,QCString& type,QCString& name,QCString& beh);
     static void writeStringLink(const MemberDef *mdef,QCString mem,OutputList& ol);
     static void writeRecUnitDocu( const MemberDef *md, OutputList& ol,QCString largs);
@@ -315,11 +287,11 @@ class FlowChart
     static void delFlowList();
     static const char* getNodeType(int c);
 
-    static void addFlowChart(int type,const char* text,const char* exp,const char * label=NULL);
+    static void addFlowChart(int type,const char* text,const char* exp,const char * label=0);
     static void moveToPrevLevel();
     static int getTimeStamp();
     static void writeFlowChart();
-    static void alignFuncProc(QCString & q,const ArgumentList*  al,bool isFunc);
+    static void alignFuncProc(QCString & q,const ArgumentList &al,bool isFunc);
     static QCString convertNameToFileName();
     static void printNode(const FlowChart* n);
     static void printFlowTree();
@@ -335,11 +307,11 @@ class FlowChart
     ~FlowChart();
 
 private:
-    int id;
-    int stamp;
-    int type;
+    int id = 0;
+    int stamp = 0;
+    int type = 0;
 
-    int line;
+    int line = 0;
 
     QCString label;
     QCString text;
