@@ -12,7 +12,7 @@
 
 #include <qcstring.h>
 #include <qfileinfo.h>
-#include <qstringlist.h>
+#include <qcstringlist.h>
 #include "vhdljjparser.h"
 #include "vhdlcode.h"
 #include "vhdldocgen.h"
@@ -29,11 +29,12 @@
 #include "arguments.h"
 #include "types.h"
 #include "VhdlParserIF.h"
+#include "growbuf.h"
 
 using namespace vhdl::parser;
 using namespace std;
 
-static ParserInterface *g_thisParser;
+static OutlineParserInterface *g_thisParser;
 
 static QCString         yyFileName;
 static int              yyLineNr      = 1;
@@ -48,16 +49,15 @@ static Entry* oldEntry;
 static bool varr=FALSE;
 static QCString varName;
 
-static QList<Entry> instFiles;
-static QList<Entry> libUse;
-static QList<Entry> lineEntry;
+static std::vector< std::shared_ptr<Entry> > instFiles;
+static std::vector< std::shared_ptr<Entry> > libUse;
+static std::vector<Entry*> lineEntry;
 
-Entry*   VhdlParser::currentCompound=0;
 Entry*   VhdlParser::tempEntry=0;
 Entry*   VhdlParser::lastEntity=0  ;
 Entry*   VhdlParser::lastCompound=0  ;
-Entry*   VhdlParser::current=0;
 Entry*   VhdlParser::current_root  = 0;
+std::shared_ptr<Entry> VhdlParser::current=0;
 QCString VhdlParser::compSpec;
 QCString VhdlParser::currName;
 QCString VhdlParser::confName;
@@ -80,17 +80,17 @@ static struct
   int iDocLine;
 } str_doc;
 
-static bool doxComment=FALSE; // doxygen comment ?
 static QCString strComment;
 static int iCodeLen;
+static const char *vhdlFileName = 0;
 
-bool  checkMultiComment(QCString& qcs,int line);
-QList<Entry>* getEntryAtLine(const Entry* ce,int line);
+static bool checkMultiComment(QCString& qcs,int line);
+static void insertEntryAtLine(const Entry* ce,int line);
 
 //-------------------------------------
 
-QList<VhdlConfNode>& getVhdlConfiguration() { return  configL; }
-QList<Entry>& getVhdlInstList() { return  instFiles; }
+const QList<VhdlConfNode>& getVhdlConfiguration() { return  configL; }
+const std::vector<std::shared_ptr<Entry> > &getVhdlInstList() { return  instFiles; }
 
 Entry* getVhdlCompound()
 {
@@ -99,67 +99,14 @@ Entry* getVhdlCompound()
   return NULL;
 }
 
-void startCodeBlock(int index)
-{
-  int ll=strComment.length();
-  if (!gBlock) gBlock = new Entry;
-  iCodeLen=inputString.findRev(strComment.data())+ll;
-  // fprintf(stderr,"\n startin code..%d %d %d\n",iCodeLen,num_chars,ll);
-  gBlock->reset();
-  int len=strComment.length();
-  QCString name=strComment.right(len-index);//
-  name=VhdlDocGen::getIndexWord(name.data(),1);
-  if (!name)
-    gBlock->name="misc"+ VhdlDocGen::getRecordNumber();
-  else
-    gBlock->name=name;
-
-  gBlock->startLine=yyLineNr;
-  gBlock->bodyLine=yyLineNr;
-
-  strComment=strComment.left(index);
-  VhdlDocGen::prepareComment(strComment);
-  gBlock->brief+=strComment;
-}
-
-void makeInlineDoc(int endCode)
-{
-  int len=endCode-iCodeLen;
-  if (!gBlock) gBlock = new Entry;
-  QCString par=inputString.mid(iCodeLen,len);
-  //fprintf(stderr,"\n inline code: \n<%s>",par.data());
-  gBlock->doc=par;
-  gBlock->inbodyDocs=par;
-  gBlock->section=Entry::VARIABLE_SEC;
-  gBlock->spec=VhdlDocGen::MISCELLANEOUS;
-  gBlock->fileName = yyFileName;
-  gBlock->endBodyLine=yyLineNr-1;
-  gBlock->lang=SrcLangExt_VHDL;
-  Entry *temp=new Entry(*gBlock);
-  Entry* compound=getVhdlCompound();
-
-  if (compound)
-  {
-    compound->addSubEntry(temp);
-  }
-  else
-  {
-    temp->type="misc"; // global code like library ieee...
-    VhdlParser::current_root->addSubEntry(temp);
-  }
-  strComment.resize(0);
-  gBlock->reset();
-}// makeInlineDoc
-
-
 bool isConstraintFile(const QCString &fileName,const QCString &ext)
 {
   return fileName.right(ext.length())==ext;
 }
 
 
-void VHDLLanguageScanner::parseInput(const char *fileName,const char *fileBuf,Entry *root,
-                          bool ,QStrList&)
+void VHDLOutlineParser::parseInput(const char *fileName,const char *fileBuf,
+                          const std::shared_ptr<Entry> &root, bool ,QStrList&)
 {
   g_thisParser=this;
   bool inLine=false;
@@ -181,37 +128,37 @@ void VHDLLanguageScanner::parseInput(const char *fileName,const char *fileBuf,En
 
   if (xilinx_ucf)
   {
-    VhdlDocGen::parseUCF(fileBuf,root,yyFileName,FALSE);
+    VhdlDocGen::parseUCF(fileBuf,root.get(),yyFileName,FALSE);
     return;
   }
   if (altera_qsf)
   {
-    VhdlDocGen::parseUCF(fileBuf,root,yyFileName,TRUE);
+    VhdlDocGen::parseUCF(fileBuf,root.get(),yyFileName,TRUE);
     return;
   }
-  libUse.setAutoDelete(true);
   yyLineNr=1;
-  VhdlParser::current_root=root;
+  VhdlParser::current_root=root.get();
   VhdlParser::lastCompound=0;
   VhdlParser::lastEntity=0;
-  VhdlParser::currentCompound=0;
   VhdlParser::lastEntity=0;
-  VhdlParser::current=new Entry();
-  VhdlParser::initEntry(VhdlParser::current);
-  groupEnterFile(fileName,yyLineNr);
+  oldEntry = 0;
+  VhdlParser::current=std::make_shared<Entry>();
+  VhdlParser::initEntry(VhdlParser::current.get());
+  Doxygen::docGroup.enterFile(fileName,yyLineNr);
+  vhdlFileName = fileName;
   lineParse=new int[200]; // Dimitri: dangerous constant: should be bigger than largest token id in VhdlParserConstants.h
   VhdlParserIF::parseVhdlfile(fileBuf,inLine);
 
-  delete VhdlParser::current;
-  VhdlParser::current=0;
+  VhdlParser::current.reset();
 
   if (!inLine)
-  VhdlParser::mapLibPackage(root);
+  VhdlParser::mapLibPackage(root.get());
 
   delete[] lineParse;
   yyFileName.resize(0);
   libUse.clear();
   VhdlDocGen::resetCodeVhdlParserState();
+  vhdlFileName = 0;
 }
 
 void VhdlParser::lineCount()
@@ -223,7 +170,7 @@ void VhdlParser::lineCount(const char* text)
 {
   for (const char* c=text ; *c ; ++c )
   {
-    yyLineNr += (*c == '\n') ;
+    if (*c == '\n') yyLineNr++;
   }
 }
 
@@ -243,53 +190,38 @@ void VhdlParser::initEntry(Entry *e)
   e->fileName = yyFileName;
   e->lang     = SrcLangExt_VHDL;
   isVhdlDocPending();
-  initGroupInfo(e);
+  Doxygen::docGroup.initGroupInfo(e);
 }
 
 void VhdlParser::newEntry()
 {
+  previous = current.get();
   if (current->spec==VhdlDocGen::ENTITY ||
       current->spec==VhdlDocGen::PACKAGE ||
       current->spec==VhdlDocGen::ARCHITECTURE ||
       current->spec==VhdlDocGen::PACKAGE_BODY)
   {
-    current_root->addSubEntry(current);
+    current_root->moveToSubEntryAndRefresh(current);
   }
   else
   {
     if (lastCompound)
     {
-      lastCompound->addSubEntry(current);
+      lastCompound->moveToSubEntryAndRefresh(current);
     }
     else
     {
       if (lastEntity)
       {
-	lastEntity->addSubEntry(current);
+	lastEntity->moveToSubEntryAndRefresh(current);
       }
       else
       {
-	current_root->addSubEntry(current);
+	current_root->moveToSubEntryAndRefresh(current);
       }
     }
   }
-  previous = current;
-  current = new Entry ;
-  initEntry(current);
-}
-
-bool checkInlineCode(QCString & doc)
-{
-  int index=doc.find("\\code");
-
-  if (index>0)
-  {
-     strComment+=doc;
-	 startCodeBlock(index);
-	 doxComment=TRUE;
-	 return true;
-  }
-  return false;
+  initEntry(current.get());
 }
 
 void VhdlParser::handleFlowComment(const char* doc)
@@ -308,8 +240,6 @@ void VhdlParser::handleFlowComment(const char* doc)
 
 void VhdlParser::handleCommentBlock(const char* doc1,bool brief)
 {
-  int position=0;
-  static bool isIn;
   QCString doc;
   doc.append(doc1);
  // fprintf(stderr,"\n %s",doc.data());
@@ -321,28 +251,11 @@ void VhdlParser::handleCommentBlock(const char* doc1,bool brief)
     return;
   }
 
-  isIn=checkInlineCode(doc);
-  bool isEndCode=doc.contains("\\endcode");
-  // empty comment  --!
-  if (isEndCode)
-  {
-    int end=inputString.find(doc.data(),iCodeLen);
-    makeInlineDoc(end);
-    strComment.resize(0);
-    isIn=false;
-  }
-  if (isIn)
-  {
-    isIn=false;
-    return;
-  }
-
   VhdlDocGen::prepareComment(doc);
 
-  bool needsEntry=FALSE;
   Protection protection=Public;
 
-  if (oldEntry==current)
+  if (oldEntry==current.get())
   {
     //printf("\n find pending message  < %s > at line: %d \n ",doc.data(),iDocLine);
     str_doc.doc=doc;
@@ -352,7 +265,7 @@ void VhdlParser::handleCommentBlock(const char* doc1,bool brief)
     return;
   }
 
-  oldEntry=current;
+  oldEntry=current.get();
 
   if (brief)
   {
@@ -371,10 +284,13 @@ void VhdlParser::handleCommentBlock(const char* doc1,bool brief)
     current->stat=true;
   }
 
+  int position=0;
+  bool needsEntry=FALSE;
+  QCString processedDoc = preprocessCommentBlock(doc,yyFileName,iDocLine);
   while (parseCommentBlock(
         g_thisParser,
-        current,
-        doc,        // text
+        current.get(),
+        processedDoc, // text
         yyFileName, // file
         iDocLine,   // line of block start
         brief,
@@ -404,7 +320,7 @@ void VhdlParser::handleCommentBlock(const char* doc1,bool brief)
   strComment.resize(0);
 }
 
-void VHDLLanguageScanner::parsePrototype(const char *text)
+void VHDLOutlineParser::parsePrototype(const char *text)
 {
   varName=text;
   varr=TRUE;
@@ -423,27 +339,25 @@ void VhdlParser::addCompInst(const char *n, const char* instName, const char* co
   {
     current->args=lastCompound->name;             // architecture name
   }
-  current->includeName=comp;                    // component/enity/configuration
+  current->includeName=comp;                    // component/entity/configuration
   int u=genLabels.find("|",1);
   if (u>0)
   {
     current->write=genLabels.right(genLabels.length()-u);
     current->read=genLabels.left(u);
   }
-  //printf  (" \n genlable: [%s]  inst: [%s]  name: [%s] %d\n",n,instName,comp,iLine);
+  //printf  (" \n genlabel: [%s]  inst: [%s]  name: [%s] %d\n",n,instName,comp,iLine);
 
   if (lastCompound)
   {
     current->args=lastCompound->name;
     if (true) // !findInstant(current->type))
     {
-      initEntry(current);
-      instFiles.append(new Entry(*current));
+      initEntry(current.get());
+      instFiles.emplace_back(std::make_shared<Entry>(*current));
     }
 
-    Entry *temp=current;  // hold  current pointer  (temp=oldEntry)
-    current=new Entry;     // (oldEntry != current)
-    delete  temp;
+    current=std::make_shared<Entry>();
   }
   else
   {
@@ -462,11 +376,11 @@ void VhdlParser::addVhdlType(const char *n,int startLine,int section,
     spec= VhdlDocGen::GENERIC;
   }
 
-  QStringList ql=QStringList::split(",",name,FALSE);
+  QCStringList ql=QCStringList::split(",",name);
 
   for (uint u=0;u<ql.count();u++)
   {
-    current->name=ql[u].utf8();
+    current->name=ql[u];
     current->startLine=startLine;
     current->bodyLine=startLine;
     current->section=section;
@@ -481,7 +395,7 @@ void VhdlParser::addVhdlType(const char *n,int startLine,int section,
 
     if (!lastCompound && (section==Entry::VARIABLE_SEC) &&  (spec == VhdlDocGen::USE || spec == VhdlDocGen::LIBRARY) )
     {
-      libUse.append(new Entry(*current));
+      libUse.emplace_back(std::make_shared<Entry>(*current));
       current->reset();
     }
     newEntry();
@@ -523,12 +437,12 @@ void VhdlParser::createFunction(const char *imp,uint64 spec,const char *fn)
     VhdlDocGen::deleteAllChars(current->args,' ');
     if (!fname.isEmpty())
     {
-      QStringList q1=QStringList::split(",",fname);
+      QCStringList q1=QCStringList::split(",",fname);
       for (uint ii=0;ii<q1.count();ii++)
       {
-        Argument *arg=new Argument;
-        arg->name=q1[ii].utf8();
-        current->argList->append(arg);
+        Argument arg;
+        arg.name=q1[ii];
+        current->argList.push_back(arg);
       }
     }
     return;
@@ -617,29 +531,29 @@ void VhdlParser::addConfigureNode(const char* a,const char*b, bool,bool isLeaf,b
 
 
 void VhdlParser::addProto(const char *s1,const char *s2,const char *s3,
-    const char *s4,const char *s5,const char *s6)
+                          const char *s4,const char *s5,const char *s6)
 {
   (void)s5; // avoid unused warning
   QCString name=s2;
-  QStringList ql=QStringList::split(",",name,FALSE);
+  QCStringList ql=QCStringList::split(",",name);
 
   for (uint u=0;u<ql.count();u++)
   {
-    Argument *arg=new Argument;
-    arg->name=ql[u].utf8();
+    Argument arg;
+    arg.name=ql[u];
     if (s3)
     {
-      arg->type=s3;
+      arg.type=s3;
     }
-    arg->type+=" ";
-    arg->type+=s4;
+    arg.type+=" ";
+    arg.type+=s4;
     if (s6)
     {
-      arg->type+=s6;
+      arg.type+=s6;
     }
     if (parse_sec==GEN_SEC && param_sec==0)
     {
-      arg->defval="gen!";
+      arg.defval="gen!";
     }
 
     if (parse_sec==PARAM_SEC)
@@ -647,10 +561,10 @@ void VhdlParser::addProto(const char *s1,const char *s2,const char *s3,
     //  assert(false);
     }
 
-    arg->defval+=s1;
-    arg->attrib="";//s6;
+    arg.defval+=s1;
+    arg.attrib="";//s6;
 
-    current->argList->append(arg);
+    current->argList.push_back(arg);
     current->args+=s2;
     current->args+=",";
   }
@@ -664,37 +578,36 @@ void VhdlParser::addProto(const char *s1,const char *s2,const char *s3,
  * .....
  * library
  * package
- * enity zzz
+ * entity zzz
  * .....
  * and so on..
  */
 void VhdlParser::mapLibPackage( Entry* root)
 {
-  QList<Entry> epp=libUse;
-  EntryListIterator eli(epp);
-  Entry *rt;
-  for (;(rt=eli.current());++eli)
+  //QList<Entry> epp=libUse;
+  //EntryListIterator eli(epp);
+  //Entry *rt;
+  //for (;(rt=eli.current());++eli)
+  for (const auto &rt : libUse)
   {
     if (addLibUseClause(rt->name))
     {
-      Entry *current;
-      EntryListIterator eLib(*root->children());
       bool bFound=FALSE;
-      for (eLib.toFirst();(current=eLib.current());++eLib)
+      for (const auto &current : root->children())
       {
-        if (VhdlDocGen::isVhdlClass(current))
+        if (VhdlDocGen::isVhdlClass(current.get()))
         {
           if (current->startLine > rt->startLine)
           {
             bFound=TRUE;
-            current->addSubEntry(new Entry(*rt));
+            current->copyToSubEntry(rt);
             break;
           }
         }
       }//for
       if (!bFound)
       {
-        root->addSubEntry(new Entry(*rt));
+        root->copyToSubEntry(rt);
       }
     } //if
   }// for
@@ -787,66 +700,80 @@ void VhdlParser::setMultCommentLine()
 
 void VhdlParser::oneLineComment(QCString qcs)
 {
-  bool isEndCode=qcs.contains("\\endcode");
-
-  int index = qcs.find("\\code");
-  if (isEndCode)
-  {
-    int end = inputString.find(qcs.data(),iCodeLen);
-    makeInlineDoc(end);
-  }
-  else if (index > 0)
-  {
-    // assert(false);
-    strComment=qcs;
-    startCodeBlock(index);
-    strComment.resize(0);
-  }
-
-  if (!isEndCode && index==-1)
-  {
     int j=qcs.find("--!");
     qcs=qcs.right(qcs.length()-3-j);
     if (!checkMultiComment(qcs,iDocLine))
     {
       handleCommentBlock(qcs,TRUE);
     }
-  }
 }
 
 
 bool  checkMultiComment(QCString& qcs,int line)
 {
-  QList<Entry> *pTemp=getEntryAtLine(VhdlParser::current_root,line);
+  insertEntryAtLine(VhdlParser::current_root,line);
 
-  if (pTemp->isEmpty()) return false;
+  if (lineEntry.empty()) return false;
 
   VhdlDocGen::prepareComment(qcs);
-  while (!pTemp->isEmpty())
+  while (!lineEntry.empty())
   {
-    Entry *e=(Entry*)pTemp->getFirst();
+    Entry *e=lineEntry.back();
     e->briefLine=line;
     e->brief+=qcs;
 
-    pTemp->removeFirst();
+    lineEntry.pop_back();
   }
   return true;
 }
 
 // returns the vhdl parsed types at line xxx
-QList<Entry>* getEntryAtLine(const Entry* ce,int line)
+void insertEntryAtLine(const Entry* ce,int line)
 {
-  EntryListIterator eli(*ce->children());
-  Entry *rt;
-  for (;(rt=eli.current());++eli)
+  for (const auto &rt : ce->children())
   {
     if (rt->bodyLine==line)
     {
-      lineEntry.insert(0,rt);
+      lineEntry.push_back(rt.get());
     }
 
-    getEntryAtLine(rt,line);
+    insertEntryAtLine(rt.get(),line);
   }
-  return &lineEntry;
 }
 
+const char *getVhdlFileName(void)
+{
+  return vhdlFileName;
+}
+
+QCString filter2008VhdlComment(const char *s)
+{
+  GrowBuf growBuf;
+  const char *p=s+3; // skip /*!
+  char c='\0';
+  while (*p == ' ' || *p == '\t') p++;
+  while ((c=*p++))
+  {
+    growBuf.addChar(c);
+    if (c == '\n')
+    {
+      // special handling of space followed by * at beginning of line
+      while (*p == ' ' || *p == '\t') p++;
+      while (*p == '*') p++;
+      // special attention in case character at end is /
+      if (*p == '/') p++;
+    }
+  }
+  // special attention in case */ at end of last line
+  int len = growBuf.getPos();
+  if (growBuf.at(len-1) == '/' && growBuf.at(len-2) == '*')
+  {
+    len -= 2;
+    while (growBuf.at(len-1) == '*') len--;
+    c = growBuf.at(len-1);
+    while ((c = growBuf.at(len-1)) == ' ' || c == '\t') len--;
+    growBuf.setPos(len);
+  }
+  growBuf.addChar(0);
+  return growBuf.get();
+}
